Class: Google::Apis::ClouddeployV1::AlertPolicyCheckStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

AlertPolicyCheckStatus contains information specific to a single run of an alert policy check.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AlertPolicyCheckStatus

Returns a new instance of AlertPolicyCheckStatus.



280
281
282
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 280

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alert_policiesArray<String>

Output only. The alert policies that this analysis monitors. Format is projects/project/locations/location/alertPolicies/alertPolicy`. Corresponds to the JSON propertyalertPolicies`

Returns:

  • (Array<String>)


256
257
258
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 256

def alert_policies
  @alert_policies
end

#failed_alert_policiesArray<Google::Apis::ClouddeployV1::FailedAlertPolicy>

Output only. The alert policies that were found to be firing during this check. This will be empty if no incidents were found. Corresponds to the JSON property failedAlertPolicies



262
263
264
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 262

def failed_alert_policies
  @failed_alert_policies
end

#failure_messageString

Output only. Additional information about the alert policy check failure, if available. This will be empty if the alert policy check succeeded. Corresponds to the JSON property failureMessage

Returns:

  • (String)


268
269
270
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 268

def failure_message
  @failure_message
end

#idString

Output only. The ID of this analysis. Corresponds to the JSON property id

Returns:

  • (String)


273
274
275
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 273

def id
  @id
end

#labelsHash<String,String>

Output only. The resolved labels used to filter for specific incidents. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


278
279
280
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 278

def labels
  @labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



285
286
287
288
289
290
291
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 285

def update!(**args)
  @alert_policies = args[:alert_policies] if args.key?(:alert_policies)
  @failed_alert_policies = args[:failed_alert_policies] if args.key?(:failed_alert_policies)
  @failure_message = args[:failure_message] if args.key?(:failure_message)
  @id = args[:id] if args.key?(:id)
  @labels = args[:labels] if args.key?(:labels)
end