Class: Google::Apis::ClouddeployV1::AnalysisJob

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

An analysis Job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AnalysisJob

Returns a new instance of AnalysisJob.



354
355
356
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 354

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_checksArray<Google::Apis::ClouddeployV1::CustomCheck>

Output only. Custom analysis checks from 3P metric providers that are run as part of the analysis Job. Corresponds to the JSON property customChecks



339
340
341
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 339

def custom_checks
  @custom_checks
end

#durationString

Output only. The amount of time in minutes the analysis Job will run, up to a maximum of 48 hours. If any check in this Job is still running when the duration ends, the Job keeps running until that check completes. Corresponds to the JSON property duration

Returns:

  • (String)


346
347
348
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 346

def duration
  @duration
end

#google_cloudGoogle::Apis::ClouddeployV1::GoogleCloudAnalysis

GoogleCloudAnalysis is a set of Google Cloud-based checks to perform on the deployment. Corresponds to the JSON property googleCloud



352
353
354
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 352

def google_cloud
  @google_cloud
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



359
360
361
362
363
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 359

def update!(**args)
  @custom_checks = args[:custom_checks] if args.key?(:custom_checks)
  @duration = args[:duration] if args.key?(:duration)
  @google_cloud = args[:google_cloud] if args.key?(:google_cloud)
end