Class: Google::Apis::ClouddeployV1::AutomationEvent
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::AutomationEvent
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
Payload proto for "clouddeploy.googleapis.com/automation" Platform Log event that describes the Automation related events.
Instance Attribute Summary collapse
-
#automation ⇒ String
The name of the
AutomationRun. -
#message ⇒ String
Debug message for when there is an update on the AutomationRun.
-
#pipeline_uid ⇒ String
Unique identifier of the
DeliveryPipeline. -
#type ⇒ String
Type of this notification, e.g.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutomationEvent
constructor
A new instance of AutomationEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutomationEvent
Returns a new instance of AutomationEvent.
697 698 699 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 697 def initialize(**args) update!(**args) end |
Instance Attribute Details
#automation ⇒ String
The name of the AutomationRun.
Corresponds to the JSON property automation
679 680 681 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 679 def automation @automation end |
#message ⇒ String
Debug message for when there is an update on the AutomationRun. Provides
further details about the resource creation or state change.
Corresponds to the JSON property message
685 686 687 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 685 def @message end |
#pipeline_uid ⇒ String
Unique identifier of the DeliveryPipeline.
Corresponds to the JSON property pipelineUid
690 691 692 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 690 def pipeline_uid @pipeline_uid end |
#type ⇒ String
Type of this notification, e.g. for a Pub/Sub failure.
Corresponds to the JSON property type
695 696 697 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 695 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
702 703 704 705 706 707 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 702 def update!(**args) @automation = args[:automation] if args.key?(:automation) @message = args[:message] if args.key?(:message) @pipeline_uid = args[:pipeline_uid] if args.key?(:pipeline_uid) @type = args[:type] if args.key?(:type) end |