Class: Google::Apis::ClouddeployV1::AutomationRule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

AutomationRule defines the automation activities.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutomationRule

Returns a new instance of AutomationRule.



792
793
794
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 792

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advance_rollout_ruleGoogle::Apis::ClouddeployV1::AdvanceRolloutRule

The AdvanceRollout automation rule will automatically advance a successful Rollout to the next phase. Corresponds to the JSON property advanceRolloutRule



772
773
774
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 772

def advance_rollout_rule
  @advance_rollout_rule
end

#promote_release_ruleGoogle::Apis::ClouddeployV1::PromoteReleaseRule

The PromoteRelease rule will automatically promote a release from the current target to a specified target. Corresponds to the JSON property promoteReleaseRule



778
779
780
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 778

def promote_release_rule
  @promote_release_rule
end

#repair_rollout_ruleGoogle::Apis::ClouddeployV1::RepairRolloutRule

The RepairRolloutRule automation rule will automatically repair a failed Rollout. Corresponds to the JSON property repairRolloutRule



784
785
786
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 784

def repair_rollout_rule
  @repair_rollout_rule
end

#timed_promote_release_ruleGoogle::Apis::ClouddeployV1::TimedPromoteReleaseRule

The TimedPromoteReleaseRule will automatically promote a release from the current target(s) to the specified target(s) on a configured schedule. Corresponds to the JSON property timedPromoteReleaseRule



790
791
792
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 790

def timed_promote_release_rule
  @timed_promote_release_rule
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



797
798
799
800
801
802
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 797

def update!(**args)
  @advance_rollout_rule = args[:advance_rollout_rule] if args.key?(:advance_rollout_rule)
  @promote_release_rule = args[:promote_release_rule] if args.key?(:promote_release_rule)
  @repair_rollout_rule = args[:repair_rollout_rule] if args.key?(:repair_rollout_rule)
  @timed_promote_release_rule = args[:timed_promote_release_rule] if args.key?(:timed_promote_release_rule)
end