Class: Google::Apis::ClouddeployV1::AutomationRun

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

An AutomationRun resource in the Cloud Deploy API. An AutomationRun represents an execution instance of an automation rule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutomationRun

Returns a new instance of AutomationRun.



948
949
950
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 948

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advance_rollout_operationGoogle::Apis::ClouddeployV1::AdvanceRolloutOperation

Contains the information of an automated advance-rollout operation. Corresponds to the JSON property advanceRolloutOperation



840
841
842
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 840

def advance_rollout_operation
  @advance_rollout_operation
end

#automation_idString

Output only. The ID of the automation that initiated the operation. Corresponds to the JSON property automationId

Returns:

  • (String)


845
846
847
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 845

def automation_id
  @automation_id
end

#automation_snapshotGoogle::Apis::ClouddeployV1::Automation

An Automation resource in the Cloud Deploy API. An Automation enables the automation of manually driven actions for a Delivery Pipeline, which includes Release promotion among Targets, Rollout repair and Rollout deployment strategy advancement. The intention of Automation is to reduce manual intervention in the continuous delivery process. Corresponds to the JSON property automationSnapshot



854
855
856
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 854

def automation_snapshot
  @automation_snapshot
end

#create_timeString

Output only. Time at which the AutomationRun was created. Corresponds to the JSON property createTime

Returns:

  • (String)


859
860
861
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 859

def create_time
  @create_time
end

#etagString

Output only. The weak etag of the AutomationRun resource. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


867
868
869
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 867

def etag
  @etag
end

#expire_timeString

Output only. Time the AutomationRun expires. An AutomationRun expires after 14 days from its creation date. Corresponds to the JSON property expireTime

Returns:

  • (String)


873
874
875
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 873

def expire_time
  @expire_time
end

#nameString

Output only. Name of the AutomationRun. Format is projects/project/ locations/location/deliveryPipelines/delivery_pipeline/automationRuns/ automation_run`. Corresponds to the JSON propertyname`

Returns:

  • (String)


880
881
882
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 880

def name
  @name
end

#policy_violationGoogle::Apis::ClouddeployV1::PolicyViolation

Returned from an action if one or more policies were violated, and therefore the action was prevented. Contains information about what policies were violated and why. Corresponds to the JSON property policyViolation



887
888
889
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 887

def policy_violation
  @policy_violation
end

#promote_release_operationGoogle::Apis::ClouddeployV1::PromoteReleaseOperation

Contains the information of an automated promote-release operation. Corresponds to the JSON property promoteReleaseOperation



892
893
894
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 892

def promote_release_operation
  @promote_release_operation
end

#repair_rollout_operationGoogle::Apis::ClouddeployV1::RepairRolloutOperation

Contains the information for an automated repair rollout operation. Corresponds to the JSON property repairRolloutOperation



897
898
899
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 897

def repair_rollout_operation
  @repair_rollout_operation
end

#rule_idString

Output only. The ID of the automation rule that initiated the operation. Corresponds to the JSON property ruleId

Returns:

  • (String)


902
903
904
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 902

def rule_id
  @rule_id
end

#service_accountString

Output only. Email address of the user-managed IAM service account that performs the operations against Cloud Deploy resources. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


908
909
910
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 908

def 
  @service_account
end

#stateString

Output only. Current state of the AutomationRun. Corresponds to the JSON property state

Returns:

  • (String)


913
914
915
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 913

def state
  @state
end

#state_descriptionString

Output only. Explains the current state of the AutomationRun. Present only when an explanation is needed. Corresponds to the JSON property stateDescription

Returns:

  • (String)


919
920
921
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 919

def state_description
  @state_description
end

#target_idString

Output only. The ID of the source target that initiates the AutomationRun. The value of this field is the last segment of a target name. Corresponds to the JSON property targetId

Returns:

  • (String)


925
926
927
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 925

def target_id
  @target_id
end

#timed_promote_release_operationGoogle::Apis::ClouddeployV1::TimedPromoteReleaseOperation

Contains the information of an automated timed promote-release operation. Corresponds to the JSON property timedPromoteReleaseOperation



930
931
932
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 930

def timed_promote_release_operation
  @timed_promote_release_operation
end

#uidString

Output only. Unique identifier of the AutomationRun. Corresponds to the JSON property uid

Returns:

  • (String)


935
936
937
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 935

def uid
  @uid
end

#update_timeString

Output only. Time at which the automationRun was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


940
941
942
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 940

def update_time
  @update_time
end

#wait_until_timeString

Output only. Earliest time the AutomationRun will attempt to resume. Wait- time is configured by wait in automation rule. Corresponds to the JSON property waitUntilTime

Returns:

  • (String)


946
947
948
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 946

def wait_until_time
  @wait_until_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 953

def update!(**args)
  @advance_rollout_operation = args[:advance_rollout_operation] if args.key?(:advance_rollout_operation)
  @automation_id = args[:automation_id] if args.key?(:automation_id)
  @automation_snapshot = args[:automation_snapshot] if args.key?(:automation_snapshot)
  @create_time = args[:create_time] if args.key?(:create_time)
  @etag = args[:etag] if args.key?(:etag)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @name = args[:name] if args.key?(:name)
  @policy_violation = args[:policy_violation] if args.key?(:policy_violation)
  @promote_release_operation = args[:promote_release_operation] if args.key?(:promote_release_operation)
  @repair_rollout_operation = args[:repair_rollout_operation] if args.key?(:repair_rollout_operation)
  @rule_id = args[:rule_id] if args.key?(:rule_id)
  @service_account = args[:service_account] if args.key?(:service_account)
  @state = args[:state] if args.key?(:state)
  @state_description = args[:state_description] if args.key?(:state_description)
  @target_id = args[:target_id] if args.key?(:target_id)
  @timed_promote_release_operation = args[:timed_promote_release_operation] if args.key?(:timed_promote_release_operation)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @wait_until_time = args[:wait_until_time] if args.key?(:wait_until_time)
end