Class: Google::Apis::ClouddeployV1::AutomationRunEvent
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::AutomationRunEvent
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
Payload proto for "clouddeploy.googleapis.com/automation_run" Platform Log event that describes the AutomationRun related events.
Instance Attribute Summary collapse
-
#automation_id ⇒ String
Identifier of the
Automation. -
#automation_run ⇒ String
The name of the
AutomationRun. -
#destination_target_id ⇒ String
ID of the
Targetto which theAutomationRunis created. -
#message ⇒ String
Debug message for when there is an update on the AutomationRun.
-
#pipeline_uid ⇒ String
Unique identifier of the
DeliveryPipeline. -
#rule_id ⇒ String
Identifier of the
Automationrule. -
#type ⇒ String
Type of this notification, e.g.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutomationRunEvent
constructor
A new instance of AutomationRunEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutomationRunEvent
Returns a new instance of AutomationRunEvent.
1017 1018 1019 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1017 def initialize(**args) update!(**args) end |
Instance Attribute Details
#automation_id ⇒ String
Identifier of the Automation.
Corresponds to the JSON property automationId
984 985 986 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 984 def automation_id @automation_id end |
#automation_run ⇒ String
The name of the AutomationRun.
Corresponds to the JSON property automationRun
989 990 991 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 989 def automation_run @automation_run end |
#destination_target_id ⇒ String
ID of the Target to which the AutomationRun is created.
Corresponds to the JSON property destinationTargetId
994 995 996 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 994 def destination_target_id @destination_target_id end |
#message ⇒ String
Debug message for when there is an update on the AutomationRun. Provides
further details about the resource creation or state change.
Corresponds to the JSON property message
1000 1001 1002 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1000 def @message end |
#pipeline_uid ⇒ String
Unique identifier of the DeliveryPipeline.
Corresponds to the JSON property pipelineUid
1005 1006 1007 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1005 def pipeline_uid @pipeline_uid end |
#rule_id ⇒ String
Identifier of the Automation rule.
Corresponds to the JSON property ruleId
1010 1011 1012 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1010 def rule_id @rule_id end |
#type ⇒ String
Type of this notification, e.g. for a Pub/Sub failure.
Corresponds to the JSON property type
1015 1016 1017 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1015 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1022 1023 1024 1025 1026 1027 1028 1029 1030 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1022 def update!(**args) @automation_id = args[:automation_id] if args.key?(:automation_id) @automation_run = args[:automation_run] if args.key?(:automation_run) @destination_target_id = args[:destination_target_id] if args.key?(:destination_target_id) @message = args[:message] if args.key?(:message) @pipeline_uid = args[:pipeline_uid] if args.key?(:pipeline_uid) @rule_id = args[:rule_id] if args.key?(:rule_id) @type = args[:type] if args.key?(:type) end |