Class: Google::Apis::ClouddeployV1::CloudRunConfig
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::CloudRunConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
CloudRunConfig contains the Cloud Run runtime configuration.
Instance Attribute Summary collapse
-
#automatic_traffic_control ⇒ Boolean
(also: #automatic_traffic_control?)
Optional.
-
#canary_revision_tags ⇒ Array<String>
Optional.
-
#prior_revision_tags ⇒ Array<String>
Optional.
-
#stable_revision_tags ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudRunConfig
constructor
A new instance of CloudRunConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudRunConfig
Returns a new instance of CloudRunConfig.
1375 1376 1377 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1375 def initialize(**args) update!(**args) end |
Instance Attribute Details
#automatic_traffic_control ⇒ Boolean Also known as: automatic_traffic_control?
Optional. Whether Cloud Deploy should update the traffic stanza in a Cloud Run
Service on the user's behalf to facilitate traffic splitting. This is required
to be true for CanaryDeployments, but optional for CustomCanaryDeployments.
Corresponds to the JSON property automaticTrafficControl
1354 1355 1356 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1354 def automatic_traffic_control @automatic_traffic_control end |
#canary_revision_tags ⇒ Array<String>
Optional. A list of tags that are added to the canary revision while the
canary phase is in progress.
Corresponds to the JSON property canaryRevisionTags
1361 1362 1363 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1361 def @canary_revision_tags end |
#prior_revision_tags ⇒ Array<String>
Optional. A list of tags that are added to the prior revision while the canary
phase is in progress.
Corresponds to the JSON property priorRevisionTags
1367 1368 1369 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1367 def @prior_revision_tags end |
#stable_revision_tags ⇒ Array<String>
Optional. A list of tags that are added to the final stable revision when the
stable phase is applied.
Corresponds to the JSON property stableRevisionTags
1373 1374 1375 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1373 def @stable_revision_tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1380 1381 1382 1383 1384 1385 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1380 def update!(**args) @automatic_traffic_control = args[:automatic_traffic_control] if args.key?(:automatic_traffic_control) @canary_revision_tags = args[:canary_revision_tags] if args.key?(:canary_revision_tags) @prior_revision_tags = args[:prior_revision_tags] if args.key?(:prior_revision_tags) @stable_revision_tags = args[:stable_revision_tags] if args.key?(:stable_revision_tags) end |