Class: Google::Apis::ClouddeployV1::CloudRunRenderMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

CloudRunRenderMetadata contains Cloud Run information associated with a Release render.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudRunRenderMetadata

Returns a new instance of CloudRunRenderMetadata.



1495
1496
1497
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1495

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#jobString

Output only. The name of the Cloud Run Job in the rendered manifest. Format is projects/project/locations/location/jobs/job`. Corresponds to the JSON propertyjob`

Returns:

  • (String)


1474
1475
1476
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1474

def job
  @job
end

#revisionString

Output only. The name of the Cloud Run Revision in the rendered manifest. Format is projects/project/locations/location/services/service/ revisions/revision`. Corresponds to the JSON propertyrevision`

Returns:

  • (String)


1481
1482
1483
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1481

def revision
  @revision
end

#serviceString

Output only. The name of the Cloud Run Service in the rendered manifest. Format is projects/project/locations/location/services/service`. Corresponds to the JSON propertyservice`

Returns:

  • (String)


1487
1488
1489
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1487

def service
  @service
end

#worker_poolString

Output only. The name of the Cloud Run Worker Pool in the rendered manifest. Format is projects/project/locations/location/workerPools/worker_pool`. Corresponds to the JSON propertyworkerPool`

Returns:

  • (String)


1493
1494
1495
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1493

def worker_pool
  @worker_pool
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1500
1501
1502
1503
1504
1505
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1500

def update!(**args)
  @job = args[:job] if args.key?(:job)
  @revision = args[:revision] if args.key?(:revision)
  @service = args[:service] if args.key?(:service)
  @worker_pool = args[:worker_pool] if args.key?(:worker_pool)
end