Class: Google::Apis::ClouddeployV1::Config
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::Config
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
Service-wide configuration.
Instance Attribute Summary collapse
-
#default_skaffold_version ⇒ String
Default Skaffold version that is assigned when a Release is created without specifying a Skaffold version.
-
#default_tool_versions ⇒ Google::Apis::ClouddeployV1::ToolVersions
Details of ToolVersions for the release.
-
#name ⇒ String
Name of the configuration.
-
#supported_versions ⇒ Array<Google::Apis::ClouddeployV1::SkaffoldVersion>
All supported versions of Skaffold.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Config
constructor
A new instance of Config.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Config
Returns a new instance of Config.
1306 1307 1308 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1306 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_skaffold_version ⇒ String
Default Skaffold version that is assigned when a Release is created without
specifying a Skaffold version.
Corresponds to the JSON property defaultSkaffoldVersion
1289 1290 1291 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1289 def default_skaffold_version @default_skaffold_version end |
#default_tool_versions ⇒ Google::Apis::ClouddeployV1::ToolVersions
Details of ToolVersions for the release.
Corresponds to the JSON property defaultToolVersions
1294 1295 1296 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1294 def default_tool_versions @default_tool_versions end |
#name ⇒ String
Name of the configuration.
Corresponds to the JSON property name
1299 1300 1301 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1299 def name @name end |
#supported_versions ⇒ Array<Google::Apis::ClouddeployV1::SkaffoldVersion>
All supported versions of Skaffold.
Corresponds to the JSON property supportedVersions
1304 1305 1306 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1304 def supported_versions @supported_versions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1311 1312 1313 1314 1315 1316 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1311 def update!(**args) @default_skaffold_version = args[:default_skaffold_version] if args.key?(:default_skaffold_version) @default_tool_versions = args[:default_tool_versions] if args.key?(:default_tool_versions) @name = args[:name] if args.key?(:name) @supported_versions = args[:supported_versions] if args.key?(:supported_versions) end |