Class: Google::Apis::ClouddeployV1::CustomCheck

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

CustomCheck configures a third-party metric provider to run the analysis, via a Task that runs at a specified frequency.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomCheck

Returns a new instance of CustomCheck.



1675
1676
1677
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1675

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#frequencyString

Optional. The frequency at which the custom check will be run, with a minimum and default of 5 minutes. Corresponds to the JSON property frequency

Returns:

  • (String)


1663
1664
1665
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1663

def frequency
  @frequency
end

#idString

Required. The ID of the custom Analysis check. Corresponds to the JSON property id

Returns:

  • (String)


1668
1669
1670
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1668

def id
  @id
end

#taskGoogle::Apis::ClouddeployV1::Task

A Task represents a unit of work that is executed as part of a Job. Corresponds to the JSON property task



1673
1674
1675
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1673

def task
  @task
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1680
1681
1682
1683
1684
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1680

def update!(**args)
  @frequency = args[:frequency] if args.key?(:frequency)
  @id = args[:id] if args.key?(:id)
  @task = args[:task] if args.key?(:task)
end