Class: Google::Apis::ClouddeployV1::CustomCheckStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

CustomCheckStatus contains information specific to a single iteration of a custom analysis job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomCheckStatus

Returns a new instance of CustomCheckStatus.



1730
1731
1732
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1730

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failure_causeString

Output only. The reason the analysis failed. This will always be unspecified while the analysis is in progress or if it succeeded. Corresponds to the JSON property failureCause

Returns:

  • (String)


1696
1697
1698
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1696

def failure_cause
  @failure_cause
end

#failure_messageString

Output only. Additional information about the analysis failure, if available. Corresponds to the JSON property failureMessage

Returns:

  • (String)


1701
1702
1703
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1701

def failure_message
  @failure_message
end

#frequencyString

Output only. The frequency in minutes at which the custom check is run. Corresponds to the JSON property frequency

Returns:

  • (String)


1706
1707
1708
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1706

def frequency
  @frequency
end

#idString

Output only. The ID of the custom check. Corresponds to the JSON property id

Returns:

  • (String)


1711
1712
1713
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1711

def id
  @id
end

#latest_buildString

Output only. The resource name of the Cloud Build Build object that was used to execute the latest run of this custom action check. Format is projects/ project/locations/location/builds/build`. Corresponds to the JSON propertylatestBuild`

Returns:

  • (String)


1718
1719
1720
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1718

def latest_build
  @latest_build
end

#metadataGoogle::Apis::ClouddeployV1::CustomMetadata

CustomMetadata contains information from a user-defined operation. Corresponds to the JSON property metadata



1723
1724
1725
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1723

def 
  @metadata
end

#taskGoogle::Apis::ClouddeployV1::Task

A Task represents a unit of work that is executed as part of a Job. Corresponds to the JSON property task



1728
1729
1730
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1728

def task
  @task
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1735

def update!(**args)
  @failure_cause = args[:failure_cause] if args.key?(:failure_cause)
  @failure_message = args[:failure_message] if args.key?(:failure_message)
  @frequency = args[:frequency] if args.key?(:frequency)
  @id = args[:id] if args.key?(:id)
  @latest_build = args[:latest_build] if args.key?(:latest_build)
  @metadata = args[:metadata] if args.key?(:metadata)
  @task = args[:task] if args.key?(:task)
end