Class: Google::Apis::ClouddeployV1::CustomTargetTasks

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

CustomTargetTasks represents the CustomTargetType configuration using tasks.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomTargetTasks

Returns a new instance of CustomTargetTasks.



1847
1848
1849
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1847

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deployGoogle::Apis::ClouddeployV1::Task

A Task represents a unit of work that is executed as part of a Job. Corresponds to the JSON property deploy



1840
1841
1842
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1840

def deploy
  @deploy
end

#renderGoogle::Apis::ClouddeployV1::Task

A Task represents a unit of work that is executed as part of a Job. Corresponds to the JSON property render



1845
1846
1847
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1845

def render
  @render
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1852
1853
1854
1855
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1852

def update!(**args)
  @deploy = args[:deploy] if args.key?(:deploy)
  @render = args[:render] if args.key?(:render)
end