Class: Google::Apis::ClouddeployV1::DeliveryPipelineNotificationEvent

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

Payload proto for "clouddeploy.googleapis.com/deliverypipeline_notification" Platform Log event that describes the failure to send delivery pipeline status change Pub/Sub notification.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeliveryPipelineNotificationEvent

Returns a new instance of DeliveryPipelineNotificationEvent.



1818
1819
1820
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1818

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#delivery_pipelineString

The name of the Delivery Pipeline. Corresponds to the JSON property deliveryPipeline

Returns:

  • (String)


1801
1802
1803
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1801

def delivery_pipeline
  @delivery_pipeline
end

#messageString

Debug message for when a notification fails to send. Corresponds to the JSON property message

Returns:

  • (String)


1806
1807
1808
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1806

def message
  @message
end

#pipeline_uidString

Unique identifier of the DeliveryPipeline. Corresponds to the JSON property pipelineUid

Returns:

  • (String)


1811
1812
1813
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1811

def pipeline_uid
  @pipeline_uid
end

#typeString

Type of this notification, e.g. for a Pub/Sub failure. Corresponds to the JSON property type

Returns:

  • (String)


1816
1817
1818
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1816

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1823
1824
1825
1826
1827
1828
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1823

def update!(**args)
  @delivery_pipeline = args[:delivery_pipeline] if args.key?(:delivery_pipeline)
  @message = args[:message] if args.key?(:message)
  @pipeline_uid = args[:pipeline_uid] if args.key?(:pipeline_uid)
  @type = args[:type] if args.key?(:type)
end