Class: Google::Apis::ClouddeployV1::DeployJobRun
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::DeployJobRun
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
DeployJobRun contains information specific to a deploy JobRun.
Instance Attribute Summary collapse
-
#artifact ⇒ Google::Apis::ClouddeployV1::DeployArtifact
The artifacts produced by a deploy operation.
-
#build ⇒ String
Output only.
-
#failure_cause ⇒ String
Output only.
-
#failure_message ⇒ String
Output only.
-
#metadata ⇒ Google::Apis::ClouddeployV1::DeployJobRunMetadata
DeployJobRunMetadata surfaces information associated with a
DeployJobRunto the user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeployJobRun
constructor
A new instance of DeployJobRun.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeployJobRun
Returns a new instance of DeployJobRun.
2300 2301 2302 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2300 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact ⇒ Google::Apis::ClouddeployV1::DeployArtifact
The artifacts produced by a deploy operation.
Corresponds to the JSON property artifact
2275 2276 2277 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2275 def artifact @artifact end |
#build ⇒ String
Output only. The resource name of the Cloud Build Build object that is used
to deploy. Format is projects/project/locations/location/builds/build`.
Corresponds to the JSON propertybuild`
2281 2282 2283 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2281 def build @build end |
#failure_cause ⇒ String
Output only. The reason the deploy failed. This will always be unspecified
while the deploy is in progress or if it succeeded.
Corresponds to the JSON property failureCause
2287 2288 2289 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2287 def failure_cause @failure_cause end |
#failure_message ⇒ String
Output only. Additional information about the deploy failure, if available.
Corresponds to the JSON property failureMessage
2292 2293 2294 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2292 def @failure_message end |
#metadata ⇒ Google::Apis::ClouddeployV1::DeployJobRunMetadata
DeployJobRunMetadata surfaces information associated with a DeployJobRun to
the user.
Corresponds to the JSON property metadata
2298 2299 2300 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2298 def @metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2305 2306 2307 2308 2309 2310 2311 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2305 def update!(**args) @artifact = args[:artifact] if args.key?(:artifact) @build = args[:build] if args.key?(:build) @failure_cause = args[:failure_cause] if args.key?(:failure_cause) @failure_message = args[:failure_message] if args.key?(:failure_message) @metadata = args[:metadata] if args.key?(:metadata) end |