Class: Google::Apis::ClouddeployV1::DeployPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::DeployPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
A DeployPolicy resource in the Cloud Deploy API. A DeployPolicy inhibits
manual or automation-driven actions within a Delivery Pipeline or Target.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#etag ⇒ String
The weak etag of the
DeployPolicyresource. -
#labels ⇒ Hash<String,String>
Labels are attributes that can be set and used by both the user and by Cloud Deploy.
-
#name ⇒ String
Output only.
-
#rules ⇒ Array<Google::Apis::ClouddeployV1::PolicyRule>
Required.
-
#selectors ⇒ Array<Google::Apis::ClouddeployV1::DeployPolicyResourceSelector>
Required.
-
#suspended ⇒ Boolean
(also: #suspended?)
Optional.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeployPolicy
constructor
A new instance of DeployPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeployPolicy
Returns a new instance of DeployPolicy.
2459 2460 2461 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2459 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. User annotations. These attributes can only be set and used by the user, and not by Cloud Deploy. Annotations must meet the following constraints:
- Annotations are key/value pairs. * Valid annotation keys have two segments:
an optional prefix and name, separated by a slash (
/). * The name segment is required and must be 63 characters or less, beginning and ending with an alphanumeric character ([a-z0-9A-Z]) with dashes (-), underscores (_), dots (.), and alphanumerics between. * The prefix is optional. If specified, the prefix must be a DNS subdomain: a series of DNS labels separated by dots(.), not longer than 253 characters in total, followed by a slash (/). See https://kubernetes.io/docs/concepts/overview/working-with-objects/annotations/# syntax-and-character-set for more details. Corresponds to the JSON propertyannotations
2392 2393 2394 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2392 def annotations @annotations end |
#create_time ⇒ String
Output only. Time at which the deploy policy was created.
Corresponds to the JSON property createTime
2397 2398 2399 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2397 def create_time @create_time end |
#description ⇒ String
Optional. Description of the DeployPolicy. Max length is 255 characters.
Corresponds to the JSON property description
2402 2403 2404 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2402 def description @description end |
#etag ⇒ String
The weak etag of the DeployPolicy resource. This checksum is computed by the
server based on the value of other fields, and may be sent on update and
delete requests to ensure the client has an up-to-date value before proceeding.
Corresponds to the JSON property etag
2409 2410 2411 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2409 def etag @etag end |
#labels ⇒ Hash<String,String>
Labels are attributes that can be set and used by both the user and by Cloud Deploy. Labels must meet the following constraints: * Keys and values can contain only lowercase letters, numeric characters, underscores, and dashes. * All characters must use UTF-8 encoding, and international characters are allowed. * Keys must start with a lowercase letter or international character.
- Each resource is limited to a maximum of 64 labels. Both keys and values are
additionally constrained to be <= 128 bytes.
Corresponds to the JSON property
labels
2420 2421 2422 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2420 def labels @labels end |
#name ⇒ String
Output only. Name of the DeployPolicy. Format is projects/project/
locations/location/deployPolicies/deployPolicy`. ThedeployPolicy
component must matcha-z?
Corresponds to the JSON propertyname`
2427 2428 2429 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2427 def name @name end |
#rules ⇒ Array<Google::Apis::ClouddeployV1::PolicyRule>
Required. Rules to apply. At least one rule must be present.
Corresponds to the JSON property rules
2432 2433 2434 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2432 def rules @rules end |
#selectors ⇒ Array<Google::Apis::ClouddeployV1::DeployPolicyResourceSelector>
Required. Selected resources to which the policy will be applied. At least one
selector is required. If one selector matches the resource the policy applies.
For example, if there are two selectors and the action being attempted matches
one of them, the policy will apply to that action.
Corresponds to the JSON property selectors
2440 2441 2442 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2440 def selectors @selectors end |
#suspended ⇒ Boolean Also known as: suspended?
Optional. When suspended, the policy will not prevent actions from occurring,
even if the action violates the policy.
Corresponds to the JSON property suspended
2446 2447 2448 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2446 def suspended @suspended end |
#uid ⇒ String
Output only. Unique identifier of the DeployPolicy.
Corresponds to the JSON property uid
2452 2453 2454 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2452 def uid @uid end |
#update_time ⇒ String
Output only. Most recent time at which the deploy policy was updated.
Corresponds to the JSON property updateTime
2457 2458 2459 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2457 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2464 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @rules = args[:rules] if args.key?(:rules) @selectors = args[:selectors] if args.key?(:selectors) @suspended = args[:suspended] if args.key?(:suspended) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |