Class: Google::Apis::ClouddeployV1::DeployPolicyEvaluationEvent

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

Payload proto for "clouddeploy.googleapis.com/deploypolicy_evaluation" Platform Log event that describes the deploy policy evaluation event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeployPolicyEvaluationEvent

Returns a new instance of DeployPolicyEvaluationEvent.



2549
2550
2551
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2549

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowedBoolean Also known as: allowed?

Whether the request is allowed. Allowed is set as true if: (1) the request complies with the policy; or (2) the request doesn't comply with the policy but the policy was overridden; or (3) the request doesn't comply with the policy but the policy was suspended Corresponds to the JSON property allowed

Returns:

  • (Boolean)


2483
2484
2485
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2483

def allowed
  @allowed
end

#delivery_pipelineString

The name of the Delivery Pipeline. Corresponds to the JSON property deliveryPipeline

Returns:

  • (String)


2489
2490
2491
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2489

def delivery_pipeline
  @delivery_pipeline
end

#deploy_policyString

The name of the DeployPolicy. Corresponds to the JSON property deployPolicy

Returns:

  • (String)


2494
2495
2496
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2494

def deploy_policy
  @deploy_policy
end

#deploy_policy_uidString

Unique identifier of the DeployPolicy. Corresponds to the JSON property deployPolicyUid

Returns:

  • (String)


2499
2500
2501
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2499

def deploy_policy_uid
  @deploy_policy_uid
end

#invokerString

What invoked the action (e.g. a user or automation). Corresponds to the JSON property invoker

Returns:

  • (String)


2504
2505
2506
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2504

def invoker
  @invoker
end

#messageString

Debug message for when a deploy policy event occurs. Corresponds to the JSON property message

Returns:

  • (String)


2509
2510
2511
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2509

def message
  @message
end

#overridesArray<String>

Things that could have overridden the policy verdict. Overrides together with verdict decide whether the request is allowed. Corresponds to the JSON property overrides

Returns:

  • (Array<String>)


2515
2516
2517
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2515

def overrides
  @overrides
end

#pipeline_uidString

Unique identifier of the Delivery Pipeline. Corresponds to the JSON property pipelineUid

Returns:

  • (String)


2520
2521
2522
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2520

def pipeline_uid
  @pipeline_uid
end

#ruleString

Rule id. Corresponds to the JSON property rule

Returns:

  • (String)


2525
2526
2527
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2525

def rule
  @rule
end

#rule_typeString

Rule type (e.g. Restrict Rollouts). Corresponds to the JSON property ruleType

Returns:

  • (String)


2530
2531
2532
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2530

def rule_type
  @rule_type
end

#targetString

The name of the Target. This is an optional field, as a Target may not always be applicable to a policy. Corresponds to the JSON property target

Returns:

  • (String)


2536
2537
2538
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2536

def target
  @target
end

#target_uidString

Unique identifier of the Target. This is an optional field, as a Target may not always be applicable to a policy. Corresponds to the JSON property targetUid

Returns:

  • (String)


2542
2543
2544
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2542

def target_uid
  @target_uid
end

#verdictString

The policy verdict of the request. Corresponds to the JSON property verdict

Returns:

  • (String)


2547
2548
2549
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2547

def verdict
  @verdict
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2554

def update!(**args)
  @allowed = args[:allowed] if args.key?(:allowed)
  @delivery_pipeline = args[:delivery_pipeline] if args.key?(:delivery_pipeline)
  @deploy_policy = args[:deploy_policy] if args.key?(:deploy_policy)
  @deploy_policy_uid = args[:deploy_policy_uid] if args.key?(:deploy_policy_uid)
  @invoker = args[:invoker] if args.key?(:invoker)
  @message = args[:message] if args.key?(:message)
  @overrides = args[:overrides] if args.key?(:overrides)
  @pipeline_uid = args[:pipeline_uid] if args.key?(:pipeline_uid)
  @rule = args[:rule] if args.key?(:rule)
  @rule_type = args[:rule_type] if args.key?(:rule_type)
  @target = args[:target] if args.key?(:target)
  @target_uid = args[:target_uid] if args.key?(:target_uid)
  @verdict = args[:verdict] if args.key?(:verdict)
end