Class: Google::Apis::ClouddeployV1::DeployPolicyNotificationEvent

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

Payload proto for "clouddeploy.googleapis.com/deploypolicy_notification". Platform Log event that describes the failure to send a pub/sub notification when there is a DeployPolicy status change.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeployPolicyNotificationEvent

Returns a new instance of DeployPolicyNotificationEvent.



2207
2208
2209
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2207

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deploy_policyString

The name of the DeployPolicy. Corresponds to the JSON property deployPolicy

Returns:

  • (String)


2190
2191
2192
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2190

def deploy_policy
  @deploy_policy
end

#deploy_policy_uidString

Unique identifier of the deploy policy. Corresponds to the JSON property deployPolicyUid

Returns:

  • (String)


2195
2196
2197
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2195

def deploy_policy_uid
  @deploy_policy_uid
end

#messageString

Debug message for when a deploy policy fails to send a pub/sub notification. Corresponds to the JSON property message

Returns:

  • (String)


2200
2201
2202
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2200

def message
  @message
end

#typeString

Type of this notification, e.g. for a Pub/Sub failure. Corresponds to the JSON property type

Returns:

  • (String)


2205
2206
2207
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2205

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2212
2213
2214
2215
2216
2217
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2212

def update!(**args)
  @deploy_policy = args[:deploy_policy] if args.key?(:deploy_policy)
  @deploy_policy_uid = args[:deploy_policy_uid] if args.key?(:deploy_policy_uid)
  @message = args[:message] if args.key?(:message)
  @type = args[:type] if args.key?(:type)
end