Class: Google::Apis::ClouddeployV1::FailedAlertPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

FailedAlertPolicy contains information about an alert policy that was found to be firing during an alert policy check.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FailedAlertPolicy

Returns a new instance of FailedAlertPolicy.



2848
2849
2850
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2848

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alert_policyString

Output only. The name of the alert policy that was found to be firing. Format is projects/project/locations/location/alertPolicies/alertPolicy`. Corresponds to the JSON propertyalertPolicy`

Returns:

  • (String)


2840
2841
2842
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2840

def alert_policy
  @alert_policy
end

#alertsArray<String>

Output only. Open alerts for the alerting policies that matched the alert policy check configuration. Corresponds to the JSON property alerts

Returns:

  • (Array<String>)


2846
2847
2848
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2846

def alerts
  @alerts
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2853
2854
2855
2856
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2853

def update!(**args)
  @alert_policy = args[:alert_policy] if args.key?(:alert_policy)
  @alerts = args[:alerts] if args.key?(:alerts)
end