Class: Google::Apis::ClouddeployV1::GkeCluster
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::GkeCluster
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
Information specifying a GKE Cluster.
Instance Attribute Summary collapse
-
#cluster ⇒ String
Optional.
-
#dns_endpoint ⇒ Boolean
(also: #dns_endpoint?)
Optional.
-
#internal_ip ⇒ Boolean
(also: #internal_ip?)
Optional.
-
#proxy_url ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GkeCluster
constructor
A new instance of GkeCluster.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GkeCluster
Returns a new instance of GkeCluster.
2957 2958 2959 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2957 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster ⇒ String
Optional. Information specifying a GKE Cluster. Format is projects/
project_id/locations/location_id/clusters/cluster_id`.
Corresponds to the JSON propertycluster`
2928 2929 2930 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2928 def cluster @cluster end |
#dns_endpoint ⇒ Boolean Also known as: dns_endpoint?
Optional. If set, the cluster will be accessed using the DNS endpoint. Note
that both dns_endpoint and internal_ip cannot be set to true.
Corresponds to the JSON property dnsEndpoint
2934 2935 2936 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2934 def dns_endpoint @dns_endpoint end |
#internal_ip ⇒ Boolean Also known as: internal_ip?
Optional. If true, cluster is accessed using the private IP address of the
control plane endpoint. Otherwise, the default IP address of the control plane
endpoint is used. The default IP address is the private IP address for
clusters with private control-plane endpoints and the public IP address
otherwise. Only specify this option when cluster is a private GKE cluster. Note that internal_ip and dns_endpoint cannot both be set to
true.
Corresponds to the JSON property internalIp
2947 2948 2949 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2947 def internal_ip @internal_ip end |
#proxy_url ⇒ String
Optional. If set, used to configure a proxy to the
Kubernetes server.
Corresponds to the JSON property proxyUrl
2955 2956 2957 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2955 def proxy_url @proxy_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2962 2963 2964 2965 2966 2967 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2962 def update!(**args) @cluster = args[:cluster] if args.key?(:cluster) @dns_endpoint = args[:dns_endpoint] if args.key?(:dns_endpoint) @internal_ip = args[:internal_ip] if args.key?(:internal_ip) @proxy_url = args[:proxy_url] if args.key?(:proxy_url) end |