Class: Google::Apis::ClouddeployV1::JobRun
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::JobRun
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
A JobRun resource in the Cloud Deploy API. A JobRun contains information
of a single Rollout job evaluation.
Instance Attribute Summary collapse
-
#advance_child_rollout_job_run ⇒ Google::Apis::ClouddeployV1::AdvanceChildRolloutJobRun
AdvanceChildRolloutJobRun contains information specific to a advanceChildRollout
JobRun. -
#analysis_job_run ⇒ Google::Apis::ClouddeployV1::AnalysisJobRun
AnalysisJobRun contains information specific to an analysis
JobRun. -
#create_child_rollout_job_run ⇒ Google::Apis::ClouddeployV1::CreateChildRolloutJobRun
CreateChildRolloutJobRun contains information specific to a createChildRollout
JobRun. -
#create_time ⇒ String
Output only.
-
#deploy_job_run ⇒ Google::Apis::ClouddeployV1::DeployJobRun
DeployJobRun contains information specific to a deploy
JobRun. -
#end_time ⇒ String
Output only.
-
#etag ⇒ String
Output only.
-
#job_id ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#phase_id ⇒ String
Output only.
-
#postdeploy_job_run ⇒ Google::Apis::ClouddeployV1::PostdeployJobRun
PostdeployJobRun contains information specific to a postdeploy
JobRun. -
#predeploy_job_run ⇒ Google::Apis::ClouddeployV1::PredeployJobRun
PredeployJobRun contains information specific to a predeploy
JobRun. -
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#verify_job_run ⇒ Google::Apis::ClouddeployV1::VerifyJobRun
VerifyJobRun contains information specific to a verify
JobRun.
Instance Method Summary collapse
-
#initialize(**args) ⇒ JobRun
constructor
A new instance of JobRun.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ JobRun
Returns a new instance of JobRun.
3207 3208 3209 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3207 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advance_child_rollout_job_run ⇒ Google::Apis::ClouddeployV1::AdvanceChildRolloutJobRun
AdvanceChildRolloutJobRun contains information specific to a
advanceChildRollout JobRun.
Corresponds to the JSON property advanceChildRolloutJobRun
3125 3126 3127 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3125 def advance_child_rollout_job_run @advance_child_rollout_job_run end |
#analysis_job_run ⇒ Google::Apis::ClouddeployV1::AnalysisJobRun
AnalysisJobRun contains information specific to an analysis JobRun.
Corresponds to the JSON property analysisJobRun
3130 3131 3132 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3130 def analysis_job_run @analysis_job_run end |
#create_child_rollout_job_run ⇒ Google::Apis::ClouddeployV1::CreateChildRolloutJobRun
CreateChildRolloutJobRun contains information specific to a createChildRollout
JobRun.
Corresponds to the JSON property createChildRolloutJobRun
3136 3137 3138 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3136 def create_child_rollout_job_run @create_child_rollout_job_run end |
#create_time ⇒ String
Output only. Time at which the JobRun was created.
Corresponds to the JSON property createTime
3141 3142 3143 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3141 def create_time @create_time end |
#deploy_job_run ⇒ Google::Apis::ClouddeployV1::DeployJobRun
DeployJobRun contains information specific to a deploy JobRun.
Corresponds to the JSON property deployJobRun
3146 3147 3148 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3146 def deploy_job_run @deploy_job_run end |
#end_time ⇒ String
Output only. Time at which the JobRun ended.
Corresponds to the JSON property endTime
3151 3152 3153 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3151 def end_time @end_time end |
#etag ⇒ String
Output only. This checksum is computed by the server based on the value of
other fields, and may be sent on update and delete requests to ensure the
client has an up-to-date value before proceeding.
Corresponds to the JSON property etag
3158 3159 3160 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3158 def etag @etag end |
#job_id ⇒ String
Output only. ID of the Rollout job this JobRun corresponds to.
Corresponds to the JSON property jobId
3163 3164 3165 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3163 def job_id @job_id end |
#name ⇒ String
Output only. Name of the JobRun. Format is projects/project/locations/
location/deliveryPipelines/deliveryPipeline/releases/releases/rollouts/
rollouts/jobRuns/uuid`.
Corresponds to the JSON propertyname`
3170 3171 3172 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3170 def name @name end |
#phase_id ⇒ String
Output only. ID of the Rollout phase this JobRun belongs in.
Corresponds to the JSON property phaseId
3175 3176 3177 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3175 def phase_id @phase_id end |
#postdeploy_job_run ⇒ Google::Apis::ClouddeployV1::PostdeployJobRun
PostdeployJobRun contains information specific to a postdeploy JobRun.
Corresponds to the JSON property postdeployJobRun
3180 3181 3182 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3180 def postdeploy_job_run @postdeploy_job_run end |
#predeploy_job_run ⇒ Google::Apis::ClouddeployV1::PredeployJobRun
PredeployJobRun contains information specific to a predeploy JobRun.
Corresponds to the JSON property predeployJobRun
3185 3186 3187 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3185 def predeploy_job_run @predeploy_job_run end |
#start_time ⇒ String
Output only. Time at which the JobRun was started.
Corresponds to the JSON property startTime
3190 3191 3192 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3190 def start_time @start_time end |
#state ⇒ String
Output only. The current state of the JobRun.
Corresponds to the JSON property state
3195 3196 3197 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3195 def state @state end |
#uid ⇒ String
Output only. Unique identifier of the JobRun.
Corresponds to the JSON property uid
3200 3201 3202 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3200 def uid @uid end |
#verify_job_run ⇒ Google::Apis::ClouddeployV1::VerifyJobRun
VerifyJobRun contains information specific to a verify JobRun.
Corresponds to the JSON property verifyJobRun
3205 3206 3207 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3205 def verify_job_run @verify_job_run end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3212 3213 3214 3215 3216 3217 3218 3219 3220 3221 3222 3223 3224 3225 3226 3227 3228 3229 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3212 def update!(**args) @advance_child_rollout_job_run = args[:advance_child_rollout_job_run] if args.key?(:advance_child_rollout_job_run) @analysis_job_run = args[:analysis_job_run] if args.key?(:analysis_job_run) @create_child_rollout_job_run = args[:create_child_rollout_job_run] if args.key?(:create_child_rollout_job_run) @create_time = args[:create_time] if args.key?(:create_time) @deploy_job_run = args[:deploy_job_run] if args.key?(:deploy_job_run) @end_time = args[:end_time] if args.key?(:end_time) @etag = args[:etag] if args.key?(:etag) @job_id = args[:job_id] if args.key?(:job_id) @name = args[:name] if args.key?(:name) @phase_id = args[:phase_id] if args.key?(:phase_id) @postdeploy_job_run = args[:postdeploy_job_run] if args.key?(:postdeploy_job_run) @predeploy_job_run = args[:predeploy_job_run] if args.key?(:predeploy_job_run) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) @verify_job_run = args[:verify_job_run] if args.key?(:verify_job_run) end |