Class: Google::Apis::ClouddeployV1::JobRunNotificationEvent

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

Payload proto for "clouddeploy.googleapis.com/jobrun_notification" Platform Log event that describes the failure to send JobRun resource update Pub/Sub notification.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JobRunNotificationEvent

Returns a new instance of JobRunNotificationEvent.



3276
3277
3278
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3276

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#job_runString

The name of the JobRun. Corresponds to the JSON property jobRun

Returns:

  • (String)


3234
3235
3236
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3234

def job_run
  @job_run
end

#messageString

Debug message for when a notification fails to send. Corresponds to the JSON property message

Returns:

  • (String)


3239
3240
3241
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3239

def message
  @message
end

#pipeline_uidString

Unique identifier of the DeliveryPipeline. Corresponds to the JSON property pipelineUid

Returns:

  • (String)


3244
3245
3246
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3244

def pipeline_uid
  @pipeline_uid
end

#releaseString

The name of the Release. Corresponds to the JSON property release

Returns:

  • (String)


3249
3250
3251
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3249

def release
  @release
end

#release_uidString

Unique identifier of the Release. Corresponds to the JSON property releaseUid

Returns:

  • (String)


3254
3255
3256
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3254

def release_uid
  @release_uid
end

#rolloutString

The name of the Rollout. Corresponds to the JSON property rollout

Returns:

  • (String)


3259
3260
3261
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3259

def rollout
  @rollout
end

#rollout_uidString

Unique identifier of the Rollout. Corresponds to the JSON property rolloutUid

Returns:

  • (String)


3264
3265
3266
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3264

def rollout_uid
  @rollout_uid
end

#target_idString

ID of the Target. Corresponds to the JSON property targetId

Returns:

  • (String)


3269
3270
3271
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3269

def target_id
  @target_id
end

#typeString

Type of this notification, e.g. for a Pub/Sub failure. Corresponds to the JSON property type

Returns:

  • (String)


3274
3275
3276
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3274

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3281
3282
3283
3284
3285
3286
3287
3288
3289
3290
3291
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3281

def update!(**args)
  @job_run = args[:job_run] if args.key?(:job_run)
  @message = args[:message] if args.key?(:message)
  @pipeline_uid = args[:pipeline_uid] if args.key?(:pipeline_uid)
  @release = args[:release] if args.key?(:release)
  @release_uid = args[:release_uid] if args.key?(:release_uid)
  @rollout = args[:rollout] if args.key?(:rollout)
  @rollout_uid = args[:rollout_uid] if args.key?(:rollout_uid)
  @target_id = args[:target_id] if args.key?(:target_id)
  @type = args[:type] if args.key?(:type)
end