Class: Google::Apis::ClouddeployV1::KubernetesRenderMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

KubernetesRenderMetadata contains Kubernetes information associated with a Release render.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ KubernetesRenderMetadata

Returns a new instance of KubernetesRenderMetadata.



3350
3351
3352
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3350

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#canary_deploymentString

Output only. Name of the canary version of the Kubernetes Deployment that will be applied to the GKE cluster. Only set if a canary deployment strategy was configured. Corresponds to the JSON property canaryDeployment

Returns:

  • (String)


3336
3337
3338
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3336

def canary_deployment
  @canary_deployment
end

#deploymentString

Output only. Name of the Kubernetes Deployment that will be applied to the GKE cluster. Only set if a single Deployment was provided in the rendered manifest. Corresponds to the JSON property deployment

Returns:

  • (String)


3342
3343
3344
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3342

def deployment
  @deployment
end

#kubernetes_namespaceString

Output only. Namespace the Kubernetes resources will be applied to in the GKE cluster. Only set if applying resources to a single namespace. Corresponds to the JSON property kubernetesNamespace

Returns:

  • (String)


3348
3349
3350
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3348

def kubernetes_namespace
  @kubernetes_namespace
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3355
3356
3357
3358
3359
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3355

def update!(**args)
  @canary_deployment = args[:canary_deployment] if args.key?(:canary_deployment)
  @deployment = args[:deployment] if args.key?(:deployment)
  @kubernetes_namespace = args[:kubernetes_namespace] if args.key?(:kubernetes_namespace)
end