Class: Google::Apis::ClouddeployV1::ListOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

The response message for Operations.ListOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListOperationsResponse

Returns a new instance of ListOperationsResponse.



3081
3082
3083
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3081

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The standard List next-page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3066
3067
3068
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3066

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::ClouddeployV1::Operation>

A list of operations that matches the specified filter in the request. Corresponds to the JSON property operations



3071
3072
3073
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3071

def operations
  @operations
end

#unreachableArray<String>

Unordered list. Unreachable resources. Populated when the request sets ListOperationsRequest.return_partial_success and reads across collections. For example, when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3079
3080
3081
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3079

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3086
3087
3088
3089
3090
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3086

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end