Class: Google::Apis::ClouddeployV1::Phase

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

Phase represents a collection of jobs that are logically grouped together for a Rollout.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Phase

Returns a new instance of Phase.



3494
3495
3496
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3494

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#child_rollout_jobsGoogle::Apis::ClouddeployV1::ChildRolloutJobs

ChildRollouts job composition Corresponds to the JSON property childRolloutJobs



3472
3473
3474
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3472

def child_rollout_jobs
  @child_rollout_jobs
end

#deployment_jobsGoogle::Apis::ClouddeployV1::DeploymentJobs

Deployment job composition. Corresponds to the JSON property deploymentJobs



3477
3478
3479
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3477

def deployment_jobs
  @deployment_jobs
end

#idString

Output only. The ID of the Phase. Corresponds to the JSON property id

Returns:

  • (String)


3482
3483
3484
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3482

def id
  @id
end

#skip_messageString

Output only. Additional information on why the Phase was skipped, if available. Corresponds to the JSON property skipMessage

Returns:

  • (String)


3487
3488
3489
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3487

def skip_message
  @skip_message
end

#stateString

Output only. Current state of the Phase. Corresponds to the JSON property state

Returns:

  • (String)


3492
3493
3494
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3492

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3499
3500
3501
3502
3503
3504
3505
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3499

def update!(**args)
  @child_rollout_jobs = args[:child_rollout_jobs] if args.key?(:child_rollout_jobs)
  @deployment_jobs = args[:deployment_jobs] if args.key?(:deployment_jobs)
  @id = args[:id] if args.key?(:id)
  @skip_message = args[:skip_message] if args.key?(:skip_message)
  @state = args[:state] if args.key?(:state)
end