Class: Google::Apis::ClouddeployV1::PipelineCondition

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

PipelineCondition contains all conditions relevant to a Delivery Pipeline.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PipelineCondition

Returns a new instance of PipelineCondition.



4145
4146
4147
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4145

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pipeline_ready_conditionGoogle::Apis::ClouddeployV1::PipelineReadyCondition

PipelineReadyCondition contains information around the status of the Pipeline. Corresponds to the JSON property pipelineReadyCondition



4131
4132
4133
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4131

def pipeline_ready_condition
  @pipeline_ready_condition
end

#targets_present_conditionGoogle::Apis::ClouddeployV1::TargetsPresentCondition

TargetsPresentCondition contains information on any Targets referenced in the Delivery Pipeline that do not actually exist. Corresponds to the JSON property targetsPresentCondition



4137
4138
4139
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4137

def targets_present_condition
  @targets_present_condition
end

#targets_type_conditionGoogle::Apis::ClouddeployV1::TargetsTypeCondition

TargetsTypeCondition contains information on whether the Targets defined in the Delivery Pipeline are of the same type. Corresponds to the JSON property targetsTypeCondition



4143
4144
4145
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4143

def targets_type_condition
  @targets_type_condition
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4150
4151
4152
4153
4154
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4150

def update!(**args)
  @pipeline_ready_condition = args[:pipeline_ready_condition] if args.key?(:pipeline_ready_condition)
  @targets_present_condition = args[:targets_present_condition] if args.key?(:targets_present_condition)
  @targets_type_condition = args[:targets_type_condition] if args.key?(:targets_type_condition)
end