Class: Google::Apis::ClouddeployV1::PolicyViolation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

Returned from an action if one or more policies were violated, and therefore the action was prevented. Contains information about what policies were violated and why.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PolicyViolation

Returns a new instance of PolicyViolation.



4318
4319
4320
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4318

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#policy_violation_detailsArray<Google::Apis::ClouddeployV1::PolicyViolationDetails>

Policy violation details. Corresponds to the JSON property policyViolationDetails



4316
4317
4318
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4316

def policy_violation_details
  @policy_violation_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4323
4324
4325
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4323

def update!(**args)
  @policy_violation_details = args[:policy_violation_details] if args.key?(:policy_violation_details)
end