Class: Google::Apis::ClouddeployV1::PostdeployJobRun
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::PostdeployJobRun
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
PostdeployJobRun contains information specific to a postdeploy JobRun.
Instance Attribute Summary collapse
-
#build ⇒ String
Output only.
-
#failure_cause ⇒ String
Output only.
-
#failure_message ⇒ String
Output only.
-
#metadata ⇒ Google::Apis::ClouddeployV1::PostdeployJobRunMetadata
PostdeployJobRunMetadata contains metadata about the postdeploy
JobRun.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PostdeployJobRun
constructor
A new instance of PostdeployJobRun.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PostdeployJobRun
Returns a new instance of PostdeployJobRun.
4441 4442 4443 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4441 def initialize(**args) update!(**args) end |
Instance Attribute Details
#build ⇒ String
Output only. The resource name of the Cloud Build Build object that is used
to execute the custom actions associated with the postdeploy Job. Format is
projects/project/locations/location/builds/build`.
Corresponds to the JSON propertybuild`
4423 4424 4425 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4423 def build @build end |
#failure_cause ⇒ String
Output only. The reason the postdeploy failed. This will always be unspecified
while the postdeploy is in progress or if it succeeded.
Corresponds to the JSON property failureCause
4429 4430 4431 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4429 def failure_cause @failure_cause end |
#failure_message ⇒ String
Output only. Additional information about the postdeploy failure, if available.
Corresponds to the JSON property failureMessage
4434 4435 4436 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4434 def @failure_message end |
#metadata ⇒ Google::Apis::ClouddeployV1::PostdeployJobRunMetadata
PostdeployJobRunMetadata contains metadata about the postdeploy JobRun.
Corresponds to the JSON property metadata
4439 4440 4441 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4439 def @metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4446 4447 4448 4449 4450 4451 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4446 def update!(**args) @build = args[:build] if args.key?(:build) @failure_cause = args[:failure_cause] if args.key?(:failure_cause) @failure_message = args[:failure_message] if args.key?(:failure_message) @metadata = args[:metadata] if args.key?(:metadata) end |