Class: Google::Apis::ClouddeployV1::Predeploy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

Predeploy contains the predeploy job configuration information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Predeploy

Returns a new instance of Predeploy.



4490
4491
4492
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4490

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionsArray<String>

Optional. A sequence of Skaffold custom actions to invoke during execution of the predeploy job. Corresponds to the JSON property actions

Returns:

  • (Array<String>)


4481
4482
4483
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4481

def actions
  @actions
end

#tasksArray<Google::Apis::ClouddeployV1::Task>

Optional. The tasks that will run as a part of the predeploy job. The tasks are executed sequentially in the order specified. Only one of actions or tasks can be specified. Corresponds to the JSON property tasks



4488
4489
4490
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4488

def tasks
  @tasks
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4495
4496
4497
4498
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4495

def update!(**args)
  @actions = args[:actions] if args.key?(:actions)
  @tasks = args[:tasks] if args.key?(:tasks)
end