Class: Google::Apis::ClouddeployV1::ReleaseCondition

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

ReleaseCondition contains all conditions relevant to a Release.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReleaseCondition

Returns a new instance of ReleaseCondition.



4935
4936
4937
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4935

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#docker_version_supported_conditionGoogle::Apis::ClouddeployV1::ToolVersionSupportedCondition

ToolVersionSupportedCondition contains information about when support for the release's version of a tool ends. Corresponds to the JSON property dockerVersionSupportedCondition



4891
4892
4893
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4891

def docker_version_supported_condition
  @docker_version_supported_condition
end

#helm_version_supported_conditionGoogle::Apis::ClouddeployV1::ToolVersionSupportedCondition

ToolVersionSupportedCondition contains information about when support for the release's version of a tool ends. Corresponds to the JSON property helmVersionSupportedCondition



4897
4898
4899
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4897

def helm_version_supported_condition
  @helm_version_supported_condition
end

#kpt_version_supported_conditionGoogle::Apis::ClouddeployV1::ToolVersionSupportedCondition

ToolVersionSupportedCondition contains information about when support for the release's version of a tool ends. Corresponds to the JSON property kptVersionSupportedCondition



4903
4904
4905
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4903

def kpt_version_supported_condition
  @kpt_version_supported_condition
end

#kubectl_version_supported_conditionGoogle::Apis::ClouddeployV1::ToolVersionSupportedCondition

ToolVersionSupportedCondition contains information about when support for the release's version of a tool ends. Corresponds to the JSON property kubectlVersionSupportedCondition



4909
4910
4911
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4909

def kubectl_version_supported_condition
  @kubectl_version_supported_condition
end

#kustomize_version_supported_conditionGoogle::Apis::ClouddeployV1::ToolVersionSupportedCondition

ToolVersionSupportedCondition contains information about when support for the release's version of a tool ends. Corresponds to the JSON property kustomizeVersionSupportedCondition



4915
4916
4917
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4915

def kustomize_version_supported_condition
  @kustomize_version_supported_condition
end

#release_ready_conditionGoogle::Apis::ClouddeployV1::ReleaseReadyCondition

ReleaseReadyCondition contains information around the status of the Release. If a release is not ready, you cannot create a rollout with the release. Corresponds to the JSON property releaseReadyCondition



4921
4922
4923
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4921

def release_ready_condition
  @release_ready_condition
end

#skaffold_supported_conditionGoogle::Apis::ClouddeployV1::SkaffoldSupportedCondition

SkaffoldSupportedCondition contains information about when support for the release's version of Skaffold ends. Corresponds to the JSON property skaffoldSupportedCondition



4927
4928
4929
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4927

def skaffold_supported_condition
  @skaffold_supported_condition
end

#skaffold_version_supported_conditionGoogle::Apis::ClouddeployV1::ToolVersionSupportedCondition

ToolVersionSupportedCondition contains information about when support for the release's version of a tool ends. Corresponds to the JSON property skaffoldVersionSupportedCondition



4933
4934
4935
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4933

def skaffold_version_supported_condition
  @skaffold_version_supported_condition
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4940
4941
4942
4943
4944
4945
4946
4947
4948
4949
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4940

def update!(**args)
  @docker_version_supported_condition = args[:docker_version_supported_condition] if args.key?(:docker_version_supported_condition)
  @helm_version_supported_condition = args[:helm_version_supported_condition] if args.key?(:helm_version_supported_condition)
  @kpt_version_supported_condition = args[:kpt_version_supported_condition] if args.key?(:kpt_version_supported_condition)
  @kubectl_version_supported_condition = args[:kubectl_version_supported_condition] if args.key?(:kubectl_version_supported_condition)
  @kustomize_version_supported_condition = args[:kustomize_version_supported_condition] if args.key?(:kustomize_version_supported_condition)
  @release_ready_condition = args[:release_ready_condition] if args.key?(:release_ready_condition)
  @skaffold_supported_condition = args[:skaffold_supported_condition] if args.key?(:skaffold_supported_condition)
  @skaffold_version_supported_condition = args[:skaffold_version_supported_condition] if args.key?(:skaffold_version_supported_condition)
end