Class: Google::Apis::ClouddeployV1::ReleaseNotificationEvent
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::ReleaseNotificationEvent
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
Payload proto for "clouddeploy.googleapis.com/release_notification" Platform Log event that describes the failure to send release status change Pub/Sub notification.
Instance Attribute Summary collapse
-
#message ⇒ String
Debug message for when a notification fails to send.
-
#pipeline_uid ⇒ String
Unique identifier of the
DeliveryPipeline. -
#release ⇒ String
The name of the
Release. -
#release_uid ⇒ String
Unique identifier of the
Release. -
#type ⇒ String
Type of this notification, e.g.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReleaseNotificationEvent
constructor
A new instance of ReleaseNotificationEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReleaseNotificationEvent
Returns a new instance of ReleaseNotificationEvent.
4372 4373 4374 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4372 def initialize(**args) update!(**args) end |
Instance Attribute Details
#message ⇒ String
Debug message for when a notification fails to send.
Corresponds to the JSON property message
4350 4351 4352 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4350 def @message end |
#pipeline_uid ⇒ String
Unique identifier of the DeliveryPipeline.
Corresponds to the JSON property pipelineUid
4355 4356 4357 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4355 def pipeline_uid @pipeline_uid end |
#release ⇒ String
The name of the Release.
Corresponds to the JSON property release
4360 4361 4362 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4360 def release @release end |
#release_uid ⇒ String
Unique identifier of the Release.
Corresponds to the JSON property releaseUid
4365 4366 4367 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4365 def release_uid @release_uid end |
#type ⇒ String
Type of this notification, e.g. for a Pub/Sub failure.
Corresponds to the JSON property type
4370 4371 4372 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4370 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4377 4378 4379 4380 4381 4382 4383 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4377 def update!(**args) @message = args[:message] if args.key?(:message) @pipeline_uid = args[:pipeline_uid] if args.key?(:pipeline_uid) @release = args[:release] if args.key?(:release) @release_uid = args[:release_uid] if args.key?(:release_uid) @type = args[:type] if args.key?(:type) end |