Class: Google::Apis::ClouddeployV1::RenderMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

RenderMetadata includes information associated with a Release render.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RenderMetadata

Returns a new instance of RenderMetadata.



5089
5090
5091
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5089

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_runGoogle::Apis::ClouddeployV1::CloudRunRenderMetadata

CloudRunRenderMetadata contains Cloud Run information associated with a Release render. Corresponds to the JSON property cloudRun



5076
5077
5078
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5076

def cloud_run
  @cloud_run
end

#customGoogle::Apis::ClouddeployV1::CustomMetadata

CustomMetadata contains information from a user-defined operation. Corresponds to the JSON property custom



5081
5082
5083
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5081

def custom
  @custom
end

#kubernetesGoogle::Apis::ClouddeployV1::KubernetesRenderMetadata

KubernetesRenderMetadata contains Kubernetes information associated with a Release render. Corresponds to the JSON property kubernetes



5087
5088
5089
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5087

def kubernetes
  @kubernetes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5094
5095
5096
5097
5098
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5094

def update!(**args)
  @cloud_run = args[:cloud_run] if args.key?(:cloud_run)
  @custom = args[:custom] if args.key?(:custom)
  @kubernetes = args[:kubernetes] if args.key?(:kubernetes)
end