Class: Google::Apis::ClouddeployV1::RepairRolloutOperation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

Contains the information for an automated repair rollout operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RepairRolloutOperation

Returns a new instance of RepairRolloutOperation.



5183
5184
5185
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5183

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_repair_phase_indexFixnum

Output only. The index of the current repair action in the repair sequence. Corresponds to the JSON property currentRepairPhaseIndex

Returns:

  • (Fixnum)


5160
5161
5162
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5160

def current_repair_phase_index
  @current_repair_phase_index
end

#job_idString

Output only. The job ID for the Job to repair. Corresponds to the JSON property jobId

Returns:

  • (String)


5165
5166
5167
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5165

def job_id
  @job_id
end

#phase_idString

Output only. The phase ID of the phase that includes the job being repaired. Corresponds to the JSON property phaseId

Returns:

  • (String)


5170
5171
5172
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5170

def phase_id
  @phase_id
end

#repair_phasesArray<Google::Apis::ClouddeployV1::RepairPhase>

Output only. Records of the repair attempts. Each repair phase may have multiple retry attempts or single rollback attempt. Corresponds to the JSON property repairPhases



5176
5177
5178
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5176

def repair_phases
  @repair_phases
end

#rolloutString

Output only. The name of the rollout that initiates the AutomationRun. Corresponds to the JSON property rollout

Returns:

  • (String)


5181
5182
5183
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5181

def rollout
  @rollout
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5188
5189
5190
5191
5192
5193
5194
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5188

def update!(**args)
  @current_repair_phase_index = args[:current_repair_phase_index] if args.key?(:current_repair_phase_index)
  @job_id = args[:job_id] if args.key?(:job_id)
  @phase_id = args[:phase_id] if args.key?(:phase_id)
  @repair_phases = args[:repair_phases] if args.key?(:repair_phases)
  @rollout = args[:rollout] if args.key?(:rollout)
end