Class: Google::Apis::ClouddeployV1::RolloutNotificationEvent
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::RolloutNotificationEvent
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
Payload proto for "clouddeploy.googleapis.com/rollout_notification" Platform Log event that describes the failure to send rollout status change Pub/Sub notification.
Instance Attribute Summary collapse
-
#message ⇒ String
Debug message for when a notification fails to send.
-
#pipeline_uid ⇒ String
Unique identifier of the
DeliveryPipeline. -
#release ⇒ String
The name of the
Release. -
#release_uid ⇒ String
Unique identifier of the
Release. -
#rollout ⇒ String
The name of the
Rollout. -
#rollout_uid ⇒ String
Unique identifier of the
Rollout. -
#target_id ⇒ String
ID of the
Targetthat the rollout is deployed to. -
#type ⇒ String
Type of this notification, e.g.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutNotificationEvent
constructor
A new instance of RolloutNotificationEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutNotificationEvent
Returns a new instance of RolloutNotificationEvent.
5199 5200 5201 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5199 def initialize(**args) update!(**args) end |
Instance Attribute Details
#message ⇒ String
Debug message for when a notification fails to send.
Corresponds to the JSON property message
5162 5163 5164 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5162 def @message end |
#pipeline_uid ⇒ String
Unique identifier of the DeliveryPipeline.
Corresponds to the JSON property pipelineUid
5167 5168 5169 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5167 def pipeline_uid @pipeline_uid end |
#release ⇒ String
The name of the Release.
Corresponds to the JSON property release
5172 5173 5174 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5172 def release @release end |
#release_uid ⇒ String
Unique identifier of the Release.
Corresponds to the JSON property releaseUid
5177 5178 5179 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5177 def release_uid @release_uid end |
#rollout ⇒ String
The name of the Rollout.
Corresponds to the JSON property rollout
5182 5183 5184 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5182 def rollout @rollout end |
#rollout_uid ⇒ String
Unique identifier of the Rollout.
Corresponds to the JSON property rolloutUid
5187 5188 5189 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5187 def rollout_uid @rollout_uid end |
#target_id ⇒ String
ID of the Target that the rollout is deployed to.
Corresponds to the JSON property targetId
5192 5193 5194 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5192 def target_id @target_id end |
#type ⇒ String
Type of this notification, e.g. for a Pub/Sub failure.
Corresponds to the JSON property type
5197 5198 5199 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5197 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5204 5205 5206 5207 5208 5209 5210 5211 5212 5213 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5204 def update!(**args) @message = args[:message] if args.key?(:message) @pipeline_uid = args[:pipeline_uid] if args.key?(:pipeline_uid) @release = args[:release] if args.key?(:release) @release_uid = args[:release_uid] if args.key?(:release_uid) @rollout = args[:rollout] if args.key?(:rollout) @rollout_uid = args[:rollout_uid] if args.key?(:rollout_uid) @target_id = args[:target_id] if args.key?(:target_id) @type = args[:type] if args.key?(:type) end |