Class: Google::Apis::ClouddeployV1::RolloutUpdateEvent

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

Payload proto for "clouddeploy.googleapis.com/rollout_update" Platform Log event that describes the rollout update event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutUpdateEvent

Returns a new instance of RolloutUpdateEvent.



5903
5904
5905
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5903

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#messageString

Debug message for when a rollout update event occurs. Corresponds to the JSON property message

Returns:

  • (String)


5864
5865
5866
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5864

def message
  @message
end

#pipeline_uidString

Unique identifier of the pipeline. Corresponds to the JSON property pipelineUid

Returns:

  • (String)


5869
5870
5871
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5869

def pipeline_uid
  @pipeline_uid
end

#releaseString

The name of the Release. Corresponds to the JSON property release

Returns:

  • (String)


5874
5875
5876
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5874

def release
  @release
end

#release_uidString

Unique identifier of the release. Corresponds to the JSON property releaseUid

Returns:

  • (String)


5879
5880
5881
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5879

def release_uid
  @release_uid
end

#rolloutString

The name of the rollout. rollout_uid is not in this log message because we write some of these log messages at rollout creation time, before we've generated the uid. Corresponds to the JSON property rollout

Returns:

  • (String)


5886
5887
5888
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5886

def rollout
  @rollout
end

#rollout_update_typeString

The type of the rollout update. Corresponds to the JSON property rolloutUpdateType

Returns:

  • (String)


5891
5892
5893
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5891

def rollout_update_type
  @rollout_update_type
end

#target_idString

ID of the target. Corresponds to the JSON property targetId

Returns:

  • (String)


5896
5897
5898
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5896

def target_id
  @target_id
end

#typeString

Type of this notification, e.g. for a rollout update event. Corresponds to the JSON property type

Returns:

  • (String)


5901
5902
5903
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5901

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5908
5909
5910
5911
5912
5913
5914
5915
5916
5917
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5908

def update!(**args)
  @message = args[:message] if args.key?(:message)
  @pipeline_uid = args[:pipeline_uid] if args.key?(:pipeline_uid)
  @release = args[:release] if args.key?(:release)
  @release_uid = args[:release_uid] if args.key?(:release_uid)
  @rollout = args[:rollout] if args.key?(:rollout)
  @rollout_update_type = args[:rollout_update_type] if args.key?(:rollout_update_type)
  @target_id = args[:target_id] if args.key?(:target_id)
  @type = args[:type] if args.key?(:type)
end