Class: Google::Apis::ClouddeployV1::SkaffoldSupportedCondition
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::SkaffoldSupportedCondition
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
SkaffoldSupportedCondition contains information about when support for the release's version of Skaffold ends.
Instance Attribute Summary collapse
-
#maintenance_mode_time ⇒ String
The time at which this release's version of Skaffold will enter maintenance mode.
-
#skaffold_support_state ⇒ String
The Skaffold support state for this release's version of Skaffold.
-
#status ⇒ Boolean
(also: #status?)
True if the version of Skaffold used by this release is supported.
-
#support_expiration_time ⇒ String
The time at which this release's version of Skaffold will no longer be supported.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SkaffoldSupportedCondition
constructor
A new instance of SkaffoldSupportedCondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SkaffoldSupportedCondition
Returns a new instance of SkaffoldSupportedCondition.
6248 6249 6250 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6248 def initialize(**args) update!(**args) end |
Instance Attribute Details
#maintenance_mode_time ⇒ String
The time at which this release's version of Skaffold will enter maintenance
mode.
Corresponds to the JSON property maintenanceModeTime
6229 6230 6231 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6229 def maintenance_mode_time @maintenance_mode_time end |
#skaffold_support_state ⇒ String
The Skaffold support state for this release's version of Skaffold.
Corresponds to the JSON property skaffoldSupportState
6234 6235 6236 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6234 def skaffold_support_state @skaffold_support_state end |
#status ⇒ Boolean Also known as: status?
True if the version of Skaffold used by this release is supported.
Corresponds to the JSON property status
6239 6240 6241 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6239 def status @status end |
#support_expiration_time ⇒ String
The time at which this release's version of Skaffold will no longer be
supported.
Corresponds to the JSON property supportExpirationTime
6246 6247 6248 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6246 def support_expiration_time @support_expiration_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6253 6254 6255 6256 6257 6258 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6253 def update!(**args) @maintenance_mode_time = args[:maintenance_mode_time] if args.key?(:maintenance_mode_time) @skaffold_support_state = args[:skaffold_support_state] if args.key?(:skaffold_support_state) @status = args[:status] if args.key?(:status) @support_expiration_time = args[:support_expiration_time] if args.key?(:support_expiration_time) end |