Class: Google::Apis::ClouddeployV1::Stage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

Stage specifies a location to which to deploy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Stage

Returns a new instance of Stage.



6334
6335
6336
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6334

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deploy_parametersArray<Google::Apis::ClouddeployV1::DeployParameters>

Optional. The deploy parameters to use for the target in this stage. Corresponds to the JSON property deployParameters



6312
6313
6314
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6312

def deploy_parameters
  @deploy_parameters
end

#profilesArray<String>

Optional. Skaffold profiles to use when rendering the manifest for this stage' s Target. Corresponds to the JSON property profiles

Returns:

  • (Array<String>)


6318
6319
6320
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6318

def profiles
  @profiles
end

#strategyGoogle::Apis::ClouddeployV1::Strategy

Strategy contains deployment strategy information. Corresponds to the JSON property strategy



6323
6324
6325
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6323

def strategy
  @strategy
end

#target_idString

Optional. The target_id to which this stage points. This field refers exclusively to the last segment of a target name. For example, this field would just be my-target (rather than projects/project/locations/location/ targets/my-target). The location of the Target is inferred to be the same as the location of the DeliveryPipeline that contains this Stage. Corresponds to the JSON property targetId

Returns:

  • (String)


6332
6333
6334
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6332

def target_id
  @target_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6339
6340
6341
6342
6343
6344
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6339

def update!(**args)
  @deploy_parameters = args[:deploy_parameters] if args.key?(:deploy_parameters)
  @profiles = args[:profiles] if args.key?(:profiles)
  @strategy = args[:strategy] if args.key?(:strategy)
  @target_id = args[:target_id] if args.key?(:target_id)
end