Class: Google::Apis::ClouddeployV1::Target

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

A Target resource in the Cloud Deploy API. A Target defines a location to which a Skaffold configuration can be deployed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Target

Returns a new instance of Target.



6576
6577
6578
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6576

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. User annotations. These attributes can only be set and used by the user, and not by Cloud Deploy. See https://google.aip.dev/128#annotations for more details such as format and size limitations. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


6466
6467
6468
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6466

def annotations
  @annotations
end

#anthos_clusterGoogle::Apis::ClouddeployV1::AnthosCluster

Information specifying an Anthos Cluster. Corresponds to the JSON property anthosCluster



6471
6472
6473
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6471

def anthos_cluster
  @anthos_cluster
end

#associated_entitiesHash<String,Google::Apis::ClouddeployV1::AssociatedEntities>

Optional. Map of entity IDs to their associated entities. Associated entities allows specifying places other than the deployment target for specific features. For example, the Gateway API canary can be configured to deploy the HTTPRoute to a different cluster(s) than the deployment cluster using associated entities. An entity ID must consist of lower-case letters, numbers, and hyphens, start with a letter and end with a letter or a number, and have a max length of 63 characters. In other words, it must match the following regex: ^[a-z]([a-z0-9-]0,61[a-z0-9])?$. Corresponds to the JSON property associatedEntities



6483
6484
6485
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6483

def associated_entities
  @associated_entities
end

#create_timeString

Output only. Time at which the Target was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6488
6489
6490
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6488

def create_time
  @create_time
end

#custom_targetGoogle::Apis::ClouddeployV1::CustomTarget

Information specifying a Custom Target. Corresponds to the JSON property customTarget



6493
6494
6495
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6493

def custom_target
  @custom_target
end

#deploy_parametersHash<String,String>

Optional. The deploy parameters to use for this target. Corresponds to the JSON property deployParameters

Returns:

  • (Hash<String,String>)


6498
6499
6500
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6498

def deploy_parameters
  @deploy_parameters
end

#descriptionString

Optional. Description of the Target. Max length is 255 characters. Corresponds to the JSON property description

Returns:

  • (String)


6503
6504
6505
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6503

def description
  @description
end

#etagString

Optional. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


6510
6511
6512
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6510

def etag
  @etag
end

#execution_configsArray<Google::Apis::ClouddeployV1::ExecutionConfig>

Optional. Configurations for all execution that relates to this Target. Each ExecutionEnvironmentUsage value may only be used in a single configuration; using the same value multiple times is an error. When one or more configurations are specified, they must include the RENDER and DEPLOY ExecutionEnvironmentUsage values. When no configurations are specified, execution will use the default specified in DefaultPool. Corresponds to the JSON property executionConfigs



6520
6521
6522
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6520

def execution_configs
  @execution_configs
end

#gkeGoogle::Apis::ClouddeployV1::GkeCluster

Information specifying a GKE Cluster. Corresponds to the JSON property gke



6525
6526
6527
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6525

def gke
  @gke
end

#labelsHash<String,String>

Optional. Labels are attributes that can be set and used by both the user and by Cloud Deploy. Labels must meet the following constraints: * Keys and values can contain only lowercase letters, numeric characters, underscores, and dashes. * All characters must use UTF-8 encoding, and international characters are allowed. * Keys must start with a lowercase letter or international character. * Each resource is limited to a maximum of 64 labels. Both keys and values are additionally constrained to be <= 128 bytes. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


6536
6537
6538
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6536

def labels
  @labels
end

#multi_targetGoogle::Apis::ClouddeployV1::MultiTarget

Information specifying a multiTarget. Corresponds to the JSON property multiTarget



6541
6542
6543
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6541

def multi_target
  @multi_target
end

#nameString

Identifier. Name of the Target. Format is projects/project/locations/ location/targets/target`. Thetargetcomponent must matcha-z? Corresponds to the JSON propertyname`

Returns:

  • (String)


6548
6549
6550
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6548

def name
  @name
end

#require_approvalBoolean Also known as: require_approval?

Optional. Whether or not the Target requires approval. Corresponds to the JSON property requireApproval

Returns:

  • (Boolean)


6553
6554
6555
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6553

def require_approval
  @require_approval
end

#runGoogle::Apis::ClouddeployV1::CloudRunLocation

Information specifying where to deploy a Cloud Run Service. Corresponds to the JSON property run



6559
6560
6561
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6559

def run
  @run
end

#target_idString

Output only. Resource id of the Target. Corresponds to the JSON property targetId

Returns:

  • (String)


6564
6565
6566
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6564

def target_id
  @target_id
end

#uidString

Output only. Unique identifier of the Target. Corresponds to the JSON property uid

Returns:

  • (String)


6569
6570
6571
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6569

def uid
  @uid
end

#update_timeString

Output only. Most recent time at which the Target was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


6574
6575
6576
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6574

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6581
6582
6583
6584
6585
6586
6587
6588
6589
6590
6591
6592
6593
6594
6595
6596
6597
6598
6599
6600
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6581

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @anthos_cluster = args[:anthos_cluster] if args.key?(:anthos_cluster)
  @associated_entities = args[:associated_entities] if args.key?(:associated_entities)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_target = args[:custom_target] if args.key?(:custom_target)
  @deploy_parameters = args[:deploy_parameters] if args.key?(:deploy_parameters)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @execution_configs = args[:execution_configs] if args.key?(:execution_configs)
  @gke = args[:gke] if args.key?(:gke)
  @labels = args[:labels] if args.key?(:labels)
  @multi_target = args[:multi_target] if args.key?(:multi_target)
  @name = args[:name] if args.key?(:name)
  @require_approval = args[:require_approval] if args.key?(:require_approval)
  @run = args[:run] if args.key?(:run)
  @target_id = args[:target_id] if args.key?(:target_id)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end