Class: Google::Apis::ClouddeployV1::TargetArtifact

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

The artifacts produced by a target render operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetArtifact

Returns a new instance of TargetArtifact.



6020
6021
6022
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6020

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_uriString

Output only. URI of a directory containing the artifacts. This contains deployment configuration used by Skaffold during a rollout, and all paths are relative to this location. Corresponds to the JSON property artifactUri

Returns:

  • (String)


6001
6002
6003
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6001

def artifact_uri
  @artifact_uri
end

#manifest_pathString

Output only. File path of the rendered manifest relative to the URI for the stable phase. Corresponds to the JSON property manifestPath

Returns:

  • (String)


6007
6008
6009
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6007

def manifest_path
  @manifest_path
end

#phase_artifactsHash<String,Google::Apis::ClouddeployV1::PhaseArtifact>

Output only. Map from the phase ID to the phase artifacts for the Target. Corresponds to the JSON property phaseArtifacts



6012
6013
6014
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6012

def phase_artifacts
  @phase_artifacts
end

#skaffold_config_pathString

Output only. File path of the resolved Skaffold configuration for the stable phase, relative to the URI. Corresponds to the JSON property skaffoldConfigPath

Returns:

  • (String)


6018
6019
6020
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6018

def skaffold_config_path
  @skaffold_config_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6025
6026
6027
6028
6029
6030
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6025

def update!(**args)
  @artifact_uri = args[:artifact_uri] if args.key?(:artifact_uri)
  @manifest_path = args[:manifest_path] if args.key?(:manifest_path)
  @phase_artifacts = args[:phase_artifacts] if args.key?(:phase_artifacts)
  @skaffold_config_path = args[:skaffold_config_path] if args.key?(:skaffold_config_path)
end