Class: Google::Apis::ClouddeployV1::TargetsPresentCondition
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::TargetsPresentCondition
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
TargetsPresentCondition contains information on any Targets referenced in
the Delivery Pipeline that do not actually exist.
Instance Attribute Summary collapse
-
#missing_targets ⇒ Array<String>
The list of Target names that do not exist.
-
#status ⇒ Boolean
(also: #status?)
True if there aren't any missing Targets.
-
#update_time ⇒ String
Last time the condition was updated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetsPresentCondition
constructor
A new instance of TargetsPresentCondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetsPresentCondition
Returns a new instance of TargetsPresentCondition.
6791 6792 6793 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6791 def initialize(**args) update!(**args) end |
Instance Attribute Details
#missing_targets ⇒ Array<String>
The list of Target names that do not exist. For example, projects/project_id
/locations/location_name/targets/target_name`.
Corresponds to the JSON propertymissingTargets`
6778 6779 6780 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6778 def missing_targets @missing_targets end |
#status ⇒ Boolean Also known as: status?
True if there aren't any missing Targets.
Corresponds to the JSON property status
6783 6784 6785 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6783 def status @status end |
#update_time ⇒ String
Last time the condition was updated.
Corresponds to the JSON property updateTime
6789 6790 6791 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6789 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6796 6797 6798 6799 6800 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6796 def update!(**args) @missing_targets = args[:missing_targets] if args.key?(:missing_targets) @status = args[:status] if args.key?(:status) @update_time = args[:update_time] if args.key?(:update_time) end |