Class: Google::Apis::ClouddeployV1::TimedPromoteReleaseCondition

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

TimedPromoteReleaseCondition contains conditions specific to an Automation with a Timed Promote Release rule defined.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TimedPromoteReleaseCondition

Returns a new instance of TimedPromoteReleaseCondition.



7026
7027
7028
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7026

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_promotion_timeString

Output only. When the next scheduled promotion(s) will occur. Corresponds to the JSON property nextPromotionTime

Returns:

  • (String)


7019
7020
7021
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7019

def next_promotion_time
  @next_promotion_time
end

#targets_listArray<Google::Apis::ClouddeployV1::Targets>

Output only. A list of targets involved in the upcoming timed promotion(s). Corresponds to the JSON property targetsList



7024
7025
7026
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7024

def targets_list
  @targets_list
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7031
7032
7033
7034
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7031

def update!(**args)
  @next_promotion_time = args[:next_promotion_time] if args.key?(:next_promotion_time)
  @targets_list = args[:targets_list] if args.key?(:targets_list)
end