Class: Google::Apis::ClouddeployV1::TimedPromoteReleaseOperation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

Contains the information of an automated timed promote-release operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TimedPromoteReleaseOperation

Returns a new instance of TimedPromoteReleaseOperation.



7058
7059
7060
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7058

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#phaseString

Output only. The starting phase of the rollout created by this operation. Corresponds to the JSON property phase

Returns:

  • (String)


7044
7045
7046
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7044

def phase
  @phase
end

#releaseString

Output only. The name of the release to be promoted. Corresponds to the JSON property release

Returns:

  • (String)


7049
7050
7051
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7049

def release
  @release
end

#target_idString

Output only. The ID of the target that represents the promotion stage to which the release will be promoted. The value of this field is the last segment of a target name. Corresponds to the JSON property targetId

Returns:

  • (String)


7056
7057
7058
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7056

def target_id
  @target_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7063
7064
7065
7066
7067
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7063

def update!(**args)
  @phase = args[:phase] if args.key?(:phase)
  @release = args[:release] if args.key?(:release)
  @target_id = args[:target_id] if args.key?(:target_id)
end