Class: Google::Apis::ClouddeployV1::ToolVersionSupportedCondition

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

ToolVersionSupportedCondition contains information about when support for the release's version of a tool ends.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ToolVersionSupportedCondition

Returns a new instance of ToolVersionSupportedCondition.



7147
7148
7149
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7147

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#maintenance_mode_timeString

Output only. The time at which this release's version of the tool will enter maintenance mode. Corresponds to the JSON property maintenanceModeTime

Returns:

  • (String)


7128
7129
7130
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7128

def maintenance_mode_time
  @maintenance_mode_time
end

#statusBoolean Also known as: status?

Output only. True if the version of Tool used by this release is supported. Corresponds to the JSON property status

Returns:

  • (Boolean)


7133
7134
7135
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7133

def status
  @status
end

#support_expiration_timeString

Output only. The time at which this release's version of the tool will no longer be supported. Corresponds to the JSON property supportExpirationTime

Returns:

  • (String)


7140
7141
7142
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7140

def support_expiration_time
  @support_expiration_time
end

#tool_version_support_stateString

Output only. The tool support state for this release's version of the tool. Corresponds to the JSON property toolVersionSupportState

Returns:

  • (String)


7145
7146
7147
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7145

def tool_version_support_state
  @tool_version_support_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7152
7153
7154
7155
7156
7157
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7152

def update!(**args)
  @maintenance_mode_time = args[:maintenance_mode_time] if args.key?(:maintenance_mode_time)
  @status = args[:status] if args.key?(:status)
  @support_expiration_time = args[:support_expiration_time] if args.key?(:support_expiration_time)
  @tool_version_support_state = args[:tool_version_support_state] if args.key?(:tool_version_support_state)
end