Class: Google::Apis::ClouddeployV1::ToolVersions

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

Details of ToolVersions for the release.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ToolVersions

Returns a new instance of ToolVersions.



7201
7202
7203
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7201

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dockerString

Optional. The Docker version to use for Cloud Deploy operations. Corresponds to the JSON property docker

Returns:

  • (String)


7174
7175
7176
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7174

def docker
  @docker
end

#helmString

Optional. The Helm version to use for Cloud Deploy operations. Corresponds to the JSON property helm

Returns:

  • (String)


7179
7180
7181
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7179

def helm
  @helm
end

#kptString

Optional. The kpt version to use for Cloud Deploy operations. Corresponds to the JSON property kpt

Returns:

  • (String)


7184
7185
7186
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7184

def kpt
  @kpt
end

#kubectlString

Optional. The Kubectl version to use for Cloud Deploy operations. Corresponds to the JSON property kubectl

Returns:

  • (String)


7189
7190
7191
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7189

def kubectl
  @kubectl
end

#kustomizeString

Optional. The Kustomize version to use for Cloud Deploy operations. Corresponds to the JSON property kustomize

Returns:

  • (String)


7194
7195
7196
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7194

def kustomize
  @kustomize
end

#skaffoldString

Optional. The Skaffold version to use for Cloud Deploy operations. Corresponds to the JSON property skaffold

Returns:

  • (String)


7199
7200
7201
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7199

def skaffold
  @skaffold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7206
7207
7208
7209
7210
7211
7212
7213
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7206

def update!(**args)
  @docker = args[:docker] if args.key?(:docker)
  @helm = args[:helm] if args.key?(:helm)
  @kpt = args[:kpt] if args.key?(:kpt)
  @kubectl = args[:kubectl] if args.key?(:kubectl)
  @kustomize = args[:kustomize] if args.key?(:kustomize)
  @skaffold = args[:skaffold] if args.key?(:skaffold)
end