Class: Google::Apis::ClouddeployV1::Verify

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

Verify contains the verify job configuration information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Verify

Returns a new instance of Verify.



7219
7220
7221
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7219

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#tasksArray<Google::Apis::ClouddeployV1::Task>

Optional. The tasks that will run as a part of the verify job. The tasks are executed sequentially in the order specified. Corresponds to the JSON property tasks



7217
7218
7219
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7217

def tasks
  @tasks
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7224
7225
7226
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7224

def update!(**args)
  @tasks = args[:tasks] if args.key?(:tasks)
end