Class: Google::Apis::ClouddeployV1::VerifyJobRun
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::VerifyJobRun
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
VerifyJobRun contains information specific to a verify JobRun.
Instance Attribute Summary collapse
-
#artifact_uri ⇒ String
Output only.
-
#build ⇒ String
Output only.
-
#event_log_path ⇒ String
Output only.
-
#failure_cause ⇒ String
Output only.
-
#failure_message ⇒ String
Output only.
-
#metadata ⇒ Google::Apis::ClouddeployV1::VerifyJobRunMetadata
VerifyJobRunMetadata contains metadata about the verify
JobRun.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VerifyJobRun
constructor
A new instance of VerifyJobRun.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VerifyJobRun
Returns a new instance of VerifyJobRun.
7292 7293 7294 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7292 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_uri ⇒ String
Output only. URI of a directory containing the verify artifacts. This contains
the Skaffold event log.
Corresponds to the JSON property artifactUri
7263 7264 7265 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7263 def artifact_uri @artifact_uri end |
#build ⇒ String
Output only. The resource name of the Cloud Build Build object that is used
to verify. Format is projects/project/locations/location/builds/build`.
Corresponds to the JSON propertybuild`
7269 7270 7271 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7269 def build @build end |
#event_log_path ⇒ String
Output only. File path of the Skaffold event log relative to the artifact URI.
Corresponds to the JSON property eventLogPath
7274 7275 7276 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7274 def event_log_path @event_log_path end |
#failure_cause ⇒ String
Output only. The reason the verify failed. This will always be unspecified
while the verify is in progress or if it succeeded.
Corresponds to the JSON property failureCause
7280 7281 7282 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7280 def failure_cause @failure_cause end |
#failure_message ⇒ String
Output only. Additional information about the verify failure, if available.
Corresponds to the JSON property failureMessage
7285 7286 7287 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7285 def @failure_message end |
#metadata ⇒ Google::Apis::ClouddeployV1::VerifyJobRunMetadata
VerifyJobRunMetadata contains metadata about the verify JobRun.
Corresponds to the JSON property metadata
7290 7291 7292 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7290 def @metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7297 7298 7299 7300 7301 7302 7303 7304 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7297 def update!(**args) @artifact_uri = args[:artifact_uri] if args.key?(:artifact_uri) @build = args[:build] if args.key?(:build) @event_log_path = args[:event_log_path] if args.key?(:event_log_path) @failure_cause = args[:failure_cause] if args.key?(:failure_cause) @failure_message = args[:failure_message] if args.key?(:failure_message) @metadata = args[:metadata] if args.key?(:metadata) end |