Class: Google::Apis::ClouddeployV1::WeeklyWindow

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

Weekly windows. For example, blocking actions every Saturday and Sunday. Another example would be blocking actions every weekday from 5pm to midnight.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WeeklyWindow

Returns a new instance of WeeklyWindow.



7343
7344
7345
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7343

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#days_of_weekArray<String>

Optional. Days of week. If left empty, all days of the week will be included. Corresponds to the JSON property daysOfWeek

Returns:

  • (Array<String>)


7327
7328
7329
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7327

def days_of_week
  @days_of_week
end

#end_timeGoogle::Apis::ClouddeployV1::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property endTime



7334
7335
7336
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7334

def end_time
  @end_time
end

#start_timeGoogle::Apis::ClouddeployV1::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property startTime



7341
7342
7343
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7341

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7348
7349
7350
7351
7352
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7348

def update!(**args)
  @days_of_week = args[:days_of_week] if args.key?(:days_of_week)
  @end_time = args[:end_time] if args.key?(:end_time)
  @start_time = args[:start_time] if args.key?(:start_time)
end