Class: Google::Apis::ClouddeployV1::AlertPolicyCheckStatus
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::AlertPolicyCheckStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
AlertPolicyCheckStatus contains information specific to a single run of an alert policy check.
Instance Attribute Summary collapse
-
#alert_policies ⇒ Array<String>
Output only.
-
#failed_alert_policies ⇒ Array<Google::Apis::ClouddeployV1::FailedAlertPolicy>
Output only.
-
#failure_message ⇒ String
Output only.
-
#id ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AlertPolicyCheckStatus
constructor
A new instance of AlertPolicyCheckStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AlertPolicyCheckStatus
Returns a new instance of AlertPolicyCheckStatus.
280 281 282 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 280 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alert_policies ⇒ Array<String>
Output only. The alert policies that this analysis monitors. Format is
projects/project/locations/location/alertPolicies/alertPolicy`.
Corresponds to the JSON propertyalertPolicies`
256 257 258 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 256 def alert_policies @alert_policies end |
#failed_alert_policies ⇒ Array<Google::Apis::ClouddeployV1::FailedAlertPolicy>
Output only. The alert policies that were found to be firing during this check.
This will be empty if no incidents were found.
Corresponds to the JSON property failedAlertPolicies
262 263 264 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 262 def failed_alert_policies @failed_alert_policies end |
#failure_message ⇒ String
Output only. Additional information about the alert policy check failure, if
available. This will be empty if the alert policy check succeeded.
Corresponds to the JSON property failureMessage
268 269 270 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 268 def @failure_message end |
#id ⇒ String
Output only. The ID of this analysis.
Corresponds to the JSON property id
273 274 275 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 273 def id @id end |
#labels ⇒ Hash<String,String>
Output only. The resolved labels used to filter for specific incidents.
Corresponds to the JSON property labels
278 279 280 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 278 def labels @labels end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
285 286 287 288 289 290 291 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 285 def update!(**args) @alert_policies = args[:alert_policies] if args.key?(:alert_policies) @failed_alert_policies = args[:failed_alert_policies] if args.key?(:failed_alert_policies) @failure_message = args[:failure_message] if args.key?(:failure_message) @id = args[:id] if args.key?(:id) @labels = args[:labels] if args.key?(:labels) end |