Class: Google::Apis::ClouddeployV1::Analysis
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::Analysis
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
Analysis contains the configuration for the set of analyses to be performed on the target.
Instance Attribute Summary collapse
-
#custom_checks ⇒ Array<Google::Apis::ClouddeployV1::CustomCheck>
Optional.
-
#duration ⇒ String
Required.
-
#google_cloud ⇒ Google::Apis::ClouddeployV1::GoogleCloudAnalysis
GoogleCloudAnalysis is a set of Google Cloud-based checks to perform on the deployment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Analysis
constructor
A new instance of Analysis.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Analysis
Returns a new instance of Analysis.
319 320 321 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 319 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_checks ⇒ Array<Google::Apis::ClouddeployV1::CustomCheck>
Optional. Custom analysis checks from 3P metric providers.
Corresponds to the JSON property customChecks
302 303 304 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 302 def custom_checks @custom_checks end |
#duration ⇒ String
Required. The amount of time in minutes the analysis on the target will last.
If all analysis checks have successfully completed before the specified
duration, the analysis is successful. If a check is still running while the
specified duration passes, it will wait for that check to complete to
determine if the analysis is successful. The maximum duration is 48 hours.
Corresponds to the JSON property duration
311 312 313 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 311 def duration @duration end |
#google_cloud ⇒ Google::Apis::ClouddeployV1::GoogleCloudAnalysis
GoogleCloudAnalysis is a set of Google Cloud-based checks to perform on the
deployment.
Corresponds to the JSON property googleCloud
317 318 319 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 317 def google_cloud @google_cloud end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
324 325 326 327 328 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 324 def update!(**args) @custom_checks = args[:custom_checks] if args.key?(:custom_checks) @duration = args[:duration] if args.key?(:duration) @google_cloud = args[:google_cloud] if args.key?(:google_cloud) end |