Class: Google::Apis::ClouddeployV1::AnalysisJobRun
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::AnalysisJobRun
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
AnalysisJobRun contains information specific to an analysis JobRun.
Instance Attribute Summary collapse
-
#alert_policy_analyses ⇒ Array<Google::Apis::ClouddeployV1::AlertPolicyCheckStatus>
Output only.
-
#custom_check_analyses ⇒ Array<Google::Apis::ClouddeployV1::CustomCheckStatus>
Output only.
-
#failed_check_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AnalysisJobRun
constructor
A new instance of AnalysisJobRun.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AnalysisJobRun
Returns a new instance of AnalysisJobRun.
388 389 390 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 388 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alert_policy_analyses ⇒ Array<Google::Apis::ClouddeployV1::AlertPolicyCheckStatus>
Output only. The status of the running alert policy checks configured for this
analysis.
Corresponds to the JSON property alertPolicyAnalyses
374 375 376 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 374 def alert_policy_analyses @alert_policy_analyses end |
#custom_check_analyses ⇒ Array<Google::Apis::ClouddeployV1::CustomCheckStatus>
Output only. The status of the running custom checks configured for this
analysis.
Corresponds to the JSON property customCheckAnalyses
380 381 382 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 380 def custom_check_analyses @custom_check_analyses end |
#failed_check_id ⇒ String
Output only. The ID of the configured check that failed. This will always be
blank while the analysis is in progress or if it succeeded.
Corresponds to the JSON property failedCheckId
386 387 388 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 386 def failed_check_id @failed_check_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
393 394 395 396 397 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 393 def update!(**args) @alert_policy_analyses = args[:alert_policy_analyses] if args.key?(:alert_policy_analyses) @custom_check_analyses = args[:custom_check_analyses] if args.key?(:custom_check_analyses) @failed_check_id = args[:failed_check_id] if args.key?(:failed_check_id) end |