Class: Google::Apis::ClouddeployV1::AutomationRunEvent
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::AutomationRunEvent
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
Payload proto for "clouddeploy.googleapis.com/automation_run" Platform Log event that describes the AutomationRun related events.
Instance Attribute Summary collapse
-
#automation_id ⇒ String
Identifier of the
Automation. -
#automation_run ⇒ String
The name of the
AutomationRun. -
#destination_target_id ⇒ String
ID of the
Targetto which theAutomationRunis created. -
#message ⇒ String
Debug message for when there is an update on the AutomationRun.
-
#pipeline_uid ⇒ String
Unique identifier of the
DeliveryPipeline. -
#rule_id ⇒ String
Identifier of the
Automationrule. -
#type ⇒ String
Type of this notification, e.g.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutomationRunEvent
constructor
A new instance of AutomationRunEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutomationRunEvent
Returns a new instance of AutomationRunEvent.
828 829 830 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 828 def initialize(**args) update!(**args) end |
Instance Attribute Details
#automation_id ⇒ String
Identifier of the Automation.
Corresponds to the JSON property automationId
795 796 797 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 795 def automation_id @automation_id end |
#automation_run ⇒ String
The name of the AutomationRun.
Corresponds to the JSON property automationRun
800 801 802 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 800 def automation_run @automation_run end |
#destination_target_id ⇒ String
ID of the Target to which the AutomationRun is created.
Corresponds to the JSON property destinationTargetId
805 806 807 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 805 def destination_target_id @destination_target_id end |
#message ⇒ String
Debug message for when there is an update on the AutomationRun. Provides
further details about the resource creation or state change.
Corresponds to the JSON property message
811 812 813 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 811 def @message end |
#pipeline_uid ⇒ String
Unique identifier of the DeliveryPipeline.
Corresponds to the JSON property pipelineUid
816 817 818 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 816 def pipeline_uid @pipeline_uid end |
#rule_id ⇒ String
Identifier of the Automation rule.
Corresponds to the JSON property ruleId
821 822 823 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 821 def rule_id @rule_id end |
#type ⇒ String
Type of this notification, e.g. for a Pub/Sub failure.
Corresponds to the JSON property type
826 827 828 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 826 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
833 834 835 836 837 838 839 840 841 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 833 def update!(**args) @automation_id = args[:automation_id] if args.key?(:automation_id) @automation_run = args[:automation_run] if args.key?(:automation_run) @destination_target_id = args[:destination_target_id] if args.key?(:destination_target_id) @message = args[:message] if args.key?(:message) @pipeline_uid = args[:pipeline_uid] if args.key?(:pipeline_uid) @rule_id = args[:rule_id] if args.key?(:rule_id) @type = args[:type] if args.key?(:type) end |