Class: Google::Apis::ClouddeployV1::CanaryDeployment
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::CanaryDeployment
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
CanaryDeployment represents the canary deployment configuration
Instance Attribute Summary collapse
-
#analysis ⇒ Google::Apis::ClouddeployV1::Analysis
Analysis contains the configuration for the set of analyses to be performed on the target.
-
#percentages ⇒ Array<Fixnum>
Required.
-
#postdeploy ⇒ Google::Apis::ClouddeployV1::Postdeploy
Postdeploy contains the postdeploy job configuration information.
-
#predeploy ⇒ Google::Apis::ClouddeployV1::Predeploy
Predeploy contains the predeploy job configuration information.
-
#verify ⇒ Boolean
(also: #verify?)
Optional.
-
#verify_config ⇒ Google::Apis::ClouddeployV1::Verify
Verify contains the verify job configuration information.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CanaryDeployment
constructor
A new instance of CanaryDeployment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CanaryDeployment
Returns a new instance of CanaryDeployment.
1233 1234 1235 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1233 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analysis ⇒ Google::Apis::ClouddeployV1::Analysis
Analysis contains the configuration for the set of analyses to be performed on
the target.
Corresponds to the JSON property analysis
1201 1202 1203 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1201 def analysis @analysis end |
#percentages ⇒ Array<Fixnum>
Required. The percentage based deployments that will occur as a part of a
Rollout. List is expected in ascending order and each integer n is 0 <= n <
- If the GatewayServiceMesh is configured for Kubernetes, then the range
for n is 0 <= n <= 100.
Corresponds to the JSON property
percentages
1209 1210 1211 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1209 def percentages @percentages end |
#postdeploy ⇒ Google::Apis::ClouddeployV1::Postdeploy
Postdeploy contains the postdeploy job configuration information.
Corresponds to the JSON property postdeploy
1214 1215 1216 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1214 def postdeploy @postdeploy end |
#predeploy ⇒ Google::Apis::ClouddeployV1::Predeploy
Predeploy contains the predeploy job configuration information.
Corresponds to the JSON property predeploy
1219 1220 1221 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1219 def predeploy @predeploy end |
#verify ⇒ Boolean Also known as: verify?
Optional. Whether to run verify tests after each percentage deployment via
skaffold verify.
Corresponds to the JSON property verify
1225 1226 1227 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1225 def verify @verify end |
#verify_config ⇒ Google::Apis::ClouddeployV1::Verify
Verify contains the verify job configuration information.
Corresponds to the JSON property verifyConfig
1231 1232 1233 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1231 def verify_config @verify_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1238 1239 1240 1241 1242 1243 1244 1245 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1238 def update!(**args) @analysis = args[:analysis] if args.key?(:analysis) @percentages = args[:percentages] if args.key?(:percentages) @postdeploy = args[:postdeploy] if args.key?(:postdeploy) @predeploy = args[:predeploy] if args.key?(:predeploy) @verify = args[:verify] if args.key?(:verify) @verify_config = args[:verify_config] if args.key?(:verify_config) end |