Class: Google::Apis::ClouddeployV1::CloudRunMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::CloudRunMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
CloudRunMetadata contains information from a Cloud Run deployment.
Instance Attribute Summary collapse
-
#job ⇒ String
Output only.
-
#previous_revision ⇒ String
Output only.
-
#revision ⇒ String
Output only.
-
#service ⇒ String
Output only.
-
#service_urls ⇒ Array<String>
Output only.
-
#worker_pool ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudRunMetadata
constructor
A new instance of CloudRunMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudRunMetadata
Returns a new instance of CloudRunMetadata.
1450 1451 1452 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1450 def initialize(**args) update!(**args) end |
Instance Attribute Details
#job ⇒ String
Output only. The name of the Cloud Run job that is associated with a Rollout.
Format is projects/project/locations/location/jobs/job_name`.
Corresponds to the JSON propertyjob`
1416 1417 1418 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1416 def job @job end |
#previous_revision ⇒ String
Output only. The previous Cloud Run Revision name associated with a Rollout.
Only set when a canary deployment strategy is configured. Format for service
is projects/project/locations/location/services/service/revisions/
revision. Format for worker pool is projects/project/locations/location/
workerPools/workerpool/revisions/revision.
Corresponds to the JSON property previousRevision
1425 1426 1427 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1425 def previous_revision @previous_revision end |
#revision ⇒ String
Output only. The Cloud Run Revision id associated with a Rollout.
Corresponds to the JSON property revision
1430 1431 1432 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1430 def revision @revision end |
#service ⇒ String
Output only. The name of the Cloud Run Service that is associated with a
Rollout. Format is projects/project/locations/location/services/service
.
Corresponds to the JSON property service
1437 1438 1439 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1437 def service @service end |
#service_urls ⇒ Array<String>
Output only. The Cloud Run Service urls that are associated with a Rollout.
Corresponds to the JSON property serviceUrls
1442 1443 1444 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1442 def service_urls @service_urls end |
#worker_pool ⇒ String
Output only. The Cloud Run worker pool associated with a Rollout. Format is
projects/project/locations/location/workerPools/worker_pool`.
Corresponds to the JSON propertyworkerPool`
1448 1449 1450 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1448 def worker_pool @worker_pool end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1455 1456 1457 1458 1459 1460 1461 1462 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1455 def update!(**args) @job = args[:job] if args.key?(:job) @previous_revision = args[:previous_revision] if args.key?(:previous_revision) @revision = args[:revision] if args.key?(:revision) @service = args[:service] if args.key?(:service) @service_urls = args[:service_urls] if args.key?(:service_urls) @worker_pool = args[:worker_pool] if args.key?(:worker_pool) end |