Class: Google::Apis::ClouddeployV1::CloudRunRenderMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::CloudRunRenderMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
CloudRunRenderMetadata contains Cloud Run information associated with a
Release render.
Instance Attribute Summary collapse
-
#job ⇒ String
Output only.
-
#revision ⇒ String
Output only.
-
#service ⇒ String
Output only.
-
#worker_pool ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudRunRenderMetadata
constructor
A new instance of CloudRunRenderMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudRunRenderMetadata
Returns a new instance of CloudRunRenderMetadata.
1495 1496 1497 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1495 def initialize(**args) update!(**args) end |
Instance Attribute Details
#job ⇒ String
Output only. The name of the Cloud Run Job in the rendered manifest. Format is
projects/project/locations/location/jobs/job`.
Corresponds to the JSON propertyjob`
1474 1475 1476 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1474 def job @job end |
#revision ⇒ String
Output only. The name of the Cloud Run Revision in the rendered manifest.
Format is projects/project/locations/location/services/service/
revisions/revision`.
Corresponds to the JSON propertyrevision`
1481 1482 1483 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1481 def revision @revision end |
#service ⇒ String
Output only. The name of the Cloud Run Service in the rendered manifest.
Format is projects/project/locations/location/services/service`.
Corresponds to the JSON propertyservice`
1487 1488 1489 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1487 def service @service end |
#worker_pool ⇒ String
Output only. The name of the Cloud Run Worker Pool in the rendered manifest.
Format is projects/project/locations/location/workerPools/worker_pool`.
Corresponds to the JSON propertyworkerPool`
1493 1494 1495 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1493 def worker_pool @worker_pool end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1500 1501 1502 1503 1504 1505 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1500 def update!(**args) @job = args[:job] if args.key?(:job) @revision = args[:revision] if args.key?(:revision) @service = args[:service] if args.key?(:service) @worker_pool = args[:worker_pool] if args.key?(:worker_pool) end |