Class: Google::Apis::ClouddeployV1::CloudRunRenderMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

CloudRunRenderMetadata contains Cloud Run information associated with a Release render.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudRunRenderMetadata

Returns a new instance of CloudRunRenderMetadata.



1270
1271
1272
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1270

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#serviceString

Output only. The name of the Cloud Run Service in the rendered manifest. Format is projects/project/locations/location/services/service`. Corresponds to the JSON propertyservice`

Returns:

  • (String)


1262
1263
1264
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1262

def service
  @service
end

#worker_poolString

Output only. The name of the Cloud Run Worker Pool in the rendered manifest. Format is projects/project/locations/location/workerPools/worker_pool`. Corresponds to the JSON propertyworkerPool`

Returns:

  • (String)


1268
1269
1270
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1268

def worker_pool
  @worker_pool
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1275
1276
1277
1278
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1275

def update!(**args)
  @service = args[:service] if args.key?(:service)
  @worker_pool = args[:worker_pool] if args.key?(:worker_pool)
end