Class: Google::Apis::ClouddeployV1::CustomCheckStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

CustomCheckStatus contains information specific to a single iteration of a custom analysis job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomCheckStatus

Returns a new instance of CustomCheckStatus.



1723
1724
1725
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1723

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failure_causeString

Output only. The reason the analysis failed. This will always be unspecified while the analysis is in progress or if it succeeded. Corresponds to the JSON property failureCause

Returns:

  • (String)


1689
1690
1691
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1689

def failure_cause
  @failure_cause
end

#failure_messageString

Output only. Additional information about the analysis failure, if available. Corresponds to the JSON property failureMessage

Returns:

  • (String)


1694
1695
1696
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1694

def failure_message
  @failure_message
end

#frequencyString

Output only. The frequency in minutes at which the custom check is run. Corresponds to the JSON property frequency

Returns:

  • (String)


1699
1700
1701
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1699

def frequency
  @frequency
end

#idString

Output only. The ID of the custom check. Corresponds to the JSON property id

Returns:

  • (String)


1704
1705
1706
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1704

def id
  @id
end

#latest_buildString

Output only. The resource name of the Cloud Build Build object that was used to execute the latest run of this custom action check. Format is projects/ project/locations/location/builds/build`. Corresponds to the JSON propertylatestBuild`

Returns:

  • (String)


1711
1712
1713
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1711

def latest_build
  @latest_build
end

#metadataGoogle::Apis::ClouddeployV1::CustomMetadata

CustomMetadata contains information from a user-defined operation. Corresponds to the JSON property metadata



1716
1717
1718
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1716

def 
  @metadata
end

#taskGoogle::Apis::ClouddeployV1::Task

A Task represents a unit of work that is executed as part of a Job. Corresponds to the JSON property task



1721
1722
1723
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1721

def task
  @task
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1728
1729
1730
1731
1732
1733
1734
1735
1736
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1728

def update!(**args)
  @failure_cause = args[:failure_cause] if args.key?(:failure_cause)
  @failure_message = args[:failure_message] if args.key?(:failure_message)
  @frequency = args[:frequency] if args.key?(:frequency)
  @id = args[:id] if args.key?(:id)
  @latest_build = args[:latest_build] if args.key?(:latest_build)
  @metadata = args[:metadata] if args.key?(:metadata)
  @task = args[:task] if args.key?(:task)
end