Class: Google::Apis::ClouddeployV1::CustomTargetSkaffoldActions
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::CustomTargetSkaffoldActions
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
CustomTargetSkaffoldActions represents the CustomTargetType configuration
using Skaffold custom actions.
Instance Attribute Summary collapse
-
#deploy_action ⇒ String
Required.
-
#include_skaffold_modules ⇒ Array<Google::Apis::ClouddeployV1::SkaffoldModules>
Optional.
-
#render_action ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomTargetSkaffoldActions
constructor
A new instance of CustomTargetSkaffoldActions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomTargetSkaffoldActions
Returns a new instance of CustomTargetSkaffoldActions.
1828 1829 1830 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1828 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deploy_action ⇒ String
Required. The Skaffold custom action responsible for deploy operations.
Corresponds to the JSON property deployAction
1813 1814 1815 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1813 def deploy_action @deploy_action end |
#include_skaffold_modules ⇒ Array<Google::Apis::ClouddeployV1::SkaffoldModules>
Optional. List of Skaffold modules Cloud Deploy will include in the Skaffold
Config as required before performing diagnose.
Corresponds to the JSON property includeSkaffoldModules
1819 1820 1821 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1819 def include_skaffold_modules @include_skaffold_modules end |
#render_action ⇒ String
Optional. The Skaffold custom action responsible for render operations. If not
provided then Cloud Deploy will perform the render operations via skaffold
render.
Corresponds to the JSON property renderAction
1826 1827 1828 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1826 def render_action @render_action end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1833 1834 1835 1836 1837 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1833 def update!(**args) @deploy_action = args[:deploy_action] if args.key?(:deploy_action) @include_skaffold_modules = args[:include_skaffold_modules] if args.key?(:include_skaffold_modules) @render_action = args[:render_action] if args.key?(:render_action) end |