Class: Google::Apis::ClouddeployV1::CustomTargetSkaffoldActions

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

CustomTargetSkaffoldActions represents the CustomTargetType configuration using Skaffold custom actions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomTargetSkaffoldActions

Returns a new instance of CustomTargetSkaffoldActions.



1821
1822
1823
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1821

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deploy_actionString

Required. The Skaffold custom action responsible for deploy operations. Corresponds to the JSON property deployAction

Returns:

  • (String)


1806
1807
1808
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1806

def deploy_action
  @deploy_action
end

#include_skaffold_modulesArray<Google::Apis::ClouddeployV1::SkaffoldModules>

Optional. List of Skaffold modules Cloud Deploy will include in the Skaffold Config as required before performing diagnose. Corresponds to the JSON property includeSkaffoldModules



1812
1813
1814
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1812

def include_skaffold_modules
  @include_skaffold_modules
end

#render_actionString

Optional. The Skaffold custom action responsible for render operations. If not provided then Cloud Deploy will perform the render operations via skaffold render. Corresponds to the JSON property renderAction

Returns:

  • (String)


1819
1820
1821
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1819

def render_action
  @render_action
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1826
1827
1828
1829
1830
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1826

def update!(**args)
  @deploy_action = args[:deploy_action] if args.key?(:deploy_action)
  @include_skaffold_modules = args[:include_skaffold_modules] if args.key?(:include_skaffold_modules)
  @render_action = args[:render_action] if args.key?(:render_action)
end