Class: Google::Apis::ClouddeployV1::CustomTargetSkaffoldActions

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

CustomTargetSkaffoldActions represents the CustomTargetType configuration using Skaffold custom actions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomTargetSkaffoldActions

Returns a new instance of CustomTargetSkaffoldActions.



1442
1443
1444
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1442

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deploy_actionString

Required. The Skaffold custom action responsible for deploy operations. Corresponds to the JSON property deployAction

Returns:

  • (String)


1427
1428
1429
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1427

def deploy_action
  @deploy_action
end

#include_skaffold_modulesArray<Google::Apis::ClouddeployV1::SkaffoldModules>

Optional. List of Skaffold modules Cloud Deploy will include in the Skaffold Config as required before performing diagnose. Corresponds to the JSON property includeSkaffoldModules



1433
1434
1435
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1433

def include_skaffold_modules
  @include_skaffold_modules
end

#render_actionString

Optional. The Skaffold custom action responsible for render operations. If not provided then Cloud Deploy will perform the render operations via skaffold render. Corresponds to the JSON property renderAction

Returns:

  • (String)


1440
1441
1442
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1440

def render_action
  @render_action
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1447
1448
1449
1450
1451
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1447

def update!(**args)
  @deploy_action = args[:deploy_action] if args.key?(:deploy_action)
  @include_skaffold_modules = args[:include_skaffold_modules] if args.key?(:include_skaffold_modules)
  @render_action = args[:render_action] if args.key?(:render_action)
end