Class: Google::Apis::ClouddeployV1::CustomTargetType
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::CustomTargetType
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
A CustomTargetType resource in the Cloud Deploy API. A CustomTargetType
defines a type of custom target that can be referenced in a Target in order
to facilitate deploying to other systems besides the supported runtimes.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#create_time ⇒ String
Output only.
-
#custom_actions ⇒ Google::Apis::ClouddeployV1::CustomTargetSkaffoldActions
CustomTargetSkaffoldActions represents the
CustomTargetTypeconfiguration using Skaffold custom actions. -
#custom_target_type_id ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#tasks ⇒ Google::Apis::ClouddeployV1::CustomTargetTasks
CustomTargetTasks represents the
CustomTargetTypeconfiguration using tasks. -
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomTargetType
constructor
A new instance of CustomTargetType.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomTargetType
Returns a new instance of CustomTargetType.
1932 1933 1934 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1932 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. User annotations. These attributes can only be set and used by the
user, and not by Cloud Deploy. See https://google.aip.dev/128#annotations for
more details such as format and size limitations.
Corresponds to the JSON property annotations
1869 1870 1871 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1869 def annotations @annotations end |
#create_time ⇒ String
Output only. Time at which the CustomTargetType was created.
Corresponds to the JSON property createTime
1874 1875 1876 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1874 def create_time @create_time end |
#custom_actions ⇒ Google::Apis::ClouddeployV1::CustomTargetSkaffoldActions
CustomTargetSkaffoldActions represents the CustomTargetType configuration
using Skaffold custom actions.
Corresponds to the JSON property customActions
1880 1881 1882 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1880 def custom_actions @custom_actions end |
#custom_target_type_id ⇒ String
Output only. Resource id of the CustomTargetType.
Corresponds to the JSON property customTargetTypeId
1885 1886 1887 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1885 def custom_target_type_id @custom_target_type_id end |
#description ⇒ String
Optional. Description of the CustomTargetType. Max length is 255 characters.
Corresponds to the JSON property description
1890 1891 1892 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1890 def description @description end |
#etag ⇒ String
Optional. This checksum is computed by the server based on the value of other
fields, and may be sent on update and delete requests to ensure the client has
an up-to-date value before proceeding.
Corresponds to the JSON property etag
1897 1898 1899 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1897 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. Labels are attributes that can be set and used by both the user and
by Cloud Deploy. Labels must meet the following constraints: * Keys and values
can contain only lowercase letters, numeric characters, underscores, and
dashes. * All characters must use UTF-8 encoding, and international characters
are allowed. * Keys must start with a lowercase letter or international
character. * Each resource is limited to a maximum of 64 labels. Both keys and
values are additionally constrained to be <= 128 bytes.
Corresponds to the JSON property labels
1908 1909 1910 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1908 def labels @labels end |
#name ⇒ String
Identifier. Name of the CustomTargetType. Format is projects/project/
locations/location/customTargetTypes/customTargetType`. The
customTargetTypecomponent must matcha-z?
Corresponds to the JSON propertyname`
1915 1916 1917 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1915 def name @name end |
#tasks ⇒ Google::Apis::ClouddeployV1::CustomTargetTasks
CustomTargetTasks represents the CustomTargetType configuration using tasks.
Corresponds to the JSON property tasks
1920 1921 1922 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1920 def tasks @tasks end |
#uid ⇒ String
Output only. Unique identifier of the CustomTargetType.
Corresponds to the JSON property uid
1925 1926 1927 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1925 def uid @uid end |
#update_time ⇒ String
Output only. Most recent time at which the CustomTargetType was updated.
Corresponds to the JSON property updateTime
1930 1931 1932 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1930 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1937 1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1937 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @create_time = args[:create_time] if args.key?(:create_time) @custom_actions = args[:custom_actions] if args.key?(:custom_actions) @custom_target_type_id = args[:custom_target_type_id] if args.key?(:custom_target_type_id) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @tasks = args[:tasks] if args.key?(:tasks) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |