Class: Google::Apis::ClouddeployV1::DeliveryPipeline
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::DeliveryPipeline
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
A DeliveryPipeline resource in the Cloud Deploy API. A DeliveryPipeline
defines a pipeline through which a Skaffold configuration can progress.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#condition ⇒ Google::Apis::ClouddeployV1::PipelineCondition
PipelineCondition contains all conditions relevant to a Delivery Pipeline.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#etag ⇒ String
This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up- to-date value before proceeding.
-
#labels ⇒ Hash<String,String>
Labels are attributes that can be set and used by both the user and by Cloud Deploy.
-
#name ⇒ String
Identifier.
-
#serial_pipeline ⇒ Google::Apis::ClouddeployV1::SerialPipeline
SerialPipeline defines a sequential set of stages for a
DeliveryPipeline. -
#suspended ⇒ Boolean
(also: #suspended?)
Optional.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeliveryPipeline
constructor
A new instance of DeliveryPipeline.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeliveryPipeline
Returns a new instance of DeliveryPipeline.
2142 2143 2144 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2142 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. User annotations. These attributes can only be set and used by the
user, and not by Cloud Deploy.
Corresponds to the JSON property annotations
2078 2079 2080 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2078 def annotations @annotations end |
#condition ⇒ Google::Apis::ClouddeployV1::PipelineCondition
PipelineCondition contains all conditions relevant to a Delivery Pipeline.
Corresponds to the JSON property condition
2083 2084 2085 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2083 def condition @condition end |
#create_time ⇒ String
Output only. Time at which the pipeline was created.
Corresponds to the JSON property createTime
2088 2089 2090 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2088 def create_time @create_time end |
#description ⇒ String
Optional. Description of the DeliveryPipeline. Max length is 255 characters.
Corresponds to the JSON property description
2093 2094 2095 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2093 def description @description end |
#etag ⇒ String
This checksum is computed by the server based on the value of other fields,
and may be sent on update and delete requests to ensure the client has an up-
to-date value before proceeding.
Corresponds to the JSON property etag
2100 2101 2102 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2100 def etag @etag end |
#labels ⇒ Hash<String,String>
Labels are attributes that can be set and used by both the user and by Cloud Deploy. Labels must meet the following constraints: * Keys and values can contain only lowercase letters, numeric characters, underscores, and dashes. * All characters must use UTF-8 encoding, and international characters are allowed. * Keys must start with a lowercase letter or international character.
- Each resource is limited to a maximum of 64 labels. Both keys and values are
additionally constrained to be <= 128 bytes.
Corresponds to the JSON property
labels
2111 2112 2113 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2111 def labels @labels end |
#name ⇒ String
Identifier. Name of the DeliveryPipeline. Format is projects/project/
locations/location/deliveryPipelines/deliveryPipeline`. The
deliveryPipelinecomponent must matcha-z?
Corresponds to the JSON propertyname`
2118 2119 2120 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2118 def name @name end |
#serial_pipeline ⇒ Google::Apis::ClouddeployV1::SerialPipeline
SerialPipeline defines a sequential set of stages for a DeliveryPipeline.
Corresponds to the JSON property serialPipeline
2123 2124 2125 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2123 def serial_pipeline @serial_pipeline end |
#suspended ⇒ Boolean Also known as: suspended?
Optional. When suspended, no new releases or rollouts can be created, but in-
progress ones will complete.
Corresponds to the JSON property suspended
2129 2130 2131 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2129 def suspended @suspended end |
#uid ⇒ String
Output only. Unique identifier of the DeliveryPipeline.
Corresponds to the JSON property uid
2135 2136 2137 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2135 def uid @uid end |
#update_time ⇒ String
Output only. Most recent time at which the pipeline was updated.
Corresponds to the JSON property updateTime
2140 2141 2142 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2140 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2147 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @condition = args[:condition] if args.key?(:condition) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @serial_pipeline = args[:serial_pipeline] if args.key?(:serial_pipeline) @suspended = args[:suspended] if args.key?(:suspended) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |