Class: Google::Apis::ClouddeployV1::DeliveryPipeline

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

A DeliveryPipeline resource in the Cloud Deploy API. A DeliveryPipeline defines a pipeline through which a Skaffold configuration can progress.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeliveryPipeline

Returns a new instance of DeliveryPipeline.



2135
2136
2137
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2135

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. User annotations. These attributes can only be set and used by the user, and not by Cloud Deploy. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


2071
2072
2073
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2071

def annotations
  @annotations
end

#conditionGoogle::Apis::ClouddeployV1::PipelineCondition

PipelineCondition contains all conditions relevant to a Delivery Pipeline. Corresponds to the JSON property condition



2076
2077
2078
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2076

def condition
  @condition
end

#create_timeString

Output only. Time at which the pipeline was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2081
2082
2083
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2081

def create_time
  @create_time
end

#descriptionString

Optional. Description of the DeliveryPipeline. Max length is 255 characters. Corresponds to the JSON property description

Returns:

  • (String)


2086
2087
2088
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2086

def description
  @description
end

#etagString

This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up- to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


2093
2094
2095
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2093

def etag
  @etag
end

#labelsHash<String,String>

Labels are attributes that can be set and used by both the user and by Cloud Deploy. Labels must meet the following constraints: * Keys and values can contain only lowercase letters, numeric characters, underscores, and dashes. * All characters must use UTF-8 encoding, and international characters are allowed. * Keys must start with a lowercase letter or international character.

  • Each resource is limited to a maximum of 64 labels. Both keys and values are additionally constrained to be <= 128 bytes. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2104
2105
2106
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2104

def labels
  @labels
end

#nameString

Identifier. Name of the DeliveryPipeline. Format is projects/project/ locations/location/deliveryPipelines/deliveryPipeline`. The deliveryPipelinecomponent must matcha-z? Corresponds to the JSON propertyname`

Returns:

  • (String)


2111
2112
2113
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2111

def name
  @name
end

#serial_pipelineGoogle::Apis::ClouddeployV1::SerialPipeline

SerialPipeline defines a sequential set of stages for a DeliveryPipeline. Corresponds to the JSON property serialPipeline



2116
2117
2118
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2116

def serial_pipeline
  @serial_pipeline
end

#suspendedBoolean Also known as: suspended?

Optional. When suspended, no new releases or rollouts can be created, but in- progress ones will complete. Corresponds to the JSON property suspended

Returns:

  • (Boolean)


2122
2123
2124
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2122

def suspended
  @suspended
end

#uidString

Output only. Unique identifier of the DeliveryPipeline. Corresponds to the JSON property uid

Returns:

  • (String)


2128
2129
2130
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2128

def uid
  @uid
end

#update_timeString

Output only. Most recent time at which the pipeline was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2133
2134
2135
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2133

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2140

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @condition = args[:condition] if args.key?(:condition)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @serial_pipeline = args[:serial_pipeline] if args.key?(:serial_pipeline)
  @suspended = args[:suspended] if args.key?(:suspended)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end