Class: Google::Apis::ClouddeployV1::DeployJobRun

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

DeployJobRun contains information specific to a deploy JobRun.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeployJobRun

Returns a new instance of DeployJobRun.



2293
2294
2295
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2293

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifactGoogle::Apis::ClouddeployV1::DeployArtifact

The artifacts produced by a deploy operation. Corresponds to the JSON property artifact



2268
2269
2270
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2268

def artifact
  @artifact
end

#buildString

Output only. The resource name of the Cloud Build Build object that is used to deploy. Format is projects/project/locations/location/builds/build`. Corresponds to the JSON propertybuild`

Returns:

  • (String)


2274
2275
2276
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2274

def build
  @build
end

#failure_causeString

Output only. The reason the deploy failed. This will always be unspecified while the deploy is in progress or if it succeeded. Corresponds to the JSON property failureCause

Returns:

  • (String)


2280
2281
2282
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2280

def failure_cause
  @failure_cause
end

#failure_messageString

Output only. Additional information about the deploy failure, if available. Corresponds to the JSON property failureMessage

Returns:

  • (String)


2285
2286
2287
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2285

def failure_message
  @failure_message
end

#metadataGoogle::Apis::ClouddeployV1::DeployJobRunMetadata

DeployJobRunMetadata surfaces information associated with a DeployJobRun to the user. Corresponds to the JSON property metadata



2291
2292
2293
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2291

def 
  @metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2298
2299
2300
2301
2302
2303
2304
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2298

def update!(**args)
  @artifact = args[:artifact] if args.key?(:artifact)
  @build = args[:build] if args.key?(:build)
  @failure_cause = args[:failure_cause] if args.key?(:failure_cause)
  @failure_message = args[:failure_message] if args.key?(:failure_message)
  @metadata = args[:metadata] if args.key?(:metadata)
end