Class: Google::Apis::ClouddeployV1::DeployJobRun
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::DeployJobRun
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
DeployJobRun contains information specific to a deploy JobRun.
Instance Attribute Summary collapse
-
#artifact ⇒ Google::Apis::ClouddeployV1::DeployArtifact
The artifacts produced by a deploy operation.
-
#build ⇒ String
Output only.
-
#failure_cause ⇒ String
Output only.
-
#failure_message ⇒ String
Output only.
-
#metadata ⇒ Google::Apis::ClouddeployV1::DeployJobRunMetadata
DeployJobRunMetadata surfaces information associated with a
DeployJobRunto the user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeployJobRun
constructor
A new instance of DeployJobRun.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeployJobRun
Returns a new instance of DeployJobRun.
1903 1904 1905 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1903 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact ⇒ Google::Apis::ClouddeployV1::DeployArtifact
The artifacts produced by a deploy operation.
Corresponds to the JSON property artifact
1878 1879 1880 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1878 def artifact @artifact end |
#build ⇒ String
Output only. The resource name of the Cloud Build Build object that is used
to deploy. Format is projects/project/locations/location/builds/build`.
Corresponds to the JSON propertybuild`
1884 1885 1886 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1884 def build @build end |
#failure_cause ⇒ String
Output only. The reason the deploy failed. This will always be unspecified
while the deploy is in progress or if it succeeded.
Corresponds to the JSON property failureCause
1890 1891 1892 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1890 def failure_cause @failure_cause end |
#failure_message ⇒ String
Output only. Additional information about the deploy failure, if available.
Corresponds to the JSON property failureMessage
1895 1896 1897 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1895 def @failure_message end |
#metadata ⇒ Google::Apis::ClouddeployV1::DeployJobRunMetadata
DeployJobRunMetadata surfaces information associated with a DeployJobRun to
the user.
Corresponds to the JSON property metadata
1901 1902 1903 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1901 def @metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1908 1909 1910 1911 1912 1913 1914 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 1908 def update!(**args) @artifact = args[:artifact] if args.key?(:artifact) @build = args[:build] if args.key?(:build) @failure_cause = args[:failure_cause] if args.key?(:failure_cause) @failure_message = args[:failure_message] if args.key?(:failure_message) @metadata = args[:metadata] if args.key?(:metadata) end |