Class: Google::Apis::ClouddeployV1::FailedAlertPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::FailedAlertPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
FailedAlertPolicy contains information about an alert policy that was found to be firing during an alert policy check.
Instance Attribute Summary collapse
-
#alert_policy ⇒ String
Output only.
-
#alerts ⇒ Array<String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FailedAlertPolicy
constructor
A new instance of FailedAlertPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FailedAlertPolicy
Returns a new instance of FailedAlertPolicy.
2841 2842 2843 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2841 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alert_policy ⇒ String
Output only. The name of the alert policy that was found to be firing. Format
is projects/project/locations/location/alertPolicies/alertPolicy`.
Corresponds to the JSON propertyalertPolicy`
2833 2834 2835 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2833 def alert_policy @alert_policy end |
#alerts ⇒ Array<String>
Output only. Open alerts for the alerting policies that matched the alert
policy check configuration.
Corresponds to the JSON property alerts
2839 2840 2841 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2839 def alerts @alerts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2846 2847 2848 2849 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2846 def update!(**args) @alert_policy = args[:alert_policy] if args.key?(:alert_policy) @alerts = args[:alerts] if args.key?(:alerts) end |