Class: Google::Apis::ClouddeployV1::GatewayServiceMesh

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

Information about the Kubernetes Gateway API service mesh configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GatewayServiceMesh

Returns a new instance of GatewayServiceMesh.



2897
2898
2899
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2897

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deploymentString

Required. Name of the Kubernetes Deployment whose traffic is managed by the specified HTTPRoute and Service. Corresponds to the JSON property deployment

Returns:

  • (String)


2860
2861
2862
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2860

def deployment
  @deployment
end

#http_routeString

Required. Name of the Gateway API HTTPRoute. Corresponds to the JSON property httpRoute

Returns:

  • (String)


2865
2866
2867
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2865

def http_route
  @http_route
end

#pod_selector_labelString

Optional. The label to use when selecting Pods for the Deployment and Service resources. This label must already be present in both resources. Corresponds to the JSON property podSelectorLabel

Returns:

  • (String)


2871
2872
2873
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2871

def pod_selector_label
  @pod_selector_label
end

#route_destinationsGoogle::Apis::ClouddeployV1::RouteDestinations

Information about route destinations for the Gateway API service mesh. Corresponds to the JSON property routeDestinations



2876
2877
2878
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2876

def route_destinations
  @route_destinations
end

#route_update_wait_timeString

Optional. The time to wait for route updates to propagate. The maximum configurable time is 3 hours, in seconds format. If unspecified, there is no wait time. Corresponds to the JSON property routeUpdateWaitTime

Returns:

  • (String)


2883
2884
2885
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2883

def route_update_wait_time
  @route_update_wait_time
end

#serviceString

Required. Name of the Kubernetes Service. Corresponds to the JSON property service

Returns:

  • (String)


2888
2889
2890
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2888

def service
  @service
end

#stable_cutback_durationString

Optional. The amount of time to migrate traffic back from the canary Service to the original Service during the stable phase deployment. If specified, must be between 15s and 3600s. If unspecified, there is no cutback time. Corresponds to the JSON property stableCutbackDuration

Returns:

  • (String)


2895
2896
2897
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2895

def stable_cutback_duration
  @stable_cutback_duration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2902
2903
2904
2905
2906
2907
2908
2909
2910
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2902

def update!(**args)
  @deployment = args[:deployment] if args.key?(:deployment)
  @http_route = args[:http_route] if args.key?(:http_route)
  @pod_selector_label = args[:pod_selector_label] if args.key?(:pod_selector_label)
  @route_destinations = args[:route_destinations] if args.key?(:route_destinations)
  @route_update_wait_time = args[:route_update_wait_time] if args.key?(:route_update_wait_time)
  @service = args[:service] if args.key?(:service)
  @stable_cutback_duration = args[:stable_cutback_duration] if args.key?(:stable_cutback_duration)
end