Class: Google::Apis::ClouddeployV1::GkeCluster

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

Information specifying a GKE Cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GkeCluster

Returns a new instance of GkeCluster.



2950
2951
2952
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2950

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clusterString

Optional. Information specifying a GKE Cluster. Format is projects/ project_id/locations/location_id/clusters/cluster_id`. Corresponds to the JSON propertycluster`

Returns:

  • (String)


2921
2922
2923
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2921

def cluster
  @cluster
end

#dns_endpointBoolean Also known as: dns_endpoint?

Optional. If set, the cluster will be accessed using the DNS endpoint. Note that both dns_endpoint and internal_ip cannot be set to true. Corresponds to the JSON property dnsEndpoint

Returns:

  • (Boolean)


2927
2928
2929
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2927

def dns_endpoint
  @dns_endpoint
end

#internal_ipBoolean Also known as: internal_ip?

Optional. If true, cluster is accessed using the private IP address of the control plane endpoint. Otherwise, the default IP address of the control plane endpoint is used. The default IP address is the private IP address for clusters with private control-plane endpoints and the public IP address otherwise. Only specify this option when cluster is a private GKE cluster. Note that internal_ip and dns_endpoint cannot both be set to true. Corresponds to the JSON property internalIp

Returns:

  • (Boolean)


2940
2941
2942
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2940

def internal_ip
  @internal_ip
end

#proxy_urlString

Optional. If set, used to configure a proxy to the Kubernetes server. Corresponds to the JSON property proxyUrl

Returns:

  • (String)


2948
2949
2950
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2948

def proxy_url
  @proxy_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2955
2956
2957
2958
2959
2960
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2955

def update!(**args)
  @cluster = args[:cluster] if args.key?(:cluster)
  @dns_endpoint = args[:dns_endpoint] if args.key?(:dns_endpoint)
  @internal_ip = args[:internal_ip] if args.key?(:internal_ip)
  @proxy_url = args[:proxy_url] if args.key?(:proxy_url)
end