Class: Google::Apis::ClouddeployV1::JobRun
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::JobRun
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
A JobRun resource in the Cloud Deploy API. A JobRun contains information
of a single Rollout job evaluation.
Instance Attribute Summary collapse
-
#advance_child_rollout_job_run ⇒ Google::Apis::ClouddeployV1::AdvanceChildRolloutJobRun
AdvanceChildRolloutJobRun contains information specific to a advanceChildRollout
JobRun. -
#analysis_job_run ⇒ Google::Apis::ClouddeployV1::AnalysisJobRun
AnalysisJobRun contains information specific to an analysis
JobRun. -
#create_child_rollout_job_run ⇒ Google::Apis::ClouddeployV1::CreateChildRolloutJobRun
CreateChildRolloutJobRun contains information specific to a createChildRollout
JobRun. -
#create_time ⇒ String
Output only.
-
#deploy_job_run ⇒ Google::Apis::ClouddeployV1::DeployJobRun
DeployJobRun contains information specific to a deploy
JobRun. -
#end_time ⇒ String
Output only.
-
#etag ⇒ String
Output only.
-
#job_id ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#phase_id ⇒ String
Output only.
-
#postdeploy_job_run ⇒ Google::Apis::ClouddeployV1::PostdeployJobRun
PostdeployJobRun contains information specific to a postdeploy
JobRun. -
#predeploy_job_run ⇒ Google::Apis::ClouddeployV1::PredeployJobRun
PredeployJobRun contains information specific to a predeploy
JobRun. -
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#verify_job_run ⇒ Google::Apis::ClouddeployV1::VerifyJobRun
VerifyJobRun contains information specific to a verify
JobRun.
Instance Method Summary collapse
-
#initialize(**args) ⇒ JobRun
constructor
A new instance of JobRun.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ JobRun
Returns a new instance of JobRun.
3200 3201 3202 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3200 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advance_child_rollout_job_run ⇒ Google::Apis::ClouddeployV1::AdvanceChildRolloutJobRun
AdvanceChildRolloutJobRun contains information specific to a
advanceChildRollout JobRun.
Corresponds to the JSON property advanceChildRolloutJobRun
3118 3119 3120 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3118 def advance_child_rollout_job_run @advance_child_rollout_job_run end |
#analysis_job_run ⇒ Google::Apis::ClouddeployV1::AnalysisJobRun
AnalysisJobRun contains information specific to an analysis JobRun.
Corresponds to the JSON property analysisJobRun
3123 3124 3125 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3123 def analysis_job_run @analysis_job_run end |
#create_child_rollout_job_run ⇒ Google::Apis::ClouddeployV1::CreateChildRolloutJobRun
CreateChildRolloutJobRun contains information specific to a createChildRollout
JobRun.
Corresponds to the JSON property createChildRolloutJobRun
3129 3130 3131 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3129 def create_child_rollout_job_run @create_child_rollout_job_run end |
#create_time ⇒ String
Output only. Time at which the JobRun was created.
Corresponds to the JSON property createTime
3134 3135 3136 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3134 def create_time @create_time end |
#deploy_job_run ⇒ Google::Apis::ClouddeployV1::DeployJobRun
DeployJobRun contains information specific to a deploy JobRun.
Corresponds to the JSON property deployJobRun
3139 3140 3141 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3139 def deploy_job_run @deploy_job_run end |
#end_time ⇒ String
Output only. Time at which the JobRun ended.
Corresponds to the JSON property endTime
3144 3145 3146 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3144 def end_time @end_time end |
#etag ⇒ String
Output only. This checksum is computed by the server based on the value of
other fields, and may be sent on update and delete requests to ensure the
client has an up-to-date value before proceeding.
Corresponds to the JSON property etag
3151 3152 3153 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3151 def etag @etag end |
#job_id ⇒ String
Output only. ID of the Rollout job this JobRun corresponds to.
Corresponds to the JSON property jobId
3156 3157 3158 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3156 def job_id @job_id end |
#name ⇒ String
Output only. Name of the JobRun. Format is projects/project/locations/
location/deliveryPipelines/deliveryPipeline/releases/releases/rollouts/
rollouts/jobRuns/uuid`.
Corresponds to the JSON propertyname`
3163 3164 3165 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3163 def name @name end |
#phase_id ⇒ String
Output only. ID of the Rollout phase this JobRun belongs in.
Corresponds to the JSON property phaseId
3168 3169 3170 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3168 def phase_id @phase_id end |
#postdeploy_job_run ⇒ Google::Apis::ClouddeployV1::PostdeployJobRun
PostdeployJobRun contains information specific to a postdeploy JobRun.
Corresponds to the JSON property postdeployJobRun
3173 3174 3175 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3173 def postdeploy_job_run @postdeploy_job_run end |
#predeploy_job_run ⇒ Google::Apis::ClouddeployV1::PredeployJobRun
PredeployJobRun contains information specific to a predeploy JobRun.
Corresponds to the JSON property predeployJobRun
3178 3179 3180 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3178 def predeploy_job_run @predeploy_job_run end |
#start_time ⇒ String
Output only. Time at which the JobRun was started.
Corresponds to the JSON property startTime
3183 3184 3185 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3183 def start_time @start_time end |
#state ⇒ String
Output only. The current state of the JobRun.
Corresponds to the JSON property state
3188 3189 3190 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3188 def state @state end |
#uid ⇒ String
Output only. Unique identifier of the JobRun.
Corresponds to the JSON property uid
3193 3194 3195 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3193 def uid @uid end |
#verify_job_run ⇒ Google::Apis::ClouddeployV1::VerifyJobRun
VerifyJobRun contains information specific to a verify JobRun.
Corresponds to the JSON property verifyJobRun
3198 3199 3200 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3198 def verify_job_run @verify_job_run end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3205 3206 3207 3208 3209 3210 3211 3212 3213 3214 3215 3216 3217 3218 3219 3220 3221 3222 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3205 def update!(**args) @advance_child_rollout_job_run = args[:advance_child_rollout_job_run] if args.key?(:advance_child_rollout_job_run) @analysis_job_run = args[:analysis_job_run] if args.key?(:analysis_job_run) @create_child_rollout_job_run = args[:create_child_rollout_job_run] if args.key?(:create_child_rollout_job_run) @create_time = args[:create_time] if args.key?(:create_time) @deploy_job_run = args[:deploy_job_run] if args.key?(:deploy_job_run) @end_time = args[:end_time] if args.key?(:end_time) @etag = args[:etag] if args.key?(:etag) @job_id = args[:job_id] if args.key?(:job_id) @name = args[:name] if args.key?(:name) @phase_id = args[:phase_id] if args.key?(:phase_id) @postdeploy_job_run = args[:postdeploy_job_run] if args.key?(:postdeploy_job_run) @predeploy_job_run = args[:predeploy_job_run] if args.key?(:predeploy_job_run) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) @verify_job_run = args[:verify_job_run] if args.key?(:verify_job_run) end |