Class: Google::Apis::ClouddeployV1::JobRun

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

A JobRun resource in the Cloud Deploy API. A JobRun contains information of a single Rollout job evaluation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JobRun

Returns a new instance of JobRun.



2744
2745
2746
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2744

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advance_child_rollout_job_runGoogle::Apis::ClouddeployV1::AdvanceChildRolloutJobRun

AdvanceChildRolloutJobRun contains information specific to a advanceChildRollout JobRun. Corresponds to the JSON property advanceChildRolloutJobRun



2667
2668
2669
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2667

def advance_child_rollout_job_run
  @advance_child_rollout_job_run
end

#create_child_rollout_job_runGoogle::Apis::ClouddeployV1::CreateChildRolloutJobRun

CreateChildRolloutJobRun contains information specific to a createChildRollout JobRun. Corresponds to the JSON property createChildRolloutJobRun



2673
2674
2675
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2673

def create_child_rollout_job_run
  @create_child_rollout_job_run
end

#create_timeString

Output only. Time at which the JobRun was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2678
2679
2680
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2678

def create_time
  @create_time
end

#deploy_job_runGoogle::Apis::ClouddeployV1::DeployJobRun

DeployJobRun contains information specific to a deploy JobRun. Corresponds to the JSON property deployJobRun



2683
2684
2685
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2683

def deploy_job_run
  @deploy_job_run
end

#end_timeString

Output only. Time at which the JobRun ended. Corresponds to the JSON property endTime

Returns:

  • (String)


2688
2689
2690
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2688

def end_time
  @end_time
end

#etagString

Output only. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


2695
2696
2697
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2695

def etag
  @etag
end

#job_idString

Output only. ID of the Rollout job this JobRun corresponds to. Corresponds to the JSON property jobId

Returns:

  • (String)


2700
2701
2702
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2700

def job_id
  @job_id
end

#nameString

Output only. Name of the JobRun. Format is projects/project/locations/ location/deliveryPipelines/deliveryPipeline/releases/releases/rollouts/ rollouts/jobRuns/uuid`. Corresponds to the JSON propertyname`

Returns:

  • (String)


2707
2708
2709
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2707

def name
  @name
end

#phase_idString

Output only. ID of the Rollout phase this JobRun belongs in. Corresponds to the JSON property phaseId

Returns:

  • (String)


2712
2713
2714
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2712

def phase_id
  @phase_id
end

#postdeploy_job_runGoogle::Apis::ClouddeployV1::PostdeployJobRun

PostdeployJobRun contains information specific to a postdeploy JobRun. Corresponds to the JSON property postdeployJobRun



2717
2718
2719
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2717

def postdeploy_job_run
  @postdeploy_job_run
end

#predeploy_job_runGoogle::Apis::ClouddeployV1::PredeployJobRun

PredeployJobRun contains information specific to a predeploy JobRun. Corresponds to the JSON property predeployJobRun



2722
2723
2724
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2722

def predeploy_job_run
  @predeploy_job_run
end

#start_timeString

Output only. Time at which the JobRun was started. Corresponds to the JSON property startTime

Returns:

  • (String)


2727
2728
2729
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2727

def start_time
  @start_time
end

#stateString

Output only. The current state of the JobRun. Corresponds to the JSON property state

Returns:

  • (String)


2732
2733
2734
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2732

def state
  @state
end

#uidString

Output only. Unique identifier of the JobRun. Corresponds to the JSON property uid

Returns:

  • (String)


2737
2738
2739
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2737

def uid
  @uid
end

#verify_job_runGoogle::Apis::ClouddeployV1::VerifyJobRun

VerifyJobRun contains information specific to a verify JobRun. Corresponds to the JSON property verifyJobRun



2742
2743
2744
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2742

def verify_job_run
  @verify_job_run
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2749
2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
2765
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2749

def update!(**args)
  @advance_child_rollout_job_run = args[:advance_child_rollout_job_run] if args.key?(:advance_child_rollout_job_run)
  @create_child_rollout_job_run = args[:create_child_rollout_job_run] if args.key?(:create_child_rollout_job_run)
  @create_time = args[:create_time] if args.key?(:create_time)
  @deploy_job_run = args[:deploy_job_run] if args.key?(:deploy_job_run)
  @end_time = args[:end_time] if args.key?(:end_time)
  @etag = args[:etag] if args.key?(:etag)
  @job_id = args[:job_id] if args.key?(:job_id)
  @name = args[:name] if args.key?(:name)
  @phase_id = args[:phase_id] if args.key?(:phase_id)
  @postdeploy_job_run = args[:postdeploy_job_run] if args.key?(:postdeploy_job_run)
  @predeploy_job_run = args[:predeploy_job_run] if args.key?(:predeploy_job_run)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @verify_job_run = args[:verify_job_run] if args.key?(:verify_job_run)
end