Class: Google::Apis::ClouddeployV1::JobRunNotificationEvent

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

Payload proto for "clouddeploy.googleapis.com/jobrun_notification" Platform Log event that describes the failure to send JobRun resource update Pub/Sub notification.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JobRunNotificationEvent

Returns a new instance of JobRunNotificationEvent.



2819
2820
2821
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2819

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#job_runString

The name of the JobRun. Corresponds to the JSON property jobRun

Returns:

  • (String)


2777
2778
2779
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2777

def job_run
  @job_run
end

#messageString

Debug message for when a notification fails to send. Corresponds to the JSON property message

Returns:

  • (String)


2782
2783
2784
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2782

def message
  @message
end

#pipeline_uidString

Unique identifier of the DeliveryPipeline. Corresponds to the JSON property pipelineUid

Returns:

  • (String)


2787
2788
2789
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2787

def pipeline_uid
  @pipeline_uid
end

#releaseString

The name of the Release. Corresponds to the JSON property release

Returns:

  • (String)


2792
2793
2794
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2792

def release
  @release
end

#release_uidString

Unique identifier of the Release. Corresponds to the JSON property releaseUid

Returns:

  • (String)


2797
2798
2799
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2797

def release_uid
  @release_uid
end

#rolloutString

The name of the Rollout. Corresponds to the JSON property rollout

Returns:

  • (String)


2802
2803
2804
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2802

def rollout
  @rollout
end

#rollout_uidString

Unique identifier of the Rollout. Corresponds to the JSON property rolloutUid

Returns:

  • (String)


2807
2808
2809
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2807

def rollout_uid
  @rollout_uid
end

#target_idString

ID of the Target. Corresponds to the JSON property targetId

Returns:

  • (String)


2812
2813
2814
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2812

def target_id
  @target_id
end

#typeString

Type of this notification, e.g. for a Pub/Sub failure. Corresponds to the JSON property type

Returns:

  • (String)


2817
2818
2819
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2817

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2824
2825
2826
2827
2828
2829
2830
2831
2832
2833
2834
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2824

def update!(**args)
  @job_run = args[:job_run] if args.key?(:job_run)
  @message = args[:message] if args.key?(:message)
  @pipeline_uid = args[:pipeline_uid] if args.key?(:pipeline_uid)
  @release = args[:release] if args.key?(:release)
  @release_uid = args[:release_uid] if args.key?(:release_uid)
  @rollout = args[:rollout] if args.key?(:rollout)
  @rollout_uid = args[:rollout_uid] if args.key?(:rollout_uid)
  @target_id = args[:target_id] if args.key?(:target_id)
  @type = args[:type] if args.key?(:type)
end