Class: Google::Apis::ClouddeployV1::JobRunNotificationEvent
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::JobRunNotificationEvent
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
Payload proto for "clouddeploy.googleapis.com/jobrun_notification" Platform Log event that describes the failure to send JobRun resource update Pub/Sub notification.
Instance Attribute Summary collapse
-
#job_run ⇒ String
The name of the
JobRun. -
#message ⇒ String
Debug message for when a notification fails to send.
-
#pipeline_uid ⇒ String
Unique identifier of the
DeliveryPipeline. -
#release ⇒ String
The name of the
Release. -
#release_uid ⇒ String
Unique identifier of the
Release. -
#rollout ⇒ String
The name of the
Rollout. -
#rollout_uid ⇒ String
Unique identifier of the
Rollout. -
#target_id ⇒ String
ID of the
Target. -
#type ⇒ String
Type of this notification, e.g.
Instance Method Summary collapse
-
#initialize(**args) ⇒ JobRunNotificationEvent
constructor
A new instance of JobRunNotificationEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ JobRunNotificationEvent
Returns a new instance of JobRunNotificationEvent.
2799 2800 2801 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2799 def initialize(**args) update!(**args) end |
Instance Attribute Details
#job_run ⇒ String
The name of the JobRun.
Corresponds to the JSON property jobRun
2757 2758 2759 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2757 def job_run @job_run end |
#message ⇒ String
Debug message for when a notification fails to send.
Corresponds to the JSON property message
2762 2763 2764 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2762 def @message end |
#pipeline_uid ⇒ String
Unique identifier of the DeliveryPipeline.
Corresponds to the JSON property pipelineUid
2767 2768 2769 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2767 def pipeline_uid @pipeline_uid end |
#release ⇒ String
The name of the Release.
Corresponds to the JSON property release
2772 2773 2774 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2772 def release @release end |
#release_uid ⇒ String
Unique identifier of the Release.
Corresponds to the JSON property releaseUid
2777 2778 2779 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2777 def release_uid @release_uid end |
#rollout ⇒ String
The name of the Rollout.
Corresponds to the JSON property rollout
2782 2783 2784 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2782 def rollout @rollout end |
#rollout_uid ⇒ String
Unique identifier of the Rollout.
Corresponds to the JSON property rolloutUid
2787 2788 2789 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2787 def rollout_uid @rollout_uid end |
#target_id ⇒ String
ID of the Target.
Corresponds to the JSON property targetId
2792 2793 2794 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2792 def target_id @target_id end |
#type ⇒ String
Type of this notification, e.g. for a Pub/Sub failure.
Corresponds to the JSON property type
2797 2798 2799 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2797 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2804 2805 2806 2807 2808 2809 2810 2811 2812 2813 2814 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 2804 def update!(**args) @job_run = args[:job_run] if args.key?(:job_run) @message = args[:message] if args.key?(:message) @pipeline_uid = args[:pipeline_uid] if args.key?(:pipeline_uid) @release = args[:release] if args.key?(:release) @release_uid = args[:release_uid] if args.key?(:release_uid) @rollout = args[:rollout] if args.key?(:rollout) @rollout_uid = args[:rollout_uid] if args.key?(:rollout_uid) @target_id = args[:target_id] if args.key?(:target_id) @type = args[:type] if args.key?(:type) end |