Class: Google::Apis::ClouddeployV1::OneTimeWindow
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::OneTimeWindow
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
One-time window within which actions are restricted. For example, blocking actions over New Year's Eve from December 31st at 5pm to January 1st at 9am.
Instance Attribute Summary collapse
-
#end_date ⇒ Google::Apis::ClouddeployV1::Date
Represents a whole or partial calendar date, such as a birthday.
-
#end_time ⇒ Google::Apis::ClouddeployV1::TimeOfDay
Represents a time of day.
-
#start_date ⇒ Google::Apis::ClouddeployV1::Date
Represents a whole or partial calendar date, such as a birthday.
-
#start_time ⇒ Google::Apis::ClouddeployV1::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OneTimeWindow
constructor
A new instance of OneTimeWindow.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OneTimeWindow
Returns a new instance of OneTimeWindow.
3843 3844 3845 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3843 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_date ⇒ Google::Apis::ClouddeployV1::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property endDate
3815 3816 3817 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3815 def end_date @end_date end |
#end_time ⇒ Google::Apis::ClouddeployV1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property endTime
3822 3823 3824 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3822 def end_time @end_time end |
#start_date ⇒ Google::Apis::ClouddeployV1::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property startDate
3834 3835 3836 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3834 def start_date @start_date end |
#start_time ⇒ Google::Apis::ClouddeployV1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property startTime
3841 3842 3843 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3841 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3848 3849 3850 3851 3852 3853 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3848 def update!(**args) @end_date = args[:end_date] if args.key?(:end_date) @end_time = args[:end_time] if args.key?(:end_time) @start_date = args[:start_date] if args.key?(:start_date) @start_time = args[:start_time] if args.key?(:start_time) end |