Class: Google::Apis::ClouddeployV1::OneTimeWindow
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::OneTimeWindow
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
One-time window within which actions are restricted. For example, blocking actions over New Year's Eve from December 31st at 5pm to January 1st at 9am.
Instance Attribute Summary collapse
-
#end_date ⇒ Google::Apis::ClouddeployV1::Date
Represents a whole or partial calendar date, such as a birthday.
-
#end_time ⇒ Google::Apis::ClouddeployV1::TimeOfDay
Represents a time of day.
-
#start_date ⇒ Google::Apis::ClouddeployV1::Date
Represents a whole or partial calendar date, such as a birthday.
-
#start_time ⇒ Google::Apis::ClouddeployV1::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OneTimeWindow
constructor
A new instance of OneTimeWindow.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OneTimeWindow
Returns a new instance of OneTimeWindow.
3350 3351 3352 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3350 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_date ⇒ Google::Apis::ClouddeployV1::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property endDate
3322 3323 3324 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3322 def end_date @end_date end |
#end_time ⇒ Google::Apis::ClouddeployV1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property endTime
3329 3330 3331 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3329 def end_time @end_time end |
#start_date ⇒ Google::Apis::ClouddeployV1::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property startDate
3341 3342 3343 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3341 def start_date @start_date end |
#start_time ⇒ Google::Apis::ClouddeployV1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property startTime
3348 3349 3350 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3348 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3355 3356 3357 3358 3359 3360 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3355 def update!(**args) @end_date = args[:end_date] if args.key?(:end_date) @end_time = args[:end_time] if args.key?(:end_time) @start_date = args[:start_date] if args.key?(:start_date) @start_time = args[:start_time] if args.key?(:start_time) end |