Class: Google::Apis::ClouddeployV1::PhaseArtifact
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::PhaseArtifact
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
Contains the paths to the artifacts, relative to the URI, for a phase.
Instance Attribute Summary collapse
-
#job_manifests_path ⇒ String
Output only.
-
#manifest_path ⇒ String
Output only.
-
#skaffold_config_path ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PhaseArtifact
constructor
A new instance of PhaseArtifact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PhaseArtifact
Returns a new instance of PhaseArtifact.
3549 3550 3551 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3549 def initialize(**args) update!(**args) end |
Instance Attribute Details
#job_manifests_path ⇒ String
Output only. File path of the directory of rendered job manifests relative to
the URI. This is only set if it is applicable.
Corresponds to the JSON property jobManifestsPath
3536 3537 3538 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3536 def job_manifests_path @job_manifests_path end |
#manifest_path ⇒ String
Output only. File path of the rendered manifest relative to the URI.
Corresponds to the JSON property manifestPath
3541 3542 3543 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3541 def manifest_path @manifest_path end |
#skaffold_config_path ⇒ String
Output only. File path of the resolved Skaffold configuration relative to the
URI.
Corresponds to the JSON property skaffoldConfigPath
3547 3548 3549 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3547 def skaffold_config_path @skaffold_config_path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3554 3555 3556 3557 3558 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3554 def update!(**args) @job_manifests_path = args[:job_manifests_path] if args.key?(:job_manifests_path) @manifest_path = args[:manifest_path] if args.key?(:manifest_path) @skaffold_config_path = args[:skaffold_config_path] if args.key?(:skaffold_config_path) end |