Class: Google::Apis::ClouddeployV1::PhaseArtifact

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

Contains the paths to the artifacts, relative to the URI, for a phase.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PhaseArtifact

Returns a new instance of PhaseArtifact.



3529
3530
3531
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3529

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#job_manifests_pathString

Output only. File path of the directory of rendered job manifests relative to the URI. This is only set if it is applicable. Corresponds to the JSON property jobManifestsPath

Returns:

  • (String)


3516
3517
3518
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3516

def job_manifests_path
  @job_manifests_path
end

#manifest_pathString

Output only. File path of the rendered manifest relative to the URI. Corresponds to the JSON property manifestPath

Returns:

  • (String)


3521
3522
3523
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3521

def manifest_path
  @manifest_path
end

#skaffold_config_pathString

Output only. File path of the resolved Skaffold configuration relative to the URI. Corresponds to the JSON property skaffoldConfigPath

Returns:

  • (String)


3527
3528
3529
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3527

def skaffold_config_path
  @skaffold_config_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3534
3535
3536
3537
3538
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3534

def update!(**args)
  @job_manifests_path = args[:job_manifests_path] if args.key?(:job_manifests_path)
  @manifest_path = args[:manifest_path] if args.key?(:manifest_path)
  @skaffold_config_path = args[:skaffold_config_path] if args.key?(:skaffold_config_path)
end