Class: Google::Apis::ClouddeployV1::PhaseConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

PhaseConfig represents the configuration for a phase in the custom canary deployment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PhaseConfig

Returns a new instance of PhaseConfig.



4107
4108
4109
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4107

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysisGoogle::Apis::ClouddeployV1::Analysis

Analysis contains the configuration for the set of analyses to be performed on the target. Corresponds to the JSON property analysis



4063
4064
4065
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4063

def analysis
  @analysis
end

#percentageFixnum

Required. Percentage deployment for the phase. Corresponds to the JSON property percentage

Returns:

  • (Fixnum)


4068
4069
4070
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4068

def percentage
  @percentage
end

#phase_idString

Required. The ID to assign to the Rollout phase. This value must consist of lower-case letters, numbers, and hyphens, start with a letter and end with a letter or a number, and have a max length of 63 characters. In other words, it must match the following regex: ^[a-z]([a-z0-9-]0,61[a-z0-9])?$. Corresponds to the JSON property phaseId

Returns:

  • (String)


4076
4077
4078
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4076

def phase_id
  @phase_id
end

#postdeployGoogle::Apis::ClouddeployV1::Postdeploy

Postdeploy contains the postdeploy job configuration information. Corresponds to the JSON property postdeploy



4081
4082
4083
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4081

def postdeploy
  @postdeploy
end

#predeployGoogle::Apis::ClouddeployV1::Predeploy

Predeploy contains the predeploy job configuration information. Corresponds to the JSON property predeploy



4086
4087
4088
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4086

def predeploy
  @predeploy
end

#profilesArray<String>

Optional. Skaffold profiles to use when rendering the manifest for this phase. These are in addition to the profiles list specified in the DeliveryPipeline stage. Corresponds to the JSON property profiles

Returns:

  • (Array<String>)


4093
4094
4095
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4093

def profiles
  @profiles
end

#verifyBoolean Also known as: verify?

Optional. Whether to run verify tests after the deployment via skaffold verify. Corresponds to the JSON property verify

Returns:

  • (Boolean)


4099
4100
4101
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4099

def verify
  @verify
end

#verify_configGoogle::Apis::ClouddeployV1::Verify

Verify contains the verify job configuration information. Corresponds to the JSON property verifyConfig



4105
4106
4107
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4105

def verify_config
  @verify_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4112
4113
4114
4115
4116
4117
4118
4119
4120
4121
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4112

def update!(**args)
  @analysis = args[:analysis] if args.key?(:analysis)
  @percentage = args[:percentage] if args.key?(:percentage)
  @phase_id = args[:phase_id] if args.key?(:phase_id)
  @postdeploy = args[:postdeploy] if args.key?(:postdeploy)
  @predeploy = args[:predeploy] if args.key?(:predeploy)
  @profiles = args[:profiles] if args.key?(:profiles)
  @verify = args[:verify] if args.key?(:verify)
  @verify_config = args[:verify_config] if args.key?(:verify_config)
end