Class: Google::Apis::ClouddeployV1::PhaseConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

PhaseConfig represents the configuration for a phase in the custom canary deployment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PhaseConfig

Returns a new instance of PhaseConfig.



3603
3604
3605
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3603

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#percentageFixnum

Required. Percentage deployment for the phase. Corresponds to the JSON property percentage

Returns:

  • (Fixnum)


3569
3570
3571
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3569

def percentage
  @percentage
end

#phase_idString

Required. The ID to assign to the Rollout phase. This value must consist of lower-case letters, numbers, and hyphens, start with a letter and end with a letter or a number, and have a max length of 63 characters. In other words, it must match the following regex: ^[a-z]([a-z0-9-]0,61[a-z0-9])?$. Corresponds to the JSON property phaseId

Returns:

  • (String)


3577
3578
3579
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3577

def phase_id
  @phase_id
end

#postdeployGoogle::Apis::ClouddeployV1::Postdeploy

Postdeploy contains the postdeploy job configuration information. Corresponds to the JSON property postdeploy



3582
3583
3584
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3582

def postdeploy
  @postdeploy
end

#predeployGoogle::Apis::ClouddeployV1::Predeploy

Predeploy contains the predeploy job configuration information. Corresponds to the JSON property predeploy



3587
3588
3589
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3587

def predeploy
  @predeploy
end

#profilesArray<String>

Optional. Skaffold profiles to use when rendering the manifest for this phase. These are in addition to the profiles list specified in the DeliveryPipeline stage. Corresponds to the JSON property profiles

Returns:

  • (Array<String>)


3594
3595
3596
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3594

def profiles
  @profiles
end

#verifyBoolean Also known as: verify?

Optional. Whether to run verify tests after the deployment via skaffold verify. Corresponds to the JSON property verify

Returns:

  • (Boolean)


3600
3601
3602
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3600

def verify
  @verify
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3608
3609
3610
3611
3612
3613
3614
3615
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3608

def update!(**args)
  @percentage = args[:percentage] if args.key?(:percentage)
  @phase_id = args[:phase_id] if args.key?(:phase_id)
  @postdeploy = args[:postdeploy] if args.key?(:postdeploy)
  @predeploy = args[:predeploy] if args.key?(:predeploy)
  @profiles = args[:profiles] if args.key?(:profiles)
  @verify = args[:verify] if args.key?(:verify)
end