Class: Google::Apis::ClouddeployV1::PhaseConfig
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::PhaseConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
PhaseConfig represents the configuration for a phase in the custom canary deployment.
Instance Attribute Summary collapse
-
#percentage ⇒ Fixnum
Required.
-
#phase_id ⇒ String
Required.
-
#postdeploy ⇒ Google::Apis::ClouddeployV1::Postdeploy
Postdeploy contains the postdeploy job configuration information.
-
#predeploy ⇒ Google::Apis::ClouddeployV1::Predeploy
Predeploy contains the predeploy job configuration information.
-
#profiles ⇒ Array<String>
Optional.
-
#verify ⇒ Boolean
(also: #verify?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PhaseConfig
constructor
A new instance of PhaseConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PhaseConfig
Returns a new instance of PhaseConfig.
3583 3584 3585 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3583 def initialize(**args) update!(**args) end |
Instance Attribute Details
#percentage ⇒ Fixnum
Required. Percentage deployment for the phase.
Corresponds to the JSON property percentage
3549 3550 3551 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3549 def percentage @percentage end |
#phase_id ⇒ String
Required. The ID to assign to the Rollout phase. This value must consist of
lower-case letters, numbers, and hyphens, start with a letter and end with a
letter or a number, and have a max length of 63 characters. In other words, it
must match the following regex: ^[a-z]([a-z0-9-]0,61[a-z0-9])?$.
Corresponds to the JSON property phaseId
3557 3558 3559 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3557 def phase_id @phase_id end |
#postdeploy ⇒ Google::Apis::ClouddeployV1::Postdeploy
Postdeploy contains the postdeploy job configuration information.
Corresponds to the JSON property postdeploy
3562 3563 3564 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3562 def postdeploy @postdeploy end |
#predeploy ⇒ Google::Apis::ClouddeployV1::Predeploy
Predeploy contains the predeploy job configuration information.
Corresponds to the JSON property predeploy
3567 3568 3569 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3567 def predeploy @predeploy end |
#profiles ⇒ Array<String>
Optional. Skaffold profiles to use when rendering the manifest for this phase.
These are in addition to the profiles list specified in the DeliveryPipeline
stage.
Corresponds to the JSON property profiles
3574 3575 3576 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3574 def profiles @profiles end |
#verify ⇒ Boolean Also known as: verify?
Optional. Whether to run verify tests after the deployment via skaffold
verify.
Corresponds to the JSON property verify
3580 3581 3582 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3580 def verify @verify end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3588 3589 3590 3591 3592 3593 3594 3595 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3588 def update!(**args) @percentage = args[:percentage] if args.key?(:percentage) @phase_id = args[:phase_id] if args.key?(:phase_id) @postdeploy = args[:postdeploy] if args.key?(:postdeploy) @predeploy = args[:predeploy] if args.key?(:predeploy) @profiles = args[:profiles] if args.key?(:profiles) @verify = args[:verify] if args.key?(:verify) end |