Class: Google::Apis::ClouddeployV1::PolicyViolation
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::PolicyViolation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
Returned from an action if one or more policies were violated, and therefore the action was prevented. Contains information about what policies were violated and why.
Instance Attribute Summary collapse
-
#policy_violation_details ⇒ Array<Google::Apis::ClouddeployV1::PolicyViolationDetails>
Policy violation details.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PolicyViolation
constructor
A new instance of PolicyViolation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PolicyViolation
Returns a new instance of PolicyViolation.
3785 3786 3787 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3785 def initialize(**args) update!(**args) end |
Instance Attribute Details
#policy_violation_details ⇒ Array<Google::Apis::ClouddeployV1::PolicyViolationDetails>
Policy violation details.
Corresponds to the JSON property policyViolationDetails
3783 3784 3785 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3783 def policy_violation_details @policy_violation_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3790 3791 3792 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3790 def update!(**args) @policy_violation_details = args[:policy_violation_details] if args.key?(:policy_violation_details) end |