Class: Google::Apis::ClouddeployV1::Postdeploy
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::Postdeploy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
Postdeploy contains the postdeploy job configuration information.
Instance Attribute Summary collapse
-
#actions ⇒ Array<String>
Optional.
-
#tasks ⇒ Array<Google::Apis::ClouddeployV1::Task>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Postdeploy
constructor
A new instance of Postdeploy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Postdeploy
Returns a new instance of Postdeploy.
4378 4379 4380 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4378 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actions ⇒ Array<String>
Optional. A sequence of Skaffold custom actions to invoke during execution of
the postdeploy job.
Corresponds to the JSON property actions
4369 4370 4371 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4369 def actions @actions end |
#tasks ⇒ Array<Google::Apis::ClouddeployV1::Task>
Optional. The tasks that will run as a part of the postdeploy job. The tasks
are executed sequentially in the order specified. Only one of actions or
tasks can be specified.
Corresponds to the JSON property tasks
4376 4377 4378 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4376 def tasks @tasks end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4383 4384 4385 4386 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4383 def update!(**args) @actions = args[:actions] if args.key?(:actions) @tasks = args[:tasks] if args.key?(:tasks) end |