Class: Google::Apis::ClouddeployV1::PostdeployJobRun
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::PostdeployJobRun
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
PostdeployJobRun contains information specific to a postdeploy JobRun.
Instance Attribute Summary collapse
-
#build ⇒ String
Output only.
-
#failure_cause ⇒ String
Output only.
-
#failure_message ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PostdeployJobRun
constructor
A new instance of PostdeployJobRun.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PostdeployJobRun
Returns a new instance of PostdeployJobRun.
3889 3890 3891 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3889 def initialize(**args) update!(**args) end |
Instance Attribute Details
#build ⇒ String
Output only. The resource name of the Cloud Build Build object that is used
to execute the custom actions associated with the postdeploy Job. Format is
projects/project/locations/location/builds/build`.
Corresponds to the JSON propertybuild`
3876 3877 3878 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3876 def build @build end |
#failure_cause ⇒ String
Output only. The reason the postdeploy failed. This will always be unspecified
while the postdeploy is in progress or if it succeeded.
Corresponds to the JSON property failureCause
3882 3883 3884 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3882 def failure_cause @failure_cause end |
#failure_message ⇒ String
Output only. Additional information about the postdeploy failure, if available.
Corresponds to the JSON property failureMessage
3887 3888 3889 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3887 def @failure_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3894 3895 3896 3897 3898 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3894 def update!(**args) @build = args[:build] if args.key?(:build) @failure_cause = args[:failure_cause] if args.key?(:failure_cause) @failure_message = args[:failure_message] if args.key?(:failure_message) end |