Class: Google::Apis::ClouddeployV1::PredeployJobRun
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::PredeployJobRun
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
PredeployJobRun contains information specific to a predeploy JobRun.
Instance Attribute Summary collapse
-
#build ⇒ String
Output only.
-
#failure_cause ⇒ String
Output only.
-
#failure_message ⇒ String
Output only.
-
#metadata ⇒ Google::Apis::ClouddeployV1::PredeployJobRunMetadata
PredeployJobRunMetadata contains metadata about the predeploy
JobRun.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PredeployJobRun
constructor
A new instance of PredeployJobRun.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PredeployJobRun
Returns a new instance of PredeployJobRun.
4553 4554 4555 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4553 def initialize(**args) update!(**args) end |
Instance Attribute Details
#build ⇒ String
Output only. The resource name of the Cloud Build Build object that is used
to execute the custom actions associated with the predeploy Job. Format is
projects/project/locations/location/builds/build`.
Corresponds to the JSON propertybuild`
4535 4536 4537 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4535 def build @build end |
#failure_cause ⇒ String
Output only. The reason the predeploy failed. This will always be unspecified
while the predeploy is in progress or if it succeeded.
Corresponds to the JSON property failureCause
4541 4542 4543 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4541 def failure_cause @failure_cause end |
#failure_message ⇒ String
Output only. Additional information about the predeploy failure, if available.
Corresponds to the JSON property failureMessage
4546 4547 4548 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4546 def @failure_message end |
#metadata ⇒ Google::Apis::ClouddeployV1::PredeployJobRunMetadata
PredeployJobRunMetadata contains metadata about the predeploy JobRun.
Corresponds to the JSON property metadata
4551 4552 4553 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4551 def @metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4558 4559 4560 4561 4562 4563 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4558 def update!(**args) @build = args[:build] if args.key?(:build) @failure_cause = args[:failure_cause] if args.key?(:failure_cause) @failure_message = args[:failure_message] if args.key?(:failure_message) @metadata = args[:metadata] if args.key?(:metadata) end |