Class: Google::Apis::ClouddeployV1::PredeployJobRun
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::PredeployJobRun
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
PredeployJobRun contains information specific to a predeploy JobRun.
Instance Attribute Summary collapse
-
#build ⇒ String
Output only.
-
#failure_cause ⇒ String
Output only.
-
#failure_message ⇒ String
Output only.
-
#metadata ⇒ Google::Apis::ClouddeployV1::PredeployJobRunMetadata
PredeployJobRunMetadata contains metadata about the predeploy
JobRun.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PredeployJobRun
constructor
A new instance of PredeployJobRun.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PredeployJobRun
Returns a new instance of PredeployJobRun.
4546 4547 4548 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4546 def initialize(**args) update!(**args) end |
Instance Attribute Details
#build ⇒ String
Output only. The resource name of the Cloud Build Build object that is used
to execute the custom actions associated with the predeploy Job. Format is
projects/project/locations/location/builds/build`.
Corresponds to the JSON propertybuild`
4528 4529 4530 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4528 def build @build end |
#failure_cause ⇒ String
Output only. The reason the predeploy failed. This will always be unspecified
while the predeploy is in progress or if it succeeded.
Corresponds to the JSON property failureCause
4534 4535 4536 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4534 def failure_cause @failure_cause end |
#failure_message ⇒ String
Output only. Additional information about the predeploy failure, if available.
Corresponds to the JSON property failureMessage
4539 4540 4541 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4539 def @failure_message end |
#metadata ⇒ Google::Apis::ClouddeployV1::PredeployJobRunMetadata
PredeployJobRunMetadata contains metadata about the predeploy JobRun.
Corresponds to the JSON property metadata
4544 4545 4546 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4544 def @metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4551 4552 4553 4554 4555 4556 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4551 def update!(**args) @build = args[:build] if args.key?(:build) @failure_cause = args[:failure_cause] if args.key?(:failure_cause) @failure_message = args[:failure_message] if args.key?(:failure_message) @metadata = args[:metadata] if args.key?(:metadata) end |