Class: Google::Apis::ClouddeployV1::PredeployJobRun
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::PredeployJobRun
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
PredeployJobRun contains information specific to a predeploy JobRun.
Instance Attribute Summary collapse
-
#build ⇒ String
Output only.
-
#failure_cause ⇒ String
Output only.
-
#failure_message ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PredeployJobRun
constructor
A new instance of PredeployJobRun.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PredeployJobRun
Returns a new instance of PredeployJobRun.
3962 3963 3964 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3962 def initialize(**args) update!(**args) end |
Instance Attribute Details
#build ⇒ String
Output only. The resource name of the Cloud Build Build object that is used
to execute the custom actions associated with the predeploy Job. Format is
projects/project/locations/location/builds/build`.
Corresponds to the JSON propertybuild`
3949 3950 3951 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3949 def build @build end |
#failure_cause ⇒ String
Output only. The reason the predeploy failed. This will always be unspecified
while the predeploy is in progress or if it succeeded.
Corresponds to the JSON property failureCause
3955 3956 3957 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3955 def failure_cause @failure_cause end |
#failure_message ⇒ String
Output only. Additional information about the predeploy failure, if available.
Corresponds to the JSON property failureMessage
3960 3961 3962 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3960 def @failure_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3967 3968 3969 3970 3971 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 3967 def update!(**args) @build = args[:build] if args.key?(:build) @failure_cause = args[:failure_cause] if args.key?(:failure_cause) @failure_message = args[:failure_message] if args.key?(:failure_message) end |