Class: Google::Apis::ClouddeployV1::PromoteReleaseRule
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::PromoteReleaseRule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
The PromoteRelease rule will automatically promote a release from the
current target to a specified target.
Instance Attribute Summary collapse
-
#condition ⇒ Google::Apis::ClouddeployV1::AutomationRuleCondition
AutomationRuleConditioncontains conditions relevant to anAutomationrule. -
#destination_phase ⇒ String
Optional.
-
#destination_target_id ⇒ String
Optional.
-
#id ⇒ String
Required.
-
#wait ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PromoteReleaseRule
constructor
A new instance of PromoteReleaseRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PromoteReleaseRule
Returns a new instance of PromoteReleaseRule.
4690 4691 4692 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4690 def initialize(**args) update!(**args) end |
Instance Attribute Details
#condition ⇒ Google::Apis::ClouddeployV1::AutomationRuleCondition
AutomationRuleCondition contains conditions relevant to an Automation rule.
Corresponds to the JSON property condition
4662 4663 4664 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4662 def condition @condition end |
#destination_phase ⇒ String
Optional. The starting phase of the rollout created by this operation. Default
to the first phase.
Corresponds to the JSON property destinationPhase
4668 4669 4670 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4668 def destination_phase @destination_phase end |
#destination_target_id ⇒ String
Optional. The ID of the stage in the pipeline to which this Release is
deploying. If unspecified, default it to the next stage in the promotion flow.
The value of this field could be one of the following: * The last segment of a
target name * "@next", the next target in the promotion sequence
Corresponds to the JSON property destinationTargetId
4676 4677 4678 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4676 def destination_target_id @destination_target_id end |
#id ⇒ String
Required. ID of the rule. This id must be unique in the Automation resource
to which this rule belongs. The format is [a-z]([a-z0-9-]0,61[a-z0-9])?.
Corresponds to the JSON property id
4682 4683 4684 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4682 def id @id end |
#wait ⇒ String
Optional. How long the release need to be paused until being promoted to the
next target.
Corresponds to the JSON property wait
4688 4689 4690 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4688 def wait @wait end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4695 4696 4697 4698 4699 4700 4701 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4695 def update!(**args) @condition = args[:condition] if args.key?(:condition) @destination_phase = args[:destination_phase] if args.key?(:destination_phase) @destination_target_id = args[:destination_target_id] if args.key?(:destination_target_id) @id = args[:id] if args.key?(:id) @wait = args[:wait] if args.key?(:wait) end |