Class: Google::Apis::ClouddeployV1::PromoteReleaseRule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

The PromoteRelease rule will automatically promote a release from the current target to a specified target.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PromoteReleaseRule

Returns a new instance of PromoteReleaseRule.



4086
4087
4088
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4086

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionGoogle::Apis::ClouddeployV1::AutomationRuleCondition

AutomationRuleCondition contains conditions relevant to an Automation rule. Corresponds to the JSON property condition



4058
4059
4060
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4058

def condition
  @condition
end

#destination_phaseString

Optional. The starting phase of the rollout created by this operation. Default to the first phase. Corresponds to the JSON property destinationPhase

Returns:

  • (String)


4064
4065
4066
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4064

def destination_phase
  @destination_phase
end

#destination_target_idString

Optional. The ID of the stage in the pipeline to which this Release is deploying. If unspecified, default it to the next stage in the promotion flow. The value of this field could be one of the following: * The last segment of a target name * "@next", the next target in the promotion sequence Corresponds to the JSON property destinationTargetId

Returns:

  • (String)


4072
4073
4074
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4072

def destination_target_id
  @destination_target_id
end

#idString

Required. ID of the rule. This id must be unique in the Automation resource to which this rule belongs. The format is [a-z]([a-z0-9-]0,61[a-z0-9])?. Corresponds to the JSON property id

Returns:

  • (String)


4078
4079
4080
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4078

def id
  @id
end

#waitString

Optional. How long the release need to be paused until being promoted to the next target. Corresponds to the JSON property wait

Returns:

  • (String)


4084
4085
4086
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4084

def wait
  @wait
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4091
4092
4093
4094
4095
4096
4097
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4091

def update!(**args)
  @condition = args[:condition] if args.key?(:condition)
  @destination_phase = args[:destination_phase] if args.key?(:destination_phase)
  @destination_target_id = args[:destination_target_id] if args.key?(:destination_target_id)
  @id = args[:id] if args.key?(:id)
  @wait = args[:wait] if args.key?(:wait)
end