Class: Google::Apis::ClouddeployV1::Release

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

A Release resource in the Cloud Deploy API. A Release defines a specific Skaffold configuration instance that can be deployed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Release

Returns a new instance of Release.



4844
4845
4846
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4844

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#abandonedBoolean Also known as: abandoned?

Output only. Indicates whether this is an abandoned release. Corresponds to the JSON property abandoned

Returns:

  • (Boolean)


4712
4713
4714
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4712

def abandoned
  @abandoned
end

#annotationsHash<String,String>

Optional. User annotations. These attributes can only be set and used by the user, and not by Cloud Deploy. See https://google.aip.dev/128#annotations for more details such as format and size limitations. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


4720
4721
4722
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4720

def annotations
  @annotations
end

#build_artifactsArray<Google::Apis::ClouddeployV1::BuildArtifact>

Optional. List of artifacts to pass through to Skaffold command. Corresponds to the JSON property buildArtifacts



4725
4726
4727
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4725

def build_artifacts
  @build_artifacts
end

#conditionGoogle::Apis::ClouddeployV1::ReleaseCondition

ReleaseCondition contains all conditions relevant to a Release. Corresponds to the JSON property condition



4730
4731
4732
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4730

def condition
  @condition
end

#create_timeString

Output only. Time at which the Release was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4735
4736
4737
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4735

def create_time
  @create_time
end

#custom_target_type_snapshotsArray<Google::Apis::ClouddeployV1::CustomTargetType>

Output only. Snapshot of the custom target types referenced by the targets taken at release creation time. Corresponds to the JSON property customTargetTypeSnapshots



4741
4742
4743
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4741

def custom_target_type_snapshots
  @custom_target_type_snapshots
end

#delivery_pipeline_snapshotGoogle::Apis::ClouddeployV1::DeliveryPipeline

A DeliveryPipeline resource in the Cloud Deploy API. A DeliveryPipeline defines a pipeline through which a Skaffold configuration can progress. Corresponds to the JSON property deliveryPipelineSnapshot



4747
4748
4749
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4747

def delivery_pipeline_snapshot
  @delivery_pipeline_snapshot
end

#deploy_parametersHash<String,String>

Optional. The deploy parameters to use for all targets in this release. Corresponds to the JSON property deployParameters

Returns:

  • (Hash<String,String>)


4752
4753
4754
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4752

def deploy_parameters
  @deploy_parameters
end

#descriptionString

Optional. Description of the Release. Max length is 255 characters. Corresponds to the JSON property description

Returns:

  • (String)


4757
4758
4759
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4757

def description
  @description
end

#etagString

This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up- to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


4764
4765
4766
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4764

def etag
  @etag
end

#labelsHash<String,String>

Labels are attributes that can be set and used by both the user and by Cloud Deploy. Labels must meet the following constraints: * Keys and values can contain only lowercase letters, numeric characters, underscores, and dashes. * All characters must use UTF-8 encoding, and international characters are allowed. * Keys must start with a lowercase letter or international character.

  • Each resource is limited to a maximum of 64 labels. Both keys and values are additionally constrained to be <= 128 bytes. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4775
4776
4777
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4775

def labels
  @labels
end

#nameString

Identifier. Name of the Release. Format is projects/project/locations/ location/deliveryPipelines/deliveryPipeline/releases/release`. The releasecomponent must matcha-z? Corresponds to the JSON propertyname`

Returns:

  • (String)


4782
4783
4784
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4782

def name
  @name
end

#render_end_timeString

Output only. Time at which the render completed. Corresponds to the JSON property renderEndTime

Returns:

  • (String)


4787
4788
4789
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4787

def render_end_time
  @render_end_time
end

#render_start_timeString

Output only. Time at which the render began. Corresponds to the JSON property renderStartTime

Returns:

  • (String)


4792
4793
4794
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4792

def render_start_time
  @render_start_time
end

#render_stateString

Output only. Current state of the render operation. Corresponds to the JSON property renderState

Returns:

  • (String)


4797
4798
4799
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4797

def render_state
  @render_state
end

#skaffold_config_pathString

Optional. Filepath of the Skaffold config inside of the config URI. Corresponds to the JSON property skaffoldConfigPath

Returns:

  • (String)


4802
4803
4804
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4802

def skaffold_config_path
  @skaffold_config_path
end

#skaffold_config_uriString

Optional. Cloud Storage URI of tar.gz archive containing Skaffold configuration. Corresponds to the JSON property skaffoldConfigUri

Returns:

  • (String)


4808
4809
4810
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4808

def skaffold_config_uri
  @skaffold_config_uri
end

#skaffold_versionString

Optional. The Skaffold version to use when operating on this release, such as " 1.20.0". Not all versions are valid; Cloud Deploy supports a specific set of versions. If unset, the most recent supported Skaffold version will be used. Corresponds to the JSON property skaffoldVersion

Returns:

  • (String)


4815
4816
4817
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4815

def skaffold_version
  @skaffold_version
end

#target_artifactsHash<String,Google::Apis::ClouddeployV1::TargetArtifact>

Output only. Map from target ID to the target artifacts created during the render operation. Corresponds to the JSON property targetArtifacts



4821
4822
4823
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4821

def target_artifacts
  @target_artifacts
end

#target_rendersHash<String,Google::Apis::ClouddeployV1::TargetRender>

Output only. Map from target ID to details of the render operation for that target. Corresponds to the JSON property targetRenders



4827
4828
4829
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4827

def target_renders
  @target_renders
end

#target_snapshotsArray<Google::Apis::ClouddeployV1::Target>

Output only. Snapshot of the targets taken at release creation time. Corresponds to the JSON property targetSnapshots



4832
4833
4834
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4832

def target_snapshots
  @target_snapshots
end

#tool_versionsGoogle::Apis::ClouddeployV1::ToolVersions

Details of ToolVersions for the release. Corresponds to the JSON property toolVersions



4837
4838
4839
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4837

def tool_versions
  @tool_versions
end

#uidString

Output only. Unique identifier of the Release. Corresponds to the JSON property uid

Returns:

  • (String)


4842
4843
4844
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4842

def uid
  @uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4849
4850
4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
4861
4862
4863
4864
4865
4866
4867
4868
4869
4870
4871
4872
4873
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4849

def update!(**args)
  @abandoned = args[:abandoned] if args.key?(:abandoned)
  @annotations = args[:annotations] if args.key?(:annotations)
  @build_artifacts = args[:build_artifacts] if args.key?(:build_artifacts)
  @condition = args[:condition] if args.key?(:condition)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_target_type_snapshots = args[:custom_target_type_snapshots] if args.key?(:custom_target_type_snapshots)
  @delivery_pipeline_snapshot = args[:delivery_pipeline_snapshot] if args.key?(:delivery_pipeline_snapshot)
  @deploy_parameters = args[:deploy_parameters] if args.key?(:deploy_parameters)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @render_end_time = args[:render_end_time] if args.key?(:render_end_time)
  @render_start_time = args[:render_start_time] if args.key?(:render_start_time)
  @render_state = args[:render_state] if args.key?(:render_state)
  @skaffold_config_path = args[:skaffold_config_path] if args.key?(:skaffold_config_path)
  @skaffold_config_uri = args[:skaffold_config_uri] if args.key?(:skaffold_config_uri)
  @skaffold_version = args[:skaffold_version] if args.key?(:skaffold_version)
  @target_artifacts = args[:target_artifacts] if args.key?(:target_artifacts)
  @target_renders = args[:target_renders] if args.key?(:target_renders)
  @target_snapshots = args[:target_snapshots] if args.key?(:target_snapshots)
  @tool_versions = args[:tool_versions] if args.key?(:tool_versions)
  @uid = args[:uid] if args.key?(:uid)
end