Class: Google::Apis::ClouddeployV1::Release

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

A Release resource in the Cloud Deploy API. A Release defines a specific Skaffold configuration instance that can be deployed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Release

Returns a new instance of Release.



4260
4261
4262
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4260

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#abandonedBoolean Also known as: abandoned?

Output only. Indicates whether this is an abandoned release. Corresponds to the JSON property abandoned

Returns:

  • (Boolean)


4128
4129
4130
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4128

def abandoned
  @abandoned
end

#annotationsHash<String,String>

Optional. User annotations. These attributes can only be set and used by the user, and not by Cloud Deploy. See https://google.aip.dev/128#annotations for more details such as format and size limitations. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


4136
4137
4138
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4136

def annotations
  @annotations
end

#build_artifactsArray<Google::Apis::ClouddeployV1::BuildArtifact>

Optional. List of artifacts to pass through to Skaffold command. Corresponds to the JSON property buildArtifacts



4141
4142
4143
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4141

def build_artifacts
  @build_artifacts
end

#conditionGoogle::Apis::ClouddeployV1::ReleaseCondition

ReleaseCondition contains all conditions relevant to a Release. Corresponds to the JSON property condition



4146
4147
4148
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4146

def condition
  @condition
end

#create_timeString

Output only. Time at which the Release was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4151
4152
4153
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4151

def create_time
  @create_time
end

#custom_target_type_snapshotsArray<Google::Apis::ClouddeployV1::CustomTargetType>

Output only. Snapshot of the custom target types referenced by the targets taken at release creation time. Corresponds to the JSON property customTargetTypeSnapshots



4157
4158
4159
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4157

def custom_target_type_snapshots
  @custom_target_type_snapshots
end

#delivery_pipeline_snapshotGoogle::Apis::ClouddeployV1::DeliveryPipeline

A DeliveryPipeline resource in the Cloud Deploy API. A DeliveryPipeline defines a pipeline through which a Skaffold configuration can progress. Corresponds to the JSON property deliveryPipelineSnapshot



4163
4164
4165
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4163

def delivery_pipeline_snapshot
  @delivery_pipeline_snapshot
end

#deploy_parametersHash<String,String>

Optional. The deploy parameters to use for all targets in this release. Corresponds to the JSON property deployParameters

Returns:

  • (Hash<String,String>)


4168
4169
4170
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4168

def deploy_parameters
  @deploy_parameters
end

#descriptionString

Optional. Description of the Release. Max length is 255 characters. Corresponds to the JSON property description

Returns:

  • (String)


4173
4174
4175
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4173

def description
  @description
end

#etagString

This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up- to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


4180
4181
4182
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4180

def etag
  @etag
end

#labelsHash<String,String>

Labels are attributes that can be set and used by both the user and by Cloud Deploy. Labels must meet the following constraints: * Keys and values can contain only lowercase letters, numeric characters, underscores, and dashes. * All characters must use UTF-8 encoding, and international characters are allowed. * Keys must start with a lowercase letter or international character.

  • Each resource is limited to a maximum of 64 labels. Both keys and values are additionally constrained to be <= 128 bytes. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4191
4192
4193
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4191

def labels
  @labels
end

#nameString

Identifier. Name of the Release. Format is projects/project/locations/ location/deliveryPipelines/deliveryPipeline/releases/release`. The releasecomponent must matcha-z? Corresponds to the JSON propertyname`

Returns:

  • (String)


4198
4199
4200
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4198

def name
  @name
end

#render_end_timeString

Output only. Time at which the render completed. Corresponds to the JSON property renderEndTime

Returns:

  • (String)


4203
4204
4205
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4203

def render_end_time
  @render_end_time
end

#render_start_timeString

Output only. Time at which the render began. Corresponds to the JSON property renderStartTime

Returns:

  • (String)


4208
4209
4210
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4208

def render_start_time
  @render_start_time
end

#render_stateString

Output only. Current state of the render operation. Corresponds to the JSON property renderState

Returns:

  • (String)


4213
4214
4215
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4213

def render_state
  @render_state
end

#skaffold_config_pathString

Optional. Filepath of the Skaffold config inside of the config URI. Corresponds to the JSON property skaffoldConfigPath

Returns:

  • (String)


4218
4219
4220
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4218

def skaffold_config_path
  @skaffold_config_path
end

#skaffold_config_uriString

Optional. Cloud Storage URI of tar.gz archive containing Skaffold configuration. Corresponds to the JSON property skaffoldConfigUri

Returns:

  • (String)


4224
4225
4226
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4224

def skaffold_config_uri
  @skaffold_config_uri
end

#skaffold_versionString

Optional. The Skaffold version to use when operating on this release, such as " 1.20.0". Not all versions are valid; Cloud Deploy supports a specific set of versions. If unset, the most recent supported Skaffold version will be used. Corresponds to the JSON property skaffoldVersion

Returns:

  • (String)


4231
4232
4233
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4231

def skaffold_version
  @skaffold_version
end

#target_artifactsHash<String,Google::Apis::ClouddeployV1::TargetArtifact>

Output only. Map from target ID to the target artifacts created during the render operation. Corresponds to the JSON property targetArtifacts



4237
4238
4239
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4237

def target_artifacts
  @target_artifacts
end

#target_rendersHash<String,Google::Apis::ClouddeployV1::TargetRender>

Output only. Map from target ID to details of the render operation for that target. Corresponds to the JSON property targetRenders



4243
4244
4245
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4243

def target_renders
  @target_renders
end

#target_snapshotsArray<Google::Apis::ClouddeployV1::Target>

Output only. Snapshot of the targets taken at release creation time. Corresponds to the JSON property targetSnapshots



4248
4249
4250
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4248

def target_snapshots
  @target_snapshots
end

#tool_versionsGoogle::Apis::ClouddeployV1::ToolVersions

Details of ToolVersions for the release. Corresponds to the JSON property toolVersions



4253
4254
4255
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4253

def tool_versions
  @tool_versions
end

#uidString

Output only. Unique identifier of the Release. Corresponds to the JSON property uid

Returns:

  • (String)


4258
4259
4260
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4258

def uid
  @uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4265
4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4265

def update!(**args)
  @abandoned = args[:abandoned] if args.key?(:abandoned)
  @annotations = args[:annotations] if args.key?(:annotations)
  @build_artifacts = args[:build_artifacts] if args.key?(:build_artifacts)
  @condition = args[:condition] if args.key?(:condition)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_target_type_snapshots = args[:custom_target_type_snapshots] if args.key?(:custom_target_type_snapshots)
  @delivery_pipeline_snapshot = args[:delivery_pipeline_snapshot] if args.key?(:delivery_pipeline_snapshot)
  @deploy_parameters = args[:deploy_parameters] if args.key?(:deploy_parameters)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @render_end_time = args[:render_end_time] if args.key?(:render_end_time)
  @render_start_time = args[:render_start_time] if args.key?(:render_start_time)
  @render_state = args[:render_state] if args.key?(:render_state)
  @skaffold_config_path = args[:skaffold_config_path] if args.key?(:skaffold_config_path)
  @skaffold_config_uri = args[:skaffold_config_uri] if args.key?(:skaffold_config_uri)
  @skaffold_version = args[:skaffold_version] if args.key?(:skaffold_version)
  @target_artifacts = args[:target_artifacts] if args.key?(:target_artifacts)
  @target_renders = args[:target_renders] if args.key?(:target_renders)
  @target_snapshots = args[:target_snapshots] if args.key?(:target_snapshots)
  @tool_versions = args[:tool_versions] if args.key?(:tool_versions)
  @uid = args[:uid] if args.key?(:uid)
end