Class: Google::Apis::ClouddeployV1::Release

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

A Release resource in the Cloud Deploy API. A Release defines a specific Skaffold configuration instance that can be deployed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Release

Returns a new instance of Release.



4240
4241
4242
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4240

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#abandonedBoolean Also known as: abandoned?

Output only. Indicates whether this is an abandoned release. Corresponds to the JSON property abandoned

Returns:

  • (Boolean)


4108
4109
4110
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4108

def abandoned
  @abandoned
end

#annotationsHash<String,String>

Optional. User annotations. These attributes can only be set and used by the user, and not by Cloud Deploy. See https://google.aip.dev/128#annotations for more details such as format and size limitations. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


4116
4117
4118
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4116

def annotations
  @annotations
end

#build_artifactsArray<Google::Apis::ClouddeployV1::BuildArtifact>

Optional. List of artifacts to pass through to Skaffold command. Corresponds to the JSON property buildArtifacts



4121
4122
4123
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4121

def build_artifacts
  @build_artifacts
end

#conditionGoogle::Apis::ClouddeployV1::ReleaseCondition

ReleaseCondition contains all conditions relevant to a Release. Corresponds to the JSON property condition



4126
4127
4128
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4126

def condition
  @condition
end

#create_timeString

Output only. Time at which the Release was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4131
4132
4133
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4131

def create_time
  @create_time
end

#custom_target_type_snapshotsArray<Google::Apis::ClouddeployV1::CustomTargetType>

Output only. Snapshot of the custom target types referenced by the targets taken at release creation time. Corresponds to the JSON property customTargetTypeSnapshots



4137
4138
4139
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4137

def custom_target_type_snapshots
  @custom_target_type_snapshots
end

#delivery_pipeline_snapshotGoogle::Apis::ClouddeployV1::DeliveryPipeline

A DeliveryPipeline resource in the Cloud Deploy API. A DeliveryPipeline defines a pipeline through which a Skaffold configuration can progress. Corresponds to the JSON property deliveryPipelineSnapshot



4143
4144
4145
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4143

def delivery_pipeline_snapshot
  @delivery_pipeline_snapshot
end

#deploy_parametersHash<String,String>

Optional. The deploy parameters to use for all targets in this release. Corresponds to the JSON property deployParameters

Returns:

  • (Hash<String,String>)


4148
4149
4150
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4148

def deploy_parameters
  @deploy_parameters
end

#descriptionString

Optional. Description of the Release. Max length is 255 characters. Corresponds to the JSON property description

Returns:

  • (String)


4153
4154
4155
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4153

def description
  @description
end

#etagString

This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up- to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


4160
4161
4162
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4160

def etag
  @etag
end

#labelsHash<String,String>

Labels are attributes that can be set and used by both the user and by Cloud Deploy. Labels must meet the following constraints: * Keys and values can contain only lowercase letters, numeric characters, underscores, and dashes. * All characters must use UTF-8 encoding, and international characters are allowed. * Keys must start with a lowercase letter or international character.

  • Each resource is limited to a maximum of 64 labels. Both keys and values are additionally constrained to be <= 128 bytes. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4171
4172
4173
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4171

def labels
  @labels
end

#nameString

Identifier. Name of the Release. Format is projects/project/locations/ location/deliveryPipelines/deliveryPipeline/releases/release`. The releasecomponent must matcha-z? Corresponds to the JSON propertyname`

Returns:

  • (String)


4178
4179
4180
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4178

def name
  @name
end

#render_end_timeString

Output only. Time at which the render completed. Corresponds to the JSON property renderEndTime

Returns:

  • (String)


4183
4184
4185
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4183

def render_end_time
  @render_end_time
end

#render_start_timeString

Output only. Time at which the render began. Corresponds to the JSON property renderStartTime

Returns:

  • (String)


4188
4189
4190
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4188

def render_start_time
  @render_start_time
end

#render_stateString

Output only. Current state of the render operation. Corresponds to the JSON property renderState

Returns:

  • (String)


4193
4194
4195
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4193

def render_state
  @render_state
end

#skaffold_config_pathString

Optional. Filepath of the Skaffold config inside of the config URI. Corresponds to the JSON property skaffoldConfigPath

Returns:

  • (String)


4198
4199
4200
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4198

def skaffold_config_path
  @skaffold_config_path
end

#skaffold_config_uriString

Optional. Cloud Storage URI of tar.gz archive containing Skaffold configuration. Corresponds to the JSON property skaffoldConfigUri

Returns:

  • (String)


4204
4205
4206
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4204

def skaffold_config_uri
  @skaffold_config_uri
end

#skaffold_versionString

Optional. The Skaffold version to use when operating on this release, such as " 1.20.0". Not all versions are valid; Cloud Deploy supports a specific set of versions. If unset, the most recent supported Skaffold version will be used. Corresponds to the JSON property skaffoldVersion

Returns:

  • (String)


4211
4212
4213
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4211

def skaffold_version
  @skaffold_version
end

#target_artifactsHash<String,Google::Apis::ClouddeployV1::TargetArtifact>

Output only. Map from target ID to the target artifacts created during the render operation. Corresponds to the JSON property targetArtifacts



4217
4218
4219
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4217

def target_artifacts
  @target_artifacts
end

#target_rendersHash<String,Google::Apis::ClouddeployV1::TargetRender>

Output only. Map from target ID to details of the render operation for that target. Corresponds to the JSON property targetRenders



4223
4224
4225
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4223

def target_renders
  @target_renders
end

#target_snapshotsArray<Google::Apis::ClouddeployV1::Target>

Output only. Snapshot of the targets taken at release creation time. Corresponds to the JSON property targetSnapshots



4228
4229
4230
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4228

def target_snapshots
  @target_snapshots
end

#tool_versionsGoogle::Apis::ClouddeployV1::ToolVersions

Details of ToolVersions for the release. Corresponds to the JSON property toolVersions



4233
4234
4235
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4233

def tool_versions
  @tool_versions
end

#uidString

Output only. Unique identifier of the Release. Corresponds to the JSON property uid

Returns:

  • (String)


4238
4239
4240
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4238

def uid
  @uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4245

def update!(**args)
  @abandoned = args[:abandoned] if args.key?(:abandoned)
  @annotations = args[:annotations] if args.key?(:annotations)
  @build_artifacts = args[:build_artifacts] if args.key?(:build_artifacts)
  @condition = args[:condition] if args.key?(:condition)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_target_type_snapshots = args[:custom_target_type_snapshots] if args.key?(:custom_target_type_snapshots)
  @delivery_pipeline_snapshot = args[:delivery_pipeline_snapshot] if args.key?(:delivery_pipeline_snapshot)
  @deploy_parameters = args[:deploy_parameters] if args.key?(:deploy_parameters)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @render_end_time = args[:render_end_time] if args.key?(:render_end_time)
  @render_start_time = args[:render_start_time] if args.key?(:render_start_time)
  @render_state = args[:render_state] if args.key?(:render_state)
  @skaffold_config_path = args[:skaffold_config_path] if args.key?(:skaffold_config_path)
  @skaffold_config_uri = args[:skaffold_config_uri] if args.key?(:skaffold_config_uri)
  @skaffold_version = args[:skaffold_version] if args.key?(:skaffold_version)
  @target_artifacts = args[:target_artifacts] if args.key?(:target_artifacts)
  @target_renders = args[:target_renders] if args.key?(:target_renders)
  @target_snapshots = args[:target_snapshots] if args.key?(:target_snapshots)
  @tool_versions = args[:tool_versions] if args.key?(:tool_versions)
  @uid = args[:uid] if args.key?(:uid)
end