Class: Google::Apis::ClouddeployV1::ReleaseCondition

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

ReleaseCondition contains all conditions relevant to a Release.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReleaseCondition

Returns a new instance of ReleaseCondition.



4928
4929
4930
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4928

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#docker_version_supported_conditionGoogle::Apis::ClouddeployV1::ToolVersionSupportedCondition

ToolVersionSupportedCondition contains information about when support for the release's version of a tool ends. Corresponds to the JSON property dockerVersionSupportedCondition



4884
4885
4886
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4884

def docker_version_supported_condition
  @docker_version_supported_condition
end

#helm_version_supported_conditionGoogle::Apis::ClouddeployV1::ToolVersionSupportedCondition

ToolVersionSupportedCondition contains information about when support for the release's version of a tool ends. Corresponds to the JSON property helmVersionSupportedCondition



4890
4891
4892
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4890

def helm_version_supported_condition
  @helm_version_supported_condition
end

#kpt_version_supported_conditionGoogle::Apis::ClouddeployV1::ToolVersionSupportedCondition

ToolVersionSupportedCondition contains information about when support for the release's version of a tool ends. Corresponds to the JSON property kptVersionSupportedCondition



4896
4897
4898
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4896

def kpt_version_supported_condition
  @kpt_version_supported_condition
end

#kubectl_version_supported_conditionGoogle::Apis::ClouddeployV1::ToolVersionSupportedCondition

ToolVersionSupportedCondition contains information about when support for the release's version of a tool ends. Corresponds to the JSON property kubectlVersionSupportedCondition



4902
4903
4904
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4902

def kubectl_version_supported_condition
  @kubectl_version_supported_condition
end

#kustomize_version_supported_conditionGoogle::Apis::ClouddeployV1::ToolVersionSupportedCondition

ToolVersionSupportedCondition contains information about when support for the release's version of a tool ends. Corresponds to the JSON property kustomizeVersionSupportedCondition



4908
4909
4910
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4908

def kustomize_version_supported_condition
  @kustomize_version_supported_condition
end

#release_ready_conditionGoogle::Apis::ClouddeployV1::ReleaseReadyCondition

ReleaseReadyCondition contains information around the status of the Release. If a release is not ready, you cannot create a rollout with the release. Corresponds to the JSON property releaseReadyCondition



4914
4915
4916
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4914

def release_ready_condition
  @release_ready_condition
end

#skaffold_supported_conditionGoogle::Apis::ClouddeployV1::SkaffoldSupportedCondition

SkaffoldSupportedCondition contains information about when support for the release's version of Skaffold ends. Corresponds to the JSON property skaffoldSupportedCondition



4920
4921
4922
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4920

def skaffold_supported_condition
  @skaffold_supported_condition
end

#skaffold_version_supported_conditionGoogle::Apis::ClouddeployV1::ToolVersionSupportedCondition

ToolVersionSupportedCondition contains information about when support for the release's version of a tool ends. Corresponds to the JSON property skaffoldVersionSupportedCondition



4926
4927
4928
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4926

def skaffold_version_supported_condition
  @skaffold_version_supported_condition
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4933
4934
4935
4936
4937
4938
4939
4940
4941
4942
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4933

def update!(**args)
  @docker_version_supported_condition = args[:docker_version_supported_condition] if args.key?(:docker_version_supported_condition)
  @helm_version_supported_condition = args[:helm_version_supported_condition] if args.key?(:helm_version_supported_condition)
  @kpt_version_supported_condition = args[:kpt_version_supported_condition] if args.key?(:kpt_version_supported_condition)
  @kubectl_version_supported_condition = args[:kubectl_version_supported_condition] if args.key?(:kubectl_version_supported_condition)
  @kustomize_version_supported_condition = args[:kustomize_version_supported_condition] if args.key?(:kustomize_version_supported_condition)
  @release_ready_condition = args[:release_ready_condition] if args.key?(:release_ready_condition)
  @skaffold_supported_condition = args[:skaffold_supported_condition] if args.key?(:skaffold_supported_condition)
  @skaffold_version_supported_condition = args[:skaffold_version_supported_condition] if args.key?(:skaffold_version_supported_condition)
end