Class: Google::Apis::ClouddeployV1::ReleaseCondition

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

ReleaseCondition contains all conditions relevant to a Release.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReleaseCondition

Returns a new instance of ReleaseCondition.



4344
4345
4346
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4344

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#docker_version_supported_conditionGoogle::Apis::ClouddeployV1::ToolVersionSupportedCondition

ToolVersionSupportedCondition contains information about when support for the release's version of a tool ends. Corresponds to the JSON property dockerVersionSupportedCondition



4300
4301
4302
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4300

def docker_version_supported_condition
  @docker_version_supported_condition
end

#helm_version_supported_conditionGoogle::Apis::ClouddeployV1::ToolVersionSupportedCondition

ToolVersionSupportedCondition contains information about when support for the release's version of a tool ends. Corresponds to the JSON property helmVersionSupportedCondition



4306
4307
4308
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4306

def helm_version_supported_condition
  @helm_version_supported_condition
end

#kpt_version_supported_conditionGoogle::Apis::ClouddeployV1::ToolVersionSupportedCondition

ToolVersionSupportedCondition contains information about when support for the release's version of a tool ends. Corresponds to the JSON property kptVersionSupportedCondition



4312
4313
4314
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4312

def kpt_version_supported_condition
  @kpt_version_supported_condition
end

#kubectl_version_supported_conditionGoogle::Apis::ClouddeployV1::ToolVersionSupportedCondition

ToolVersionSupportedCondition contains information about when support for the release's version of a tool ends. Corresponds to the JSON property kubectlVersionSupportedCondition



4318
4319
4320
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4318

def kubectl_version_supported_condition
  @kubectl_version_supported_condition
end

#kustomize_version_supported_conditionGoogle::Apis::ClouddeployV1::ToolVersionSupportedCondition

ToolVersionSupportedCondition contains information about when support for the release's version of a tool ends. Corresponds to the JSON property kustomizeVersionSupportedCondition



4324
4325
4326
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4324

def kustomize_version_supported_condition
  @kustomize_version_supported_condition
end

#release_ready_conditionGoogle::Apis::ClouddeployV1::ReleaseReadyCondition

ReleaseReadyCondition contains information around the status of the Release. If a release is not ready, you cannot create a rollout with the release. Corresponds to the JSON property releaseReadyCondition



4330
4331
4332
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4330

def release_ready_condition
  @release_ready_condition
end

#skaffold_supported_conditionGoogle::Apis::ClouddeployV1::SkaffoldSupportedCondition

SkaffoldSupportedCondition contains information about when support for the release's version of Skaffold ends. Corresponds to the JSON property skaffoldSupportedCondition



4336
4337
4338
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4336

def skaffold_supported_condition
  @skaffold_supported_condition
end

#skaffold_version_supported_conditionGoogle::Apis::ClouddeployV1::ToolVersionSupportedCondition

ToolVersionSupportedCondition contains information about when support for the release's version of a tool ends. Corresponds to the JSON property skaffoldVersionSupportedCondition



4342
4343
4344
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4342

def skaffold_version_supported_condition
  @skaffold_version_supported_condition
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4349
4350
4351
4352
4353
4354
4355
4356
4357
4358
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4349

def update!(**args)
  @docker_version_supported_condition = args[:docker_version_supported_condition] if args.key?(:docker_version_supported_condition)
  @helm_version_supported_condition = args[:helm_version_supported_condition] if args.key?(:helm_version_supported_condition)
  @kpt_version_supported_condition = args[:kpt_version_supported_condition] if args.key?(:kpt_version_supported_condition)
  @kubectl_version_supported_condition = args[:kubectl_version_supported_condition] if args.key?(:kubectl_version_supported_condition)
  @kustomize_version_supported_condition = args[:kustomize_version_supported_condition] if args.key?(:kustomize_version_supported_condition)
  @release_ready_condition = args[:release_ready_condition] if args.key?(:release_ready_condition)
  @skaffold_supported_condition = args[:skaffold_supported_condition] if args.key?(:skaffold_supported_condition)
  @skaffold_version_supported_condition = args[:skaffold_version_supported_condition] if args.key?(:skaffold_version_supported_condition)
end