Class: Google::Apis::ClouddeployV1::ReleaseCondition

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

ReleaseCondition contains all conditions relevant to a Release.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReleaseCondition

Returns a new instance of ReleaseCondition.



4324
4325
4326
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4324

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#docker_version_supported_conditionGoogle::Apis::ClouddeployV1::ToolVersionSupportedCondition

ToolVersionSupportedCondition contains information about when support for the release's version of a tool ends. Corresponds to the JSON property dockerVersionSupportedCondition



4280
4281
4282
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4280

def docker_version_supported_condition
  @docker_version_supported_condition
end

#helm_version_supported_conditionGoogle::Apis::ClouddeployV1::ToolVersionSupportedCondition

ToolVersionSupportedCondition contains information about when support for the release's version of a tool ends. Corresponds to the JSON property helmVersionSupportedCondition



4286
4287
4288
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4286

def helm_version_supported_condition
  @helm_version_supported_condition
end

#kpt_version_supported_conditionGoogle::Apis::ClouddeployV1::ToolVersionSupportedCondition

ToolVersionSupportedCondition contains information about when support for the release's version of a tool ends. Corresponds to the JSON property kptVersionSupportedCondition



4292
4293
4294
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4292

def kpt_version_supported_condition
  @kpt_version_supported_condition
end

#kubectl_version_supported_conditionGoogle::Apis::ClouddeployV1::ToolVersionSupportedCondition

ToolVersionSupportedCondition contains information about when support for the release's version of a tool ends. Corresponds to the JSON property kubectlVersionSupportedCondition



4298
4299
4300
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4298

def kubectl_version_supported_condition
  @kubectl_version_supported_condition
end

#kustomize_version_supported_conditionGoogle::Apis::ClouddeployV1::ToolVersionSupportedCondition

ToolVersionSupportedCondition contains information about when support for the release's version of a tool ends. Corresponds to the JSON property kustomizeVersionSupportedCondition



4304
4305
4306
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4304

def kustomize_version_supported_condition
  @kustomize_version_supported_condition
end

#release_ready_conditionGoogle::Apis::ClouddeployV1::ReleaseReadyCondition

ReleaseReadyCondition contains information around the status of the Release. If a release is not ready, you cannot create a rollout with the release. Corresponds to the JSON property releaseReadyCondition



4310
4311
4312
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4310

def release_ready_condition
  @release_ready_condition
end

#skaffold_supported_conditionGoogle::Apis::ClouddeployV1::SkaffoldSupportedCondition

SkaffoldSupportedCondition contains information about when support for the release's version of Skaffold ends. Corresponds to the JSON property skaffoldSupportedCondition



4316
4317
4318
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4316

def skaffold_supported_condition
  @skaffold_supported_condition
end

#skaffold_version_supported_conditionGoogle::Apis::ClouddeployV1::ToolVersionSupportedCondition

ToolVersionSupportedCondition contains information about when support for the release's version of a tool ends. Corresponds to the JSON property skaffoldVersionSupportedCondition



4322
4323
4324
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4322

def skaffold_version_supported_condition
  @skaffold_version_supported_condition
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4329
4330
4331
4332
4333
4334
4335
4336
4337
4338
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4329

def update!(**args)
  @docker_version_supported_condition = args[:docker_version_supported_condition] if args.key?(:docker_version_supported_condition)
  @helm_version_supported_condition = args[:helm_version_supported_condition] if args.key?(:helm_version_supported_condition)
  @kpt_version_supported_condition = args[:kpt_version_supported_condition] if args.key?(:kpt_version_supported_condition)
  @kubectl_version_supported_condition = args[:kubectl_version_supported_condition] if args.key?(:kubectl_version_supported_condition)
  @kustomize_version_supported_condition = args[:kustomize_version_supported_condition] if args.key?(:kustomize_version_supported_condition)
  @release_ready_condition = args[:release_ready_condition] if args.key?(:release_ready_condition)
  @skaffold_supported_condition = args[:skaffold_supported_condition] if args.key?(:skaffold_supported_condition)
  @skaffold_version_supported_condition = args[:skaffold_version_supported_condition] if args.key?(:skaffold_version_supported_condition)
end