Class: Google::Apis::ClouddeployV1::ReleaseRenderEvent
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::ReleaseRenderEvent
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
Payload proto for "clouddeploy.googleapis.com/release_render" Platform Log event that describes the render status change.
Instance Attribute Summary collapse
-
#message ⇒ String
Debug message for when a render transition occurs.
-
#pipeline_uid ⇒ String
Unique identifier of the
DeliveryPipeline. -
#release ⇒ String
The name of the release.
-
#release_render_state ⇒ String
The state of the release render.
-
#type ⇒ String
Type of this notification, e.g.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReleaseRenderEvent
constructor
A new instance of ReleaseRenderEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReleaseRenderEvent
Returns a new instance of ReleaseRenderEvent.
5054 5055 5056 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5054 def initialize(**args) update!(**args) end |
Instance Attribute Details
#message ⇒ String
Debug message for when a render transition occurs. Provides further details as
rendering progresses through render states.
Corresponds to the JSON property message
5030 5031 5032 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5030 def @message end |
#pipeline_uid ⇒ String
Unique identifier of the DeliveryPipeline.
Corresponds to the JSON property pipelineUid
5035 5036 5037 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5035 def pipeline_uid @pipeline_uid end |
#release ⇒ String
The name of the release. release_uid is not in this log message because we
write some of these log messages at release creation time, before we've
generated the uid.
Corresponds to the JSON property release
5042 5043 5044 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5042 def release @release end |
#release_render_state ⇒ String
The state of the release render.
Corresponds to the JSON property releaseRenderState
5047 5048 5049 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5047 def release_render_state @release_render_state end |
#type ⇒ String
Type of this notification, e.g. for a release render state change event.
Corresponds to the JSON property type
5052 5053 5054 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5052 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5059 5060 5061 5062 5063 5064 5065 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5059 def update!(**args) @message = args[:message] if args.key?(:message) @pipeline_uid = args[:pipeline_uid] if args.key?(:pipeline_uid) @release = args[:release] if args.key?(:release) @release_render_state = args[:release_render_state] if args.key?(:release_render_state) @type = args[:type] if args.key?(:type) end |