Class: Google::Apis::ClouddeployV1::ReleaseRenderEvent

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

Payload proto for "clouddeploy.googleapis.com/release_render" Platform Log event that describes the render status change.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReleaseRenderEvent

Returns a new instance of ReleaseRenderEvent.



4443
4444
4445
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4443

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#messageString

Debug message for when a render transition occurs. Provides further details as rendering progresses through render states. Corresponds to the JSON property message

Returns:

  • (String)


4419
4420
4421
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4419

def message
  @message
end

#pipeline_uidString

Unique identifier of the DeliveryPipeline. Corresponds to the JSON property pipelineUid

Returns:

  • (String)


4424
4425
4426
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4424

def pipeline_uid
  @pipeline_uid
end

#releaseString

The name of the release. release_uid is not in this log message because we write some of these log messages at release creation time, before we've generated the uid. Corresponds to the JSON property release

Returns:

  • (String)


4431
4432
4433
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4431

def release
  @release
end

#release_render_stateString

The state of the release render. Corresponds to the JSON property releaseRenderState

Returns:

  • (String)


4436
4437
4438
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4436

def release_render_state
  @release_render_state
end

#typeString

Type of this notification, e.g. for a release render state change event. Corresponds to the JSON property type

Returns:

  • (String)


4441
4442
4443
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4441

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4448
4449
4450
4451
4452
4453
4454
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4448

def update!(**args)
  @message = args[:message] if args.key?(:message)
  @pipeline_uid = args[:pipeline_uid] if args.key?(:pipeline_uid)
  @release = args[:release] if args.key?(:release)
  @release_render_state = args[:release_render_state] if args.key?(:release_render_state)
  @type = args[:type] if args.key?(:type)
end