Class: Google::Apis::ClouddeployV1::RepairRolloutOperation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

Contains the information for an automated repair rollout operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RepairRolloutOperation

Returns a new instance of RepairRolloutOperation.



4565
4566
4567
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4565

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_repair_phase_indexFixnum

Output only. The index of the current repair action in the repair sequence. Corresponds to the JSON property currentRepairPhaseIndex

Returns:

  • (Fixnum)


4542
4543
4544
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4542

def current_repair_phase_index
  @current_repair_phase_index
end

#job_idString

Output only. The job ID for the Job to repair. Corresponds to the JSON property jobId

Returns:

  • (String)


4547
4548
4549
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4547

def job_id
  @job_id
end

#phase_idString

Output only. The phase ID of the phase that includes the job being repaired. Corresponds to the JSON property phaseId

Returns:

  • (String)


4552
4553
4554
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4552

def phase_id
  @phase_id
end

#repair_phasesArray<Google::Apis::ClouddeployV1::RepairPhase>

Output only. Records of the repair attempts. Each repair phase may have multiple retry attempts or single rollback attempt. Corresponds to the JSON property repairPhases



4558
4559
4560
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4558

def repair_phases
  @repair_phases
end

#rolloutString

Output only. The name of the rollout that initiates the AutomationRun. Corresponds to the JSON property rollout

Returns:

  • (String)


4563
4564
4565
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4563

def rollout
  @rollout
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4570
4571
4572
4573
4574
4575
4576
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4570

def update!(**args)
  @current_repair_phase_index = args[:current_repair_phase_index] if args.key?(:current_repair_phase_index)
  @job_id = args[:job_id] if args.key?(:job_id)
  @phase_id = args[:phase_id] if args.key?(:phase_id)
  @repair_phases = args[:repair_phases] if args.key?(:repair_phases)
  @rollout = args[:rollout] if args.key?(:rollout)
end