Class: Google::Apis::ClouddeployV1::RepairRolloutRule
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::RepairRolloutRule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
The RepairRolloutRule automation rule will automatically repair a failed
Rollout.
Instance Attribute Summary collapse
-
#condition ⇒ Google::Apis::ClouddeployV1::AutomationRuleCondition
AutomationRuleConditioncontains conditions relevant to anAutomationrule. -
#id ⇒ String
Required.
-
#jobs ⇒ Array<String>
Optional.
-
#phases ⇒ Array<String>
Optional.
-
#repair_phases ⇒ Array<Google::Apis::ClouddeployV1::RepairPhaseConfig>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RepairRolloutRule
constructor
A new instance of RepairRolloutRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RepairRolloutRule
Returns a new instance of RepairRolloutRule.
4640 4641 4642 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4640 def initialize(**args) update!(**args) end |
Instance Attribute Details
#condition ⇒ Google::Apis::ClouddeployV1::AutomationRuleCondition
AutomationRuleCondition contains conditions relevant to an Automation rule.
Corresponds to the JSON property condition
4607 4608 4609 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4607 def condition @condition end |
#id ⇒ String
Required. ID of the rule. This id must be unique in the Automation resource
to which this rule belongs. The format is [a-z]([a-z0-9-]0,61[a-z0-9])?.
Corresponds to the JSON property id
4613 4614 4615 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4613 def id @id end |
#jobs ⇒ Array<String>
Optional. Jobs to repair. Proceeds only after job name matched any one in the
list, or for all jobs if unspecified or empty. The phase that includes the job
must match the phase ID specified in source_phase. This value must consist
of lower-case letters, numbers, and hyphens, start with a letter and end with
a letter or a number, and have a max length of 63 characters. In other words,
it must match the following regex: ^[a-z]([a-z0-9-]0,61[a-z0-9])?$.
Corresponds to the JSON property jobs
4623 4624 4625 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4623 def jobs @jobs end |
#phases ⇒ Array<String>
Optional. Phases within which jobs are subject to automatic repair actions on
failure. Proceeds only after phase name matched any one in the list, or for
all phases if unspecified. This value must consist of lower-case letters,
numbers, and hyphens, start with a letter and end with a letter or a number,
and have a max length of 63 characters. In other words, it must match the
following regex: ^[a-z]([a-z0-9-]0,61[a-z0-9])?$.
Corresponds to the JSON property phases
4633 4634 4635 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4633 def phases @phases end |
#repair_phases ⇒ Array<Google::Apis::ClouddeployV1::RepairPhaseConfig>
Required. Defines the types of automatic repair phases for failed jobs.
Corresponds to the JSON property repairPhases
4638 4639 4640 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4638 def repair_phases @repair_phases end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4645 4646 4647 4648 4649 4650 4651 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4645 def update!(**args) @condition = args[:condition] if args.key?(:condition) @id = args[:id] if args.key?(:id) @jobs = args[:jobs] if args.key?(:jobs) @phases = args[:phases] if args.key?(:phases) @repair_phases = args[:repair_phases] if args.key?(:repair_phases) end |