Class: Google::Apis::ClouddeployV1::RepairRolloutRule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

The RepairRolloutRule automation rule will automatically repair a failed Rollout.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RepairRolloutRule

Returns a new instance of RepairRolloutRule.



4620
4621
4622
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4620

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionGoogle::Apis::ClouddeployV1::AutomationRuleCondition

AutomationRuleCondition contains conditions relevant to an Automation rule. Corresponds to the JSON property condition



4587
4588
4589
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4587

def condition
  @condition
end

#idString

Required. ID of the rule. This id must be unique in the Automation resource to which this rule belongs. The format is [a-z]([a-z0-9-]0,61[a-z0-9])?. Corresponds to the JSON property id

Returns:

  • (String)


4593
4594
4595
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4593

def id
  @id
end

#jobsArray<String>

Optional. Jobs to repair. Proceeds only after job name matched any one in the list, or for all jobs if unspecified or empty. The phase that includes the job must match the phase ID specified in source_phase. This value must consist of lower-case letters, numbers, and hyphens, start with a letter and end with a letter or a number, and have a max length of 63 characters. In other words, it must match the following regex: ^[a-z]([a-z0-9-]0,61[a-z0-9])?$. Corresponds to the JSON property jobs

Returns:

  • (Array<String>)


4603
4604
4605
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4603

def jobs
  @jobs
end

#phasesArray<String>

Optional. Phases within which jobs are subject to automatic repair actions on failure. Proceeds only after phase name matched any one in the list, or for all phases if unspecified. This value must consist of lower-case letters, numbers, and hyphens, start with a letter and end with a letter or a number, and have a max length of 63 characters. In other words, it must match the following regex: ^[a-z]([a-z0-9-]0,61[a-z0-9])?$. Corresponds to the JSON property phases

Returns:

  • (Array<String>)


4613
4614
4615
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4613

def phases
  @phases
end

#repair_phasesArray<Google::Apis::ClouddeployV1::RepairPhaseConfig>

Required. Defines the types of automatic repair phases for failed jobs. Corresponds to the JSON property repairPhases



4618
4619
4620
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4618

def repair_phases
  @repair_phases
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4625
4626
4627
4628
4629
4630
4631
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4625

def update!(**args)
  @condition = args[:condition] if args.key?(:condition)
  @id = args[:id] if args.key?(:id)
  @jobs = args[:jobs] if args.key?(:jobs)
  @phases = args[:phases] if args.key?(:phases)
  @repair_phases = args[:repair_phases] if args.key?(:repair_phases)
end