Class: Google::Apis::ClouddeployV1::Retry
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::Retry
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
Retries the failed job.
Instance Attribute Summary collapse
-
#attempts ⇒ Fixnum
Required.
-
#backoff_mode ⇒ String
Optional.
-
#wait ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Retry
constructor
A new instance of Retry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Retry
Returns a new instance of Retry.
5267 5268 5269 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5267 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attempts ⇒ Fixnum
Required. Total number of retries. Retry is skipped if set to 0; The minimum
value is 1, and the maximum value is 10.
Corresponds to the JSON property attempts
5253 5254 5255 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5253 def attempts @attempts end |
#backoff_mode ⇒ String
Optional. The pattern of how wait time will be increased. Default is linear.
Backoff mode will be ignored if wait is 0.
Corresponds to the JSON property backoffMode
5259 5260 5261 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5259 def backoff_mode @backoff_mode end |
#wait ⇒ String
Optional. How long to wait for the first retry. Default is 0, and the maximum
value is 14d.
Corresponds to the JSON property wait
5265 5266 5267 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5265 def wait @wait end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5272 5273 5274 5275 5276 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5272 def update!(**args) @attempts = args[:attempts] if args.key?(:attempts) @backoff_mode = args[:backoff_mode] if args.key?(:backoff_mode) @wait = args[:wait] if args.key?(:wait) end |