Class: Google::Apis::ClouddeployV1::Retry

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

Retries the failed job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Retry

Returns a new instance of Retry.



4676
4677
4678
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4676

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attemptsFixnum

Required. Total number of retries. Retry is skipped if set to 0; The minimum value is 1, and the maximum value is 10. Corresponds to the JSON property attempts

Returns:

  • (Fixnum)


4662
4663
4664
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4662

def attempts
  @attempts
end

#backoff_modeString

Optional. The pattern of how wait time will be increased. Default is linear. Backoff mode will be ignored if wait is 0. Corresponds to the JSON property backoffMode

Returns:

  • (String)


4668
4669
4670
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4668

def backoff_mode
  @backoff_mode
end

#waitString

Optional. How long to wait for the first retry. Default is 0, and the maximum value is 14d. Corresponds to the JSON property wait

Returns:

  • (String)


4674
4675
4676
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4674

def wait
  @wait
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4681
4682
4683
4684
4685
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4681

def update!(**args)
  @attempts = args[:attempts] if args.key?(:attempts)
  @backoff_mode = args[:backoff_mode] if args.key?(:backoff_mode)
  @wait = args[:wait] if args.key?(:wait)
end