Class: Google::Apis::ClouddeployV1::Retry
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::Retry
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
Retries the failed job.
Instance Attribute Summary collapse
-
#attempts ⇒ Fixnum
Required.
-
#backoff_mode ⇒ String
Optional.
-
#wait ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Retry
constructor
A new instance of Retry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Retry
Returns a new instance of Retry.
4656 4657 4658 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4656 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attempts ⇒ Fixnum
Required. Total number of retries. Retry is skipped if set to 0; The minimum
value is 1, and the maximum value is 10.
Corresponds to the JSON property attempts
4642 4643 4644 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4642 def attempts @attempts end |
#backoff_mode ⇒ String
Optional. The pattern of how wait time will be increased. Default is linear.
Backoff mode will be ignored if wait is 0.
Corresponds to the JSON property backoffMode
4648 4649 4650 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4648 def backoff_mode @backoff_mode end |
#wait ⇒ String
Optional. How long to wait for the first retry. Default is 0, and the maximum
value is 14d.
Corresponds to the JSON property wait
4654 4655 4656 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4654 def wait @wait end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4661 4662 4663 4664 4665 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4661 def update!(**args) @attempts = args[:attempts] if args.key?(:attempts) @backoff_mode = args[:backoff_mode] if args.key?(:backoff_mode) @wait = args[:wait] if args.key?(:wait) end |