Class: Google::Apis::ClouddeployV1::RollbackTargetRequest
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::RollbackTargetRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
The request object for RollbackTarget.
Instance Attribute Summary collapse
-
#override_deploy_policy ⇒ Array<String>
Optional.
-
#release_id ⇒ String
Optional.
-
#rollback_config ⇒ Google::Apis::ClouddeployV1::RollbackTargetConfig
Configs for the Rollback rollout.
-
#rollout_id ⇒ String
Required.
-
#rollout_to_roll_back ⇒ String
Optional.
-
#target_id ⇒ String
Required.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RollbackTargetRequest
constructor
A new instance of RollbackTargetRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RollbackTargetRequest
Returns a new instance of RollbackTargetRequest.
5545 5546 5547 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5545 def initialize(**args) update!(**args) end |
Instance Attribute Details
#override_deploy_policy ⇒ Array<String>
Optional. Deploy policies to override. Format is projects/project/locations/
location/deployPolicies/deploy_policy`.
Corresponds to the JSON propertyoverrideDeployPolicy`
5508 5509 5510 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5508 def override_deploy_policy @override_deploy_policy end |
#release_id ⇒ String
Optional. ID of the Release to roll back to. If this isn't specified, the
previous successful Rollout to the specified target will be used to
determine the Release.
Corresponds to the JSON property releaseId
5515 5516 5517 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5515 def release_id @release_id end |
#rollback_config ⇒ Google::Apis::ClouddeployV1::RollbackTargetConfig
Configs for the Rollback rollout.
Corresponds to the JSON property rollbackConfig
5520 5521 5522 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5520 def rollback_config @rollback_config end |
#rollout_id ⇒ String
Required. ID of the rollback Rollout to create.
Corresponds to the JSON property rolloutId
5525 5526 5527 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5525 def rollout_id @rollout_id end |
#rollout_to_roll_back ⇒ String
Optional. If provided, this must be the latest Rollout that is on the
Target.
Corresponds to the JSON property rolloutToRollBack
5531 5532 5533 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5531 def rollout_to_roll_back @rollout_to_roll_back end |
#target_id ⇒ String
Required. ID of the Target that is being rolled back.
Corresponds to the JSON property targetId
5536 5537 5538 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5536 def target_id @target_id end |
#validate_only ⇒ Boolean Also known as: validate_only?
Optional. If set to true, the request is validated and the user is provided
with a RollbackTargetResponse.
Corresponds to the JSON property validateOnly
5542 5543 5544 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5542 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5550 5551 5552 5553 5554 5555 5556 5557 5558 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5550 def update!(**args) @override_deploy_policy = args[:override_deploy_policy] if args.key?(:override_deploy_policy) @release_id = args[:release_id] if args.key?(:release_id) @rollback_config = args[:rollback_config] if args.key?(:rollback_config) @rollout_id = args[:rollout_id] if args.key?(:rollout_id) @rollout_to_roll_back = args[:rollout_to_roll_back] if args.key?(:rollout_to_roll_back) @target_id = args[:target_id] if args.key?(:target_id) @validate_only = args[:validate_only] if args.key?(:validate_only) end |