Class: Google::Apis::ClouddeployV1::RollbackTargetRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

The request object for RollbackTarget.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RollbackTargetRequest

Returns a new instance of RollbackTargetRequest.



5538
5539
5540
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5538

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#override_deploy_policyArray<String>

Optional. Deploy policies to override. Format is projects/project/locations/ location/deployPolicies/deploy_policy`. Corresponds to the JSON propertyoverrideDeployPolicy`

Returns:

  • (Array<String>)


5501
5502
5503
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5501

def override_deploy_policy
  @override_deploy_policy
end

#release_idString

Optional. ID of the Release to roll back to. If this isn't specified, the previous successful Rollout to the specified target will be used to determine the Release. Corresponds to the JSON property releaseId

Returns:

  • (String)


5508
5509
5510
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5508

def release_id
  @release_id
end

#rollback_configGoogle::Apis::ClouddeployV1::RollbackTargetConfig

Configs for the Rollback rollout. Corresponds to the JSON property rollbackConfig



5513
5514
5515
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5513

def rollback_config
  @rollback_config
end

#rollout_idString

Required. ID of the rollback Rollout to create. Corresponds to the JSON property rolloutId

Returns:

  • (String)


5518
5519
5520
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5518

def rollout_id
  @rollout_id
end

#rollout_to_roll_backString

Optional. If provided, this must be the latest Rollout that is on the Target. Corresponds to the JSON property rolloutToRollBack

Returns:

  • (String)


5524
5525
5526
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5524

def rollout_to_roll_back
  @rollout_to_roll_back
end

#target_idString

Required. ID of the Target that is being rolled back. Corresponds to the JSON property targetId

Returns:

  • (String)


5529
5530
5531
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5529

def target_id
  @target_id
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If set to true, the request is validated and the user is provided with a RollbackTargetResponse. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


5535
5536
5537
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5535

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5543
5544
5545
5546
5547
5548
5549
5550
5551
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5543

def update!(**args)
  @override_deploy_policy = args[:override_deploy_policy] if args.key?(:override_deploy_policy)
  @release_id = args[:release_id] if args.key?(:release_id)
  @rollback_config = args[:rollback_config] if args.key?(:rollback_config)
  @rollout_id = args[:rollout_id] if args.key?(:rollout_id)
  @rollout_to_roll_back = args[:rollout_to_roll_back] if args.key?(:rollout_to_roll_back)
  @target_id = args[:target_id] if args.key?(:target_id)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end