Class: Google::Apis::ClouddeployV1::RollbackTargetRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

The request object for RollbackTarget.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RollbackTargetRequest

Returns a new instance of RollbackTargetRequest.



4947
4948
4949
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4947

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#override_deploy_policyArray<String>

Optional. Deploy policies to override. Format is projects/project/locations/ location/deployPolicies/deploy_policy`. Corresponds to the JSON propertyoverrideDeployPolicy`

Returns:

  • (Array<String>)


4910
4911
4912
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4910

def override_deploy_policy
  @override_deploy_policy
end

#release_idString

Optional. ID of the Release to roll back to. If this isn't specified, the previous successful Rollout to the specified target will be used to determine the Release. Corresponds to the JSON property releaseId

Returns:

  • (String)


4917
4918
4919
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4917

def release_id
  @release_id
end

#rollback_configGoogle::Apis::ClouddeployV1::RollbackTargetConfig

Configs for the Rollback rollout. Corresponds to the JSON property rollbackConfig



4922
4923
4924
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4922

def rollback_config
  @rollback_config
end

#rollout_idString

Required. ID of the rollback Rollout to create. Corresponds to the JSON property rolloutId

Returns:

  • (String)


4927
4928
4929
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4927

def rollout_id
  @rollout_id
end

#rollout_to_roll_backString

Optional. If provided, this must be the latest Rollout that is on the Target. Corresponds to the JSON property rolloutToRollBack

Returns:

  • (String)


4933
4934
4935
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4933

def rollout_to_roll_back
  @rollout_to_roll_back
end

#target_idString

Required. ID of the Target that is being rolled back. Corresponds to the JSON property targetId

Returns:

  • (String)


4938
4939
4940
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4938

def target_id
  @target_id
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If set to true, the request is validated and the user is provided with a RollbackTargetResponse. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


4944
4945
4946
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4944

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4952
4953
4954
4955
4956
4957
4958
4959
4960
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4952

def update!(**args)
  @override_deploy_policy = args[:override_deploy_policy] if args.key?(:override_deploy_policy)
  @release_id = args[:release_id] if args.key?(:release_id)
  @rollback_config = args[:rollback_config] if args.key?(:rollback_config)
  @rollout_id = args[:rollout_id] if args.key?(:rollout_id)
  @rollout_to_roll_back = args[:rollout_to_roll_back] if args.key?(:rollout_to_roll_back)
  @target_id = args[:target_id] if args.key?(:target_id)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end