Class: Google::Apis::ClouddeployV1::Rollout

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

A Rollout resource in the Cloud Deploy API. A Rollout contains information around a specific deployment to a Target.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Rollout

Returns a new instance of Rollout.



5712
5713
5714
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5712

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_repair_automation_runString

Output only. The AutomationRun actively repairing the rollout. Corresponds to the JSON property activeRepairAutomationRun

Returns:

  • (String)


5581
5582
5583
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5581

def active_repair_automation_run
  @active_repair_automation_run
end

#annotationsHash<String,String>

Optional. User annotations. These attributes can only be set and used by the user, and not by Cloud Deploy. See https://google.aip.dev/128#annotations for more details such as format and size limitations. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


5588
5589
5590
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5588

def annotations
  @annotations
end

#approval_stateString

Output only. Approval state of the Rollout. Corresponds to the JSON property approvalState

Returns:

  • (String)


5593
5594
5595
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5593

def approval_state
  @approval_state
end

#approve_timeString

Output only. Time at which the Rollout was approved. Corresponds to the JSON property approveTime

Returns:

  • (String)


5598
5599
5600
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5598

def approve_time
  @approve_time
end

#controller_rolloutString

Output only. Name of the ControllerRollout. Format is projects/project/ locations/location/deliveryPipelines/deliveryPipeline/releases/release/ rollouts/rollout`. Corresponds to the JSON propertycontrollerRollout`

Returns:

  • (String)


5605
5606
5607
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5605

def controller_rollout
  @controller_rollout
end

#create_timeString

Output only. Time at which the Rollout was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5610
5611
5612
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5610

def create_time
  @create_time
end

#deploy_end_timeString

Output only. Time at which the Rollout finished deploying. Corresponds to the JSON property deployEndTime

Returns:

  • (String)


5615
5616
5617
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5615

def deploy_end_time
  @deploy_end_time
end

#deploy_failure_causeString

Output only. The reason this rollout failed. This will always be unspecified while the rollout is in progress. Corresponds to the JSON property deployFailureCause

Returns:

  • (String)


5621
5622
5623
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5621

def deploy_failure_cause
  @deploy_failure_cause
end

#deploy_start_timeString

Output only. Time at which the Rollout started deploying. Corresponds to the JSON property deployStartTime

Returns:

  • (String)


5626
5627
5628
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5626

def deploy_start_time
  @deploy_start_time
end

#deploying_buildString

Output only. The resource name of the Cloud Build Build object that is used to deploy the Rollout. Format is projects/project/locations/location/ builds/build`. Corresponds to the JSON propertydeployingBuild`

Returns:

  • (String)


5633
5634
5635
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5633

def deploying_build
  @deploying_build
end

#descriptionString

Optional. Description of the Rollout for user purposes. Max length is 255 characters. Corresponds to the JSON property description

Returns:

  • (String)


5639
5640
5641
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5639

def description
  @description
end

#enqueue_timeString

Output only. Time at which the Rollout was enqueued. Corresponds to the JSON property enqueueTime

Returns:

  • (String)


5644
5645
5646
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5644

def enqueue_time
  @enqueue_time
end

#etagString

This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up- to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


5651
5652
5653
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5651

def etag
  @etag
end

#failure_reasonString

Output only. Additional information about the rollout failure, if available. Corresponds to the JSON property failureReason

Returns:

  • (String)


5656
5657
5658
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5656

def failure_reason
  @failure_reason
end

#labelsHash<String,String>

Labels are attributes that can be set and used by both the user and by Cloud Deploy. Labels must meet the following constraints: * Keys and values can contain only lowercase letters, numeric characters, underscores, and dashes. * All characters must use UTF-8 encoding, and international characters are allowed. * Keys must start with a lowercase letter or international character.

  • Each resource is limited to a maximum of 64 labels. Both keys and values are additionally constrained to be <= 128 bytes. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5667
5668
5669
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5667

def labels
  @labels
end

#metadataGoogle::Apis::ClouddeployV1::Metadata

Metadata includes information associated with a Rollout. Corresponds to the JSON property metadata



5672
5673
5674
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5672

def 
  @metadata
end

#nameString

Identifier. Name of the Rollout. Format is projects/project/locations/ location/deliveryPipelines/deliveryPipeline/releases/release/rollouts/ rollout`. Therolloutcomponent must matcha-z? Corresponds to the JSON propertyname`

Returns:

  • (String)


5679
5680
5681
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5679

def name
  @name
end

#phasesArray<Google::Apis::ClouddeployV1::Phase>

Output only. The phases that represent the workflows of this Rollout. Corresponds to the JSON property phases



5684
5685
5686
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5684

def phases
  @phases
end

#rollback_of_rolloutString

Output only. Name of the Rollout that is rolled back by this Rollout. Empty if this Rollout wasn't created as a rollback. Corresponds to the JSON property rollbackOfRollout

Returns:

  • (String)


5690
5691
5692
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5690

def rollback_of_rollout
  @rollback_of_rollout
end

#rolled_back_by_rolloutsArray<String>

Output only. Names of Rollouts that rolled back this Rollout. Corresponds to the JSON property rolledBackByRollouts

Returns:

  • (Array<String>)


5695
5696
5697
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5695

def rolled_back_by_rollouts
  @rolled_back_by_rollouts
end

#stateString

Output only. Current state of the Rollout. Corresponds to the JSON property state

Returns:

  • (String)


5700
5701
5702
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5700

def state
  @state
end

#target_idString

Required. The ID of Target to which this Rollout is deploying. Corresponds to the JSON property targetId

Returns:

  • (String)


5705
5706
5707
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5705

def target_id
  @target_id
end

#uidString

Output only. Unique identifier of the Rollout. Corresponds to the JSON property uid

Returns:

  • (String)


5710
5711
5712
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5710

def uid
  @uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5717
5718
5719
5720
5721
5722
5723
5724
5725
5726
5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
5739
5740
5741
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5717

def update!(**args)
  @active_repair_automation_run = args[:active_repair_automation_run] if args.key?(:active_repair_automation_run)
  @annotations = args[:annotations] if args.key?(:annotations)
  @approval_state = args[:approval_state] if args.key?(:approval_state)
  @approve_time = args[:approve_time] if args.key?(:approve_time)
  @controller_rollout = args[:controller_rollout] if args.key?(:controller_rollout)
  @create_time = args[:create_time] if args.key?(:create_time)
  @deploy_end_time = args[:deploy_end_time] if args.key?(:deploy_end_time)
  @deploy_failure_cause = args[:deploy_failure_cause] if args.key?(:deploy_failure_cause)
  @deploy_start_time = args[:deploy_start_time] if args.key?(:deploy_start_time)
  @deploying_build = args[:deploying_build] if args.key?(:deploying_build)
  @description = args[:description] if args.key?(:description)
  @enqueue_time = args[:enqueue_time] if args.key?(:enqueue_time)
  @etag = args[:etag] if args.key?(:etag)
  @failure_reason = args[:failure_reason] if args.key?(:failure_reason)
  @labels = args[:labels] if args.key?(:labels)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @phases = args[:phases] if args.key?(:phases)
  @rollback_of_rollout = args[:rollback_of_rollout] if args.key?(:rollback_of_rollout)
  @rolled_back_by_rollouts = args[:rolled_back_by_rollouts] if args.key?(:rolled_back_by_rollouts)
  @state = args[:state] if args.key?(:state)
  @target_id = args[:target_id] if args.key?(:target_id)
  @uid = args[:uid] if args.key?(:uid)
end