Class: Google::Apis::ClouddeployV1::Rollout
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::Rollout
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
A Rollout resource in the Cloud Deploy API. A Rollout contains information
around a specific deployment to a Target.
Instance Attribute Summary collapse
-
#active_repair_automation_run ⇒ String
Output only.
-
#annotations ⇒ Hash<String,String>
Optional.
-
#approval_state ⇒ String
Output only.
-
#approve_time ⇒ String
Output only.
-
#controller_rollout ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#deploy_end_time ⇒ String
Output only.
-
#deploy_failure_cause ⇒ String
Output only.
-
#deploy_start_time ⇒ String
Output only.
-
#deploying_build ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#enqueue_time ⇒ String
Output only.
-
#etag ⇒ String
This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up- to-date value before proceeding.
-
#failure_reason ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Labels are attributes that can be set and used by both the user and by Cloud Deploy.
-
#metadata ⇒ Google::Apis::ClouddeployV1::Metadata
Metadata includes information associated with a
Rollout. -
#name ⇒ String
Identifier.
-
#phases ⇒ Array<Google::Apis::ClouddeployV1::Phase>
Output only.
-
#rollback_of_rollout ⇒ String
Output only.
-
#rolled_back_by_rollouts ⇒ Array<String>
Output only.
-
#state ⇒ String
Output only.
-
#target_id ⇒ String
Required.
-
#uid ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Rollout
constructor
A new instance of Rollout.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Rollout
Returns a new instance of Rollout.
5121 5122 5123 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5121 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_repair_automation_run ⇒ String
Output only. The AutomationRun actively repairing the rollout.
Corresponds to the JSON property activeRepairAutomationRun
4990 4991 4992 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4990 def active_repair_automation_run @active_repair_automation_run end |
#annotations ⇒ Hash<String,String>
Optional. User annotations. These attributes can only be set and used by the
user, and not by Cloud Deploy. See https://google.aip.dev/128#annotations for
more details such as format and size limitations.
Corresponds to the JSON property annotations
4997 4998 4999 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 4997 def annotations @annotations end |
#approval_state ⇒ String
Output only. Approval state of the Rollout.
Corresponds to the JSON property approvalState
5002 5003 5004 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5002 def approval_state @approval_state end |
#approve_time ⇒ String
Output only. Time at which the Rollout was approved.
Corresponds to the JSON property approveTime
5007 5008 5009 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5007 def approve_time @approve_time end |
#controller_rollout ⇒ String
Output only. Name of the ControllerRollout. Format is projects/project/
locations/location/deliveryPipelines/deliveryPipeline/releases/release/
rollouts/rollout`.
Corresponds to the JSON propertycontrollerRollout`
5014 5015 5016 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5014 def controller_rollout @controller_rollout end |
#create_time ⇒ String
Output only. Time at which the Rollout was created.
Corresponds to the JSON property createTime
5019 5020 5021 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5019 def create_time @create_time end |
#deploy_end_time ⇒ String
Output only. Time at which the Rollout finished deploying.
Corresponds to the JSON property deployEndTime
5024 5025 5026 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5024 def deploy_end_time @deploy_end_time end |
#deploy_failure_cause ⇒ String
Output only. The reason this rollout failed. This will always be unspecified
while the rollout is in progress.
Corresponds to the JSON property deployFailureCause
5030 5031 5032 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5030 def deploy_failure_cause @deploy_failure_cause end |
#deploy_start_time ⇒ String
Output only. Time at which the Rollout started deploying.
Corresponds to the JSON property deployStartTime
5035 5036 5037 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5035 def deploy_start_time @deploy_start_time end |
#deploying_build ⇒ String
Output only. The resource name of the Cloud Build Build object that is used
to deploy the Rollout. Format is projects/project/locations/location/
builds/build`.
Corresponds to the JSON propertydeployingBuild`
5042 5043 5044 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5042 def @deploying_build end |
#description ⇒ String
Optional. Description of the Rollout for user purposes. Max length is 255
characters.
Corresponds to the JSON property description
5048 5049 5050 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5048 def description @description end |
#enqueue_time ⇒ String
Output only. Time at which the Rollout was enqueued.
Corresponds to the JSON property enqueueTime
5053 5054 5055 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5053 def enqueue_time @enqueue_time end |
#etag ⇒ String
This checksum is computed by the server based on the value of other fields,
and may be sent on update and delete requests to ensure the client has an up-
to-date value before proceeding.
Corresponds to the JSON property etag
5060 5061 5062 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5060 def etag @etag end |
#failure_reason ⇒ String
Output only. Additional information about the rollout failure, if available.
Corresponds to the JSON property failureReason
5065 5066 5067 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5065 def failure_reason @failure_reason end |
#labels ⇒ Hash<String,String>
Labels are attributes that can be set and used by both the user and by Cloud Deploy. Labels must meet the following constraints: * Keys and values can contain only lowercase letters, numeric characters, underscores, and dashes. * All characters must use UTF-8 encoding, and international characters are allowed. * Keys must start with a lowercase letter or international character.
- Each resource is limited to a maximum of 64 labels. Both keys and values are
additionally constrained to be <= 128 bytes.
Corresponds to the JSON property
labels
5076 5077 5078 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5076 def labels @labels end |
#metadata ⇒ Google::Apis::ClouddeployV1::Metadata
Metadata includes information associated with a Rollout.
Corresponds to the JSON property metadata
5081 5082 5083 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5081 def @metadata end |
#name ⇒ String
Identifier. Name of the Rollout. Format is projects/project/locations/
location/deliveryPipelines/deliveryPipeline/releases/release/rollouts/
rollout`. Therolloutcomponent must matcha-z?
Corresponds to the JSON propertyname`
5088 5089 5090 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5088 def name @name end |
#phases ⇒ Array<Google::Apis::ClouddeployV1::Phase>
Output only. The phases that represent the workflows of this Rollout.
Corresponds to the JSON property phases
5093 5094 5095 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5093 def phases @phases end |
#rollback_of_rollout ⇒ String
Output only. Name of the Rollout that is rolled back by this Rollout.
Empty if this Rollout wasn't created as a rollback.
Corresponds to the JSON property rollbackOfRollout
5099 5100 5101 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5099 def rollback_of_rollout @rollback_of_rollout end |
#rolled_back_by_rollouts ⇒ Array<String>
Output only. Names of Rollouts that rolled back this Rollout.
Corresponds to the JSON property rolledBackByRollouts
5104 5105 5106 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5104 def rolled_back_by_rollouts @rolled_back_by_rollouts end |
#state ⇒ String
Output only. Current state of the Rollout.
Corresponds to the JSON property state
5109 5110 5111 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5109 def state @state end |
#target_id ⇒ String
Required. The ID of Target to which this Rollout is deploying.
Corresponds to the JSON property targetId
5114 5115 5116 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5114 def target_id @target_id end |
#uid ⇒ String
Output only. Unique identifier of the Rollout.
Corresponds to the JSON property uid
5119 5120 5121 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5119 def uid @uid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5126 def update!(**args) @active_repair_automation_run = args[:active_repair_automation_run] if args.key?(:active_repair_automation_run) @annotations = args[:annotations] if args.key?(:annotations) @approval_state = args[:approval_state] if args.key?(:approval_state) @approve_time = args[:approve_time] if args.key?(:approve_time) @controller_rollout = args[:controller_rollout] if args.key?(:controller_rollout) @create_time = args[:create_time] if args.key?(:create_time) @deploy_end_time = args[:deploy_end_time] if args.key?(:deploy_end_time) @deploy_failure_cause = args[:deploy_failure_cause] if args.key?(:deploy_failure_cause) @deploy_start_time = args[:deploy_start_time] if args.key?(:deploy_start_time) @deploying_build = args[:deploying_build] if args.key?(:deploying_build) @description = args[:description] if args.key?(:description) @enqueue_time = args[:enqueue_time] if args.key?(:enqueue_time) @etag = args[:etag] if args.key?(:etag) @failure_reason = args[:failure_reason] if args.key?(:failure_reason) @labels = args[:labels] if args.key?(:labels) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @phases = args[:phases] if args.key?(:phases) @rollback_of_rollout = args[:rollback_of_rollout] if args.key?(:rollback_of_rollout) @rolled_back_by_rollouts = args[:rolled_back_by_rollouts] if args.key?(:rolled_back_by_rollouts) @state = args[:state] if args.key?(:state) @target_id = args[:target_id] if args.key?(:target_id) @uid = args[:uid] if args.key?(:uid) end |