Class: Google::Apis::ClouddeployV1::RolloutNotificationEvent

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

Payload proto for "clouddeploy.googleapis.com/rollout_notification" Platform Log event that describes the failure to send rollout status change Pub/Sub notification.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutNotificationEvent

Returns a new instance of RolloutNotificationEvent.



5179
5180
5181
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5179

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#messageString

Debug message for when a notification fails to send. Corresponds to the JSON property message

Returns:

  • (String)


5142
5143
5144
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5142

def message
  @message
end

#pipeline_uidString

Unique identifier of the DeliveryPipeline. Corresponds to the JSON property pipelineUid

Returns:

  • (String)


5147
5148
5149
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5147

def pipeline_uid
  @pipeline_uid
end

#releaseString

The name of the Release. Corresponds to the JSON property release

Returns:

  • (String)


5152
5153
5154
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5152

def release
  @release
end

#release_uidString

Unique identifier of the Release. Corresponds to the JSON property releaseUid

Returns:

  • (String)


5157
5158
5159
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5157

def release_uid
  @release_uid
end

#rolloutString

The name of the Rollout. Corresponds to the JSON property rollout

Returns:

  • (String)


5162
5163
5164
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5162

def rollout
  @rollout
end

#rollout_uidString

Unique identifier of the Rollout. Corresponds to the JSON property rolloutUid

Returns:

  • (String)


5167
5168
5169
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5167

def rollout_uid
  @rollout_uid
end

#target_idString

ID of the Target that the rollout is deployed to. Corresponds to the JSON property targetId

Returns:

  • (String)


5172
5173
5174
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5172

def target_id
  @target_id
end

#typeString

Type of this notification, e.g. for a Pub/Sub failure. Corresponds to the JSON property type

Returns:

  • (String)


5177
5178
5179
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5177

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5184
5185
5186
5187
5188
5189
5190
5191
5192
5193
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5184

def update!(**args)
  @message = args[:message] if args.key?(:message)
  @pipeline_uid = args[:pipeline_uid] if args.key?(:pipeline_uid)
  @release = args[:release] if args.key?(:release)
  @release_uid = args[:release_uid] if args.key?(:release_uid)
  @rollout = args[:rollout] if args.key?(:rollout)
  @rollout_uid = args[:rollout_uid] if args.key?(:rollout_uid)
  @target_id = args[:target_id] if args.key?(:target_id)
  @type = args[:type] if args.key?(:type)
end