Class: Google::Apis::ClouddeployV1::RolloutUpdateEvent
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::RolloutUpdateEvent
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
Payload proto for "clouddeploy.googleapis.com/rollout_update" Platform Log event that describes the rollout update event.
Instance Attribute Summary collapse
-
#message ⇒ String
Debug message for when a rollout update event occurs.
-
#pipeline_uid ⇒ String
Unique identifier of the pipeline.
-
#release ⇒ String
The name of the
Release. -
#release_uid ⇒ String
Unique identifier of the release.
-
#rollout ⇒ String
The name of the rollout.
-
#rollout_update_type ⇒ String
The type of the rollout update.
-
#target_id ⇒ String
ID of the target.
-
#type ⇒ String
Type of this notification, e.g.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutUpdateEvent
constructor
A new instance of RolloutUpdateEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutUpdateEvent
Returns a new instance of RolloutUpdateEvent.
5896 5897 5898 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5896 def initialize(**args) update!(**args) end |
Instance Attribute Details
#message ⇒ String
Debug message for when a rollout update event occurs.
Corresponds to the JSON property message
5857 5858 5859 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5857 def @message end |
#pipeline_uid ⇒ String
Unique identifier of the pipeline.
Corresponds to the JSON property pipelineUid
5862 5863 5864 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5862 def pipeline_uid @pipeline_uid end |
#release ⇒ String
The name of the Release.
Corresponds to the JSON property release
5867 5868 5869 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5867 def release @release end |
#release_uid ⇒ String
Unique identifier of the release.
Corresponds to the JSON property releaseUid
5872 5873 5874 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5872 def release_uid @release_uid end |
#rollout ⇒ String
The name of the rollout. rollout_uid is not in this log message because we
write some of these log messages at rollout creation time, before we've
generated the uid.
Corresponds to the JSON property rollout
5879 5880 5881 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5879 def rollout @rollout end |
#rollout_update_type ⇒ String
The type of the rollout update.
Corresponds to the JSON property rolloutUpdateType
5884 5885 5886 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5884 def rollout_update_type @rollout_update_type end |
#target_id ⇒ String
ID of the target.
Corresponds to the JSON property targetId
5889 5890 5891 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5889 def target_id @target_id end |
#type ⇒ String
Type of this notification, e.g. for a rollout update event.
Corresponds to the JSON property type
5894 5895 5896 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5894 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5901 5902 5903 5904 5905 5906 5907 5908 5909 5910 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5901 def update!(**args) @message = args[:message] if args.key?(:message) @pipeline_uid = args[:pipeline_uid] if args.key?(:pipeline_uid) @release = args[:release] if args.key?(:release) @release_uid = args[:release_uid] if args.key?(:release_uid) @rollout = args[:rollout] if args.key?(:rollout) @rollout_update_type = args[:rollout_update_type] if args.key?(:rollout_update_type) @target_id = args[:target_id] if args.key?(:target_id) @type = args[:type] if args.key?(:type) end |