Class: Google::Apis::ClouddeployV1::RolloutUpdateEvent

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

Payload proto for "clouddeploy.googleapis.com/rollout_update" Platform Log event that describes the rollout update event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutUpdateEvent

Returns a new instance of RolloutUpdateEvent.



5305
5306
5307
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5305

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#messageString

Debug message for when a rollout update event occurs. Corresponds to the JSON property message

Returns:

  • (String)


5266
5267
5268
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5266

def message
  @message
end

#pipeline_uidString

Unique identifier of the pipeline. Corresponds to the JSON property pipelineUid

Returns:

  • (String)


5271
5272
5273
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5271

def pipeline_uid
  @pipeline_uid
end

#releaseString

The name of the Release. Corresponds to the JSON property release

Returns:

  • (String)


5276
5277
5278
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5276

def release
  @release
end

#release_uidString

Unique identifier of the release. Corresponds to the JSON property releaseUid

Returns:

  • (String)


5281
5282
5283
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5281

def release_uid
  @release_uid
end

#rolloutString

The name of the rollout. rollout_uid is not in this log message because we write some of these log messages at rollout creation time, before we've generated the uid. Corresponds to the JSON property rollout

Returns:

  • (String)


5288
5289
5290
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5288

def rollout
  @rollout
end

#rollout_update_typeString

The type of the rollout update. Corresponds to the JSON property rolloutUpdateType

Returns:

  • (String)


5293
5294
5295
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5293

def rollout_update_type
  @rollout_update_type
end

#target_idString

ID of the target. Corresponds to the JSON property targetId

Returns:

  • (String)


5298
5299
5300
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5298

def target_id
  @target_id
end

#typeString

Type of this notification, e.g. for a rollout update event. Corresponds to the JSON property type

Returns:

  • (String)


5303
5304
5305
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5303

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5310
5311
5312
5313
5314
5315
5316
5317
5318
5319
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5310

def update!(**args)
  @message = args[:message] if args.key?(:message)
  @pipeline_uid = args[:pipeline_uid] if args.key?(:pipeline_uid)
  @release = args[:release] if args.key?(:release)
  @release_uid = args[:release_uid] if args.key?(:release_uid)
  @rollout = args[:rollout] if args.key?(:rollout)
  @rollout_update_type = args[:rollout_update_type] if args.key?(:rollout_update_type)
  @target_id = args[:target_id] if args.key?(:target_id)
  @type = args[:type] if args.key?(:type)
end