Class: Google::Apis::ClouddeployV1::RolloutUpdateEvent

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

Payload proto for "clouddeploy.googleapis.com/rollout_update" Platform Log event that describes the rollout update event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutUpdateEvent

Returns a new instance of RolloutUpdateEvent.



5285
5286
5287
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5285

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#messageString

Debug message for when a rollout update event occurs. Corresponds to the JSON property message

Returns:

  • (String)


5246
5247
5248
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5246

def message
  @message
end

#pipeline_uidString

Unique identifier of the pipeline. Corresponds to the JSON property pipelineUid

Returns:

  • (String)


5251
5252
5253
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5251

def pipeline_uid
  @pipeline_uid
end

#releaseString

The name of the Release. Corresponds to the JSON property release

Returns:

  • (String)


5256
5257
5258
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5256

def release
  @release
end

#release_uidString

Unique identifier of the release. Corresponds to the JSON property releaseUid

Returns:

  • (String)


5261
5262
5263
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5261

def release_uid
  @release_uid
end

#rolloutString

The name of the rollout. rollout_uid is not in this log message because we write some of these log messages at rollout creation time, before we've generated the uid. Corresponds to the JSON property rollout

Returns:

  • (String)


5268
5269
5270
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5268

def rollout
  @rollout
end

#rollout_update_typeString

The type of the rollout update. Corresponds to the JSON property rolloutUpdateType

Returns:

  • (String)


5273
5274
5275
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5273

def rollout_update_type
  @rollout_update_type
end

#target_idString

ID of the target. Corresponds to the JSON property targetId

Returns:

  • (String)


5278
5279
5280
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5278

def target_id
  @target_id
end

#typeString

Type of this notification, e.g. for a rollout update event. Corresponds to the JSON property type

Returns:

  • (String)


5283
5284
5285
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5283

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5290
5291
5292
5293
5294
5295
5296
5297
5298
5299
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5290

def update!(**args)
  @message = args[:message] if args.key?(:message)
  @pipeline_uid = args[:pipeline_uid] if args.key?(:pipeline_uid)
  @release = args[:release] if args.key?(:release)
  @release_uid = args[:release_uid] if args.key?(:release_uid)
  @rollout = args[:rollout] if args.key?(:rollout)
  @rollout_update_type = args[:rollout_update_type] if args.key?(:rollout_update_type)
  @target_id = args[:target_id] if args.key?(:target_id)
  @type = args[:type] if args.key?(:type)
end