Class: Google::Apis::ClouddeployV1::RouteDestinations

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

Information about route destinations for the Gateway API service mesh.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouteDestinations

Returns a new instance of RouteDestinations.



5343
5344
5345
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5343

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destination_idsArray<String>

Required. The clusters where the Gateway API HTTPRoute resource will be deployed to. Valid entries include the associated entities IDs configured in the Target resource and "@self" to include the Target cluster. Corresponds to the JSON property destinationIds

Returns:

  • (Array<String>)


5331
5332
5333
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5331

def destination_ids
  @destination_ids
end

#propagate_serviceBoolean Also known as: propagate_service?

Optional. Whether to propagate the Kubernetes Service to the route destination clusters. The Service will always be deployed to the Target cluster even if the HTTPRoute is not. This option may be used to facilitate successful DNS lookup in the route destination clusters. Can only be set to true if destinations are specified. Corresponds to the JSON property propagateService

Returns:

  • (Boolean)


5340
5341
5342
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5340

def propagate_service
  @propagate_service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5348
5349
5350
5351
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5348

def update!(**args)
  @destination_ids = args[:destination_ids] if args.key?(:destination_ids)
  @propagate_service = args[:propagate_service] if args.key?(:propagate_service)
end