Class: Google::Apis::ClouddeployV1::ServiceNetworking
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::ServiceNetworking
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
Information about the Kubernetes Service networking configuration.
Instance Attribute Summary collapse
-
#deployment ⇒ String
Required.
-
#disable_pod_overprovisioning ⇒ Boolean
(also: #disable_pod_overprovisioning?)
Optional.
-
#pod_selector_label ⇒ String
Optional.
-
#service ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceNetworking
constructor
A new instance of ServiceNetworking.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceNetworking
Returns a new instance of ServiceNetworking.
6020 6021 6022 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6020 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployment ⇒ String
Required. Name of the Kubernetes Deployment whose traffic is managed by the
specified Service.
Corresponds to the JSON property deployment
5999 6000 6001 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5999 def deployment @deployment end |
#disable_pod_overprovisioning ⇒ Boolean Also known as: disable_pod_overprovisioning?
Optional. Whether to disable Pod overprovisioning. If Pod overprovisioning is
disabled then Cloud Deploy will limit the number of total Pods used for the
deployment strategy to the number of Pods the Deployment has on the cluster.
Corresponds to the JSON property disablePodOverprovisioning
6006 6007 6008 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6006 def disable_pod_overprovisioning @disable_pod_overprovisioning end |
#pod_selector_label ⇒ String
Optional. The label to use when selecting Pods for the Deployment resource.
This label must already be present in the Deployment.
Corresponds to the JSON property podSelectorLabel
6013 6014 6015 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6013 def pod_selector_label @pod_selector_label end |
#service ⇒ String
Required. Name of the Kubernetes Service.
Corresponds to the JSON property service
6018 6019 6020 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6018 def service @service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6025 6026 6027 6028 6029 6030 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6025 def update!(**args) @deployment = args[:deployment] if args.key?(:deployment) @disable_pod_overprovisioning = args[:disable_pod_overprovisioning] if args.key?(:disable_pod_overprovisioning) @pod_selector_label = args[:pod_selector_label] if args.key?(:pod_selector_label) @service = args[:service] if args.key?(:service) end |