Class: Google::Apis::ClouddeployV1::ServiceNetworking

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

Information about the Kubernetes Service networking configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceNetworking

Returns a new instance of ServiceNetworking.



5429
5430
5431
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5429

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deploymentString

Required. Name of the Kubernetes Deployment whose traffic is managed by the specified Service. Corresponds to the JSON property deployment

Returns:

  • (String)


5408
5409
5410
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5408

def deployment
  @deployment
end

#disable_pod_overprovisioningBoolean Also known as: disable_pod_overprovisioning?

Optional. Whether to disable Pod overprovisioning. If Pod overprovisioning is disabled then Cloud Deploy will limit the number of total Pods used for the deployment strategy to the number of Pods the Deployment has on the cluster. Corresponds to the JSON property disablePodOverprovisioning

Returns:

  • (Boolean)


5415
5416
5417
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5415

def disable_pod_overprovisioning
  @disable_pod_overprovisioning
end

#pod_selector_labelString

Optional. The label to use when selecting Pods for the Deployment resource. This label must already be present in the Deployment. Corresponds to the JSON property podSelectorLabel

Returns:

  • (String)


5422
5423
5424
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5422

def pod_selector_label
  @pod_selector_label
end

#serviceString

Required. Name of the Kubernetes Service. Corresponds to the JSON property service

Returns:

  • (String)


5427
5428
5429
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5427

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5434
5435
5436
5437
5438
5439
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5434

def update!(**args)
  @deployment = args[:deployment] if args.key?(:deployment)
  @disable_pod_overprovisioning = args[:disable_pod_overprovisioning] if args.key?(:disable_pod_overprovisioning)
  @pod_selector_label = args[:pod_selector_label] if args.key?(:pod_selector_label)
  @service = args[:service] if args.key?(:service)
end