Class: Google::Apis::ClouddeployV1::SkaffoldSupportedCondition

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

SkaffoldSupportedCondition contains information about when support for the release's version of Skaffold ends.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SkaffoldSupportedCondition

Returns a new instance of SkaffoldSupportedCondition.



6241
6242
6243
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6241

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#maintenance_mode_timeString

The time at which this release's version of Skaffold will enter maintenance mode. Corresponds to the JSON property maintenanceModeTime

Returns:

  • (String)


6222
6223
6224
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6222

def maintenance_mode_time
  @maintenance_mode_time
end

#skaffold_support_stateString

The Skaffold support state for this release's version of Skaffold. Corresponds to the JSON property skaffoldSupportState

Returns:

  • (String)


6227
6228
6229
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6227

def skaffold_support_state
  @skaffold_support_state
end

#statusBoolean Also known as: status?

True if the version of Skaffold used by this release is supported. Corresponds to the JSON property status

Returns:

  • (Boolean)


6232
6233
6234
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6232

def status
  @status
end

#support_expiration_timeString

The time at which this release's version of Skaffold will no longer be supported. Corresponds to the JSON property supportExpirationTime

Returns:

  • (String)


6239
6240
6241
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6239

def support_expiration_time
  @support_expiration_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6246
6247
6248
6249
6250
6251
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6246

def update!(**args)
  @maintenance_mode_time = args[:maintenance_mode_time] if args.key?(:maintenance_mode_time)
  @skaffold_support_state = args[:skaffold_support_state] if args.key?(:skaffold_support_state)
  @status = args[:status] if args.key?(:status)
  @support_expiration_time = args[:support_expiration_time] if args.key?(:support_expiration_time)
end