Class: Google::Apis::ClouddeployV1::Target
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::Target
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
A Target resource in the Cloud Deploy API. A Target defines a location to
which a Skaffold configuration can be deployed.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#anthos_cluster ⇒ Google::Apis::ClouddeployV1::AnthosCluster
Information specifying an Anthos Cluster.
-
#associated_entities ⇒ Hash<String,Google::Apis::ClouddeployV1::AssociatedEntities>
Optional.
-
#create_time ⇒ String
Output only.
-
#custom_target ⇒ Google::Apis::ClouddeployV1::CustomTarget
Information specifying a Custom Target.
-
#deploy_parameters ⇒ Hash<String,String>
Optional.
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Optional.
-
#execution_configs ⇒ Array<Google::Apis::ClouddeployV1::ExecutionConfig>
Optional.
-
#gke ⇒ Google::Apis::ClouddeployV1::GkeCluster
Information specifying a GKE Cluster.
-
#labels ⇒ Hash<String,String>
Optional.
-
#multi_target ⇒ Google::Apis::ClouddeployV1::MultiTarget
Information specifying a multiTarget.
-
#name ⇒ String
Identifier.
-
#require_approval ⇒ Boolean
(also: #require_approval?)
Optional.
-
#run ⇒ Google::Apis::ClouddeployV1::CloudRunLocation
Information specifying where to deploy a Cloud Run Service.
-
#target_id ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Target
constructor
A new instance of Target.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Target
Returns a new instance of Target.
5965 5966 5967 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5965 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. User annotations. These attributes can only be set and used by the
user, and not by Cloud Deploy. See https://google.aip.dev/128#annotations for
more details such as format and size limitations.
Corresponds to the JSON property annotations
5855 5856 5857 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5855 def annotations @annotations end |
#anthos_cluster ⇒ Google::Apis::ClouddeployV1::AnthosCluster
Information specifying an Anthos Cluster.
Corresponds to the JSON property anthosCluster
5860 5861 5862 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5860 def anthos_cluster @anthos_cluster end |
#associated_entities ⇒ Hash<String,Google::Apis::ClouddeployV1::AssociatedEntities>
Optional. Map of entity IDs to their associated entities. Associated entities
allows specifying places other than the deployment target for specific
features. For example, the Gateway API canary can be configured to deploy the
HTTPRoute to a different cluster(s) than the deployment cluster using
associated entities. An entity ID must consist of lower-case letters, numbers,
and hyphens, start with a letter and end with a letter or a number, and have a
max length of 63 characters. In other words, it must match the following regex:
^[a-z]([a-z0-9-]0,61[a-z0-9])?$.
Corresponds to the JSON property associatedEntities
5872 5873 5874 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5872 def associated_entities @associated_entities end |
#create_time ⇒ String
Output only. Time at which the Target was created.
Corresponds to the JSON property createTime
5877 5878 5879 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5877 def create_time @create_time end |
#custom_target ⇒ Google::Apis::ClouddeployV1::CustomTarget
Information specifying a Custom Target.
Corresponds to the JSON property customTarget
5882 5883 5884 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5882 def custom_target @custom_target end |
#deploy_parameters ⇒ Hash<String,String>
Optional. The deploy parameters to use for this target.
Corresponds to the JSON property deployParameters
5887 5888 5889 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5887 def deploy_parameters @deploy_parameters end |
#description ⇒ String
Optional. Description of the Target. Max length is 255 characters.
Corresponds to the JSON property description
5892 5893 5894 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5892 def description @description end |
#etag ⇒ String
Optional. This checksum is computed by the server based on the value of other
fields, and may be sent on update and delete requests to ensure the client has
an up-to-date value before proceeding.
Corresponds to the JSON property etag
5899 5900 5901 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5899 def etag @etag end |
#execution_configs ⇒ Array<Google::Apis::ClouddeployV1::ExecutionConfig>
Optional. Configurations for all execution that relates to this Target. Each
ExecutionEnvironmentUsage value may only be used in a single configuration;
using the same value multiple times is an error. When one or more
configurations are specified, they must include the RENDER and DEPLOY
ExecutionEnvironmentUsage values. When no configurations are specified,
execution will use the default specified in DefaultPool.
Corresponds to the JSON property executionConfigs
5909 5910 5911 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5909 def execution_configs @execution_configs end |
#gke ⇒ Google::Apis::ClouddeployV1::GkeCluster
Information specifying a GKE Cluster.
Corresponds to the JSON property gke
5914 5915 5916 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5914 def gke @gke end |
#labels ⇒ Hash<String,String>
Optional. Labels are attributes that can be set and used by both the user and
by Cloud Deploy. Labels must meet the following constraints: * Keys and values
can contain only lowercase letters, numeric characters, underscores, and
dashes. * All characters must use UTF-8 encoding, and international characters
are allowed. * Keys must start with a lowercase letter or international
character. * Each resource is limited to a maximum of 64 labels. Both keys and
values are additionally constrained to be <= 128 bytes.
Corresponds to the JSON property labels
5925 5926 5927 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5925 def labels @labels end |
#multi_target ⇒ Google::Apis::ClouddeployV1::MultiTarget
Information specifying a multiTarget.
Corresponds to the JSON property multiTarget
5930 5931 5932 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5930 def multi_target @multi_target end |
#name ⇒ String
Identifier. Name of the Target. Format is projects/project/locations/
location/targets/target`. Thetargetcomponent must matcha-z?
Corresponds to the JSON propertyname`
5937 5938 5939 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5937 def name @name end |
#require_approval ⇒ Boolean Also known as: require_approval?
Optional. Whether or not the Target requires approval.
Corresponds to the JSON property requireApproval
5942 5943 5944 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5942 def require_approval @require_approval end |
#run ⇒ Google::Apis::ClouddeployV1::CloudRunLocation
Information specifying where to deploy a Cloud Run Service.
Corresponds to the JSON property run
5948 5949 5950 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5948 def run @run end |
#target_id ⇒ String
Output only. Resource id of the Target.
Corresponds to the JSON property targetId
5953 5954 5955 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5953 def target_id @target_id end |
#uid ⇒ String
Output only. Unique identifier of the Target.
Corresponds to the JSON property uid
5958 5959 5960 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5958 def uid @uid end |
#update_time ⇒ String
Output only. Most recent time at which the Target was updated.
Corresponds to the JSON property updateTime
5963 5964 5965 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5963 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 5987 5988 5989 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 5970 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @anthos_cluster = args[:anthos_cluster] if args.key?(:anthos_cluster) @associated_entities = args[:associated_entities] if args.key?(:associated_entities) @create_time = args[:create_time] if args.key?(:create_time) @custom_target = args[:custom_target] if args.key?(:custom_target) @deploy_parameters = args[:deploy_parameters] if args.key?(:deploy_parameters) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @execution_configs = args[:execution_configs] if args.key?(:execution_configs) @gke = args[:gke] if args.key?(:gke) @labels = args[:labels] if args.key?(:labels) @multi_target = args[:multi_target] if args.key?(:multi_target) @name = args[:name] if args.key?(:name) @require_approval = args[:require_approval] if args.key?(:require_approval) @run = args[:run] if args.key?(:run) @target_id = args[:target_id] if args.key?(:target_id) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |