Class: Google::Apis::ClouddeployV1::TargetsTypeCondition
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::TargetsTypeCondition
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
TargetsTypeCondition contains information on whether the Targets defined in the Delivery Pipeline are of the same type.
Instance Attribute Summary collapse
-
#error_details ⇒ String
Human readable error message.
-
#status ⇒ Boolean
(also: #status?)
True if the targets are all a comparable type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetsTypeCondition
constructor
A new instance of TargetsTypeCondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetsTypeCondition
Returns a new instance of TargetsTypeCondition.
6821 6822 6823 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6821 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_details ⇒ String
Human readable error message.
Corresponds to the JSON property errorDetails
6811 6812 6813 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6811 def error_details @error_details end |
#status ⇒ Boolean Also known as: status?
True if the targets are all a comparable type. For example this is true if all
targets are GKE clusters. This is false if some targets are Cloud Run targets
and others are GKE clusters.
Corresponds to the JSON property status
6818 6819 6820 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6818 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6826 6827 6828 6829 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6826 def update!(**args) @error_details = args[:error_details] if args.key?(:error_details) @status = args[:status] if args.key?(:status) end |