Class: Google::Apis::ClouddeployV1::TargetsTypeCondition

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

TargetsTypeCondition contains information on whether the Targets defined in the Delivery Pipeline are of the same type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetsTypeCondition

Returns a new instance of TargetsTypeCondition.



6217
6218
6219
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6217

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_detailsString

Human readable error message. Corresponds to the JSON property errorDetails

Returns:

  • (String)


6207
6208
6209
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6207

def error_details
  @error_details
end

#statusBoolean Also known as: status?

True if the targets are all a comparable type. For example this is true if all targets are GKE clusters. This is false if some targets are Cloud Run targets and others are GKE clusters. Corresponds to the JSON property status

Returns:

  • (Boolean)


6214
6215
6216
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6214

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6222
6223
6224
6225
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6222

def update!(**args)
  @error_details = args[:error_details] if args.key?(:error_details)
  @status = args[:status] if args.key?(:status)
end