Class: Google::Apis::ClouddeployV1::TargetsTypeCondition

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

TargetsTypeCondition contains information on whether the Targets defined in the Delivery Pipeline are of the same type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetsTypeCondition

Returns a new instance of TargetsTypeCondition.



6197
6198
6199
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6197

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_detailsString

Human readable error message. Corresponds to the JSON property errorDetails

Returns:

  • (String)


6187
6188
6189
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6187

def error_details
  @error_details
end

#statusBoolean Also known as: status?

True if the targets are all a comparable type. For example this is true if all targets are GKE clusters. This is false if some targets are Cloud Run targets and others are GKE clusters. Corresponds to the JSON property status

Returns:

  • (Boolean)


6194
6195
6196
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6194

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6202
6203
6204
6205
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6202

def update!(**args)
  @error_details = args[:error_details] if args.key?(:error_details)
  @status = args[:status] if args.key?(:status)
end