Class: Google::Apis::ClouddeployV1::Task
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::Task
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
A Task represents a unit of work that is executed as part of a Job.
Instance Attribute Summary collapse
-
#container ⇒ Google::Apis::ClouddeployV1::ContainerTask
This task is represented by a container that is executed in the Cloud Build execution environment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Task
constructor
A new instance of Task.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Task
Returns a new instance of Task.
6849 6850 6851 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6849 def initialize(**args) update!(**args) end |
Instance Attribute Details
#container ⇒ Google::Apis::ClouddeployV1::ContainerTask
This task is represented by a container that is executed in the Cloud Build
execution environment.
Corresponds to the JSON property container
6847 6848 6849 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6847 def container @container end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6854 6855 6856 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6854 def update!(**args) @container = args[:container] if args.key?(:container) end |