Class: Google::Apis::ClouddeployV1::Task

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

A Task represents a unit of work that is executed as part of a Job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Task

Returns a new instance of Task.



6842
6843
6844
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6842

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#containerGoogle::Apis::ClouddeployV1::ContainerTask

This task is represented by a container that is executed in the Cloud Build execution environment. Corresponds to the JSON property container



6840
6841
6842
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6840

def container
  @container
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6847
6848
6849
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6847

def update!(**args)
  @container = args[:container] if args.key?(:container)
end