Class: Google::Apis::ClouddeployV1::TimedPromoteReleaseOperation
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::TimedPromoteReleaseOperation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
Contains the information of an automated timed promote-release operation.
Instance Attribute Summary collapse
-
#phase ⇒ String
Output only.
-
#release ⇒ String
Output only.
-
#target_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TimedPromoteReleaseOperation
constructor
A new instance of TimedPromoteReleaseOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TimedPromoteReleaseOperation
Returns a new instance of TimedPromoteReleaseOperation.
6427 6428 6429 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6427 def initialize(**args) update!(**args) end |
Instance Attribute Details
#phase ⇒ String
Output only. The starting phase of the rollout created by this operation.
Corresponds to the JSON property phase
6413 6414 6415 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6413 def phase @phase end |
#release ⇒ String
Output only. The name of the release to be promoted.
Corresponds to the JSON property release
6418 6419 6420 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6418 def release @release end |
#target_id ⇒ String
Output only. The ID of the target that represents the promotion stage to which
the release will be promoted. The value of this field is the last segment of a
target name.
Corresponds to the JSON property targetId
6425 6426 6427 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6425 def target_id @target_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6432 6433 6434 6435 6436 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6432 def update!(**args) @phase = args[:phase] if args.key?(:phase) @release = args[:release] if args.key?(:release) @target_id = args[:target_id] if args.key?(:target_id) end |