Class: Google::Apis::ClouddeployV1::TimedPromoteReleaseRule
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::TimedPromoteReleaseRule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
The TimedPromoteReleaseRule will automatically promote a release from the
current target(s) to the specified target(s) on a configured schedule.
Instance Attribute Summary collapse
-
#condition ⇒ Google::Apis::ClouddeployV1::AutomationRuleCondition
AutomationRuleConditioncontains conditions relevant to anAutomationrule. -
#destination_phase ⇒ String
Optional.
-
#destination_target_id ⇒ String
Optional.
-
#id ⇒ String
Required.
-
#schedule ⇒ String
Required.
-
#time_zone ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TimedPromoteReleaseRule
constructor
A new instance of TimedPromoteReleaseRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TimedPromoteReleaseRule
Returns a new instance of TimedPromoteReleaseRule.
7111 7112 7113 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7111 def initialize(**args) update!(**args) end |
Instance Attribute Details
#condition ⇒ Google::Apis::ClouddeployV1::AutomationRuleCondition
AutomationRuleCondition contains conditions relevant to an Automation rule.
Corresponds to the JSON property condition
7078 7079 7080 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7078 def condition @condition end |
#destination_phase ⇒ String
Optional. The starting phase of the rollout created by this rule. Default to
the first phase.
Corresponds to the JSON property destinationPhase
7084 7085 7086 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7084 def destination_phase @destination_phase end |
#destination_target_id ⇒ String
Optional. The ID of the stage in the pipeline to which this Release is
deploying. If unspecified, default it to the next stage in the promotion flow.
The value of this field could be one of the following: * The last segment of a
target name * "@next", the next target in the promotion sequence
Corresponds to the JSON property destinationTargetId
7092 7093 7094 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7092 def destination_target_id @destination_target_id end |
#id ⇒ String
Required. ID of the rule. This ID must be unique in the Automation resource
to which this rule belongs. The format is [a-z]([a-z0-9-]0,61[a-z0-9])?.
Corresponds to the JSON property id
7098 7099 7100 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7098 def id @id end |
#schedule ⇒ String
Required. Schedule in crontab format. e.g. "0 9 * * 1" for every Monday at 9am.
Corresponds to the JSON property schedule
7103 7104 7105 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7103 def schedule @schedule end |
#time_zone ⇒ String
Required. The time zone in IANA format IANA Time Zone Database (e.g. America/New_York).
Corresponds to the JSON property timeZone
7109 7110 7111 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7109 def time_zone @time_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7116 7117 7118 7119 7120 7121 7122 7123 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7116 def update!(**args) @condition = args[:condition] if args.key?(:condition) @destination_phase = args[:destination_phase] if args.key?(:destination_phase) @destination_target_id = args[:destination_target_id] if args.key?(:destination_target_id) @id = args[:id] if args.key?(:id) @schedule = args[:schedule] if args.key?(:schedule) @time_zone = args[:time_zone] if args.key?(:time_zone) end |