Class: Google::Apis::ClouddeployV1::ToolVersionSupportedCondition
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::ToolVersionSupportedCondition
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
ToolVersionSupportedCondition contains information about when support for the release's version of a tool ends.
Instance Attribute Summary collapse
-
#maintenance_mode_time ⇒ String
Output only.
-
#status ⇒ Boolean
(also: #status?)
Output only.
-
#support_expiration_time ⇒ String
Output only.
-
#tool_version_support_state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ToolVersionSupportedCondition
constructor
A new instance of ToolVersionSupportedCondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ToolVersionSupportedCondition
Returns a new instance of ToolVersionSupportedCondition.
6503 6504 6505 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6503 def initialize(**args) update!(**args) end |
Instance Attribute Details
#maintenance_mode_time ⇒ String
Output only. The time at which this release's version of the tool will enter
maintenance mode.
Corresponds to the JSON property maintenanceModeTime
6484 6485 6486 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6484 def maintenance_mode_time @maintenance_mode_time end |
#status ⇒ Boolean Also known as: status?
Output only. True if the version of Tool used by this release is supported.
Corresponds to the JSON property status
6489 6490 6491 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6489 def status @status end |
#support_expiration_time ⇒ String
Output only. The time at which this release's version of the tool will no
longer be supported.
Corresponds to the JSON property supportExpirationTime
6496 6497 6498 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6496 def support_expiration_time @support_expiration_time end |
#tool_version_support_state ⇒ String
Output only. The tool support state for this release's version of the tool.
Corresponds to the JSON property toolVersionSupportState
6501 6502 6503 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6501 def tool_version_support_state @tool_version_support_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6508 6509 6510 6511 6512 6513 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6508 def update!(**args) @maintenance_mode_time = args[:maintenance_mode_time] if args.key?(:maintenance_mode_time) @status = args[:status] if args.key?(:status) @support_expiration_time = args[:support_expiration_time] if args.key?(:support_expiration_time) @tool_version_support_state = args[:tool_version_support_state] if args.key?(:tool_version_support_state) end |