Class: Google::Apis::ClouddeployV1::ToolVersions

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

Details of ToolVersions for the release.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ToolVersions

Returns a new instance of ToolVersions.



7194
7195
7196
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7194

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dockerString

Optional. The Docker version to use for Cloud Deploy operations. Corresponds to the JSON property docker

Returns:

  • (String)


7167
7168
7169
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7167

def docker
  @docker
end

#helmString

Optional. The Helm version to use for Cloud Deploy operations. Corresponds to the JSON property helm

Returns:

  • (String)


7172
7173
7174
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7172

def helm
  @helm
end

#kptString

Optional. The kpt version to use for Cloud Deploy operations. Corresponds to the JSON property kpt

Returns:

  • (String)


7177
7178
7179
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7177

def kpt
  @kpt
end

#kubectlString

Optional. The Kubectl version to use for Cloud Deploy operations. Corresponds to the JSON property kubectl

Returns:

  • (String)


7182
7183
7184
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7182

def kubectl
  @kubectl
end

#kustomizeString

Optional. The Kustomize version to use for Cloud Deploy operations. Corresponds to the JSON property kustomize

Returns:

  • (String)


7187
7188
7189
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7187

def kustomize
  @kustomize
end

#skaffoldString

Optional. The Skaffold version to use for Cloud Deploy operations. Corresponds to the JSON property skaffold

Returns:

  • (String)


7192
7193
7194
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7192

def skaffold
  @skaffold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7199
7200
7201
7202
7203
7204
7205
7206
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 7199

def update!(**args)
  @docker = args[:docker] if args.key?(:docker)
  @helm = args[:helm] if args.key?(:helm)
  @kpt = args[:kpt] if args.key?(:kpt)
  @kubectl = args[:kubectl] if args.key?(:kubectl)
  @kustomize = args[:kustomize] if args.key?(:kustomize)
  @skaffold = args[:skaffold] if args.key?(:skaffold)
end