Class: Google::Apis::ClouddeployV1::ToolVersions
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::ToolVersions
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
Details of ToolVersions for the release.
Instance Attribute Summary collapse
-
#docker ⇒ String
Optional.
-
#helm ⇒ String
Optional.
-
#kpt ⇒ String
Optional.
-
#kubectl ⇒ String
Optional.
-
#kustomize ⇒ String
Optional.
-
#skaffold ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ToolVersions
constructor
A new instance of ToolVersions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ToolVersions
Returns a new instance of ToolVersions.
6570 6571 6572 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6570 def initialize(**args) update!(**args) end |
Instance Attribute Details
#docker ⇒ String
Optional. The Docker version to use for Cloud Deploy operations.
Corresponds to the JSON property docker
6543 6544 6545 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6543 def docker @docker end |
#helm ⇒ String
Optional. The Helm version to use for Cloud Deploy operations.
Corresponds to the JSON property helm
6548 6549 6550 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6548 def helm @helm end |
#kpt ⇒ String
Optional. The kpt version to use for Cloud Deploy operations.
Corresponds to the JSON property kpt
6553 6554 6555 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6553 def kpt @kpt end |
#kubectl ⇒ String
Optional. The Kubectl version to use for Cloud Deploy operations.
Corresponds to the JSON property kubectl
6558 6559 6560 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6558 def kubectl @kubectl end |
#kustomize ⇒ String
Optional. The Kustomize version to use for Cloud Deploy operations.
Corresponds to the JSON property kustomize
6563 6564 6565 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6563 def kustomize @kustomize end |
#skaffold ⇒ String
Optional. The Skaffold version to use for Cloud Deploy operations.
Corresponds to the JSON property skaffold
6568 6569 6570 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6568 def skaffold @skaffold end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6575 6576 6577 6578 6579 6580 6581 6582 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6575 def update!(**args) @docker = args[:docker] if args.key?(:docker) @helm = args[:helm] if args.key?(:helm) @kpt = args[:kpt] if args.key?(:kpt) @kubectl = args[:kubectl] if args.key?(:kubectl) @kustomize = args[:kustomize] if args.key?(:kustomize) @skaffold = args[:skaffold] if args.key?(:skaffold) end |