Class: Google::Apis::ClouddeployV1::ToolVersions

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

Details of ToolVersions for the release.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ToolVersions

Returns a new instance of ToolVersions.



6550
6551
6552
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6550

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dockerString

Optional. The Docker version to use for Cloud Deploy operations. Corresponds to the JSON property docker

Returns:

  • (String)


6523
6524
6525
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6523

def docker
  @docker
end

#helmString

Optional. The Helm version to use for Cloud Deploy operations. Corresponds to the JSON property helm

Returns:

  • (String)


6528
6529
6530
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6528

def helm
  @helm
end

#kptString

Optional. The kpt version to use for Cloud Deploy operations. Corresponds to the JSON property kpt

Returns:

  • (String)


6533
6534
6535
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6533

def kpt
  @kpt
end

#kubectlString

Optional. The Kubectl version to use for Cloud Deploy operations. Corresponds to the JSON property kubectl

Returns:

  • (String)


6538
6539
6540
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6538

def kubectl
  @kubectl
end

#kustomizeString

Optional. The Kustomize version to use for Cloud Deploy operations. Corresponds to the JSON property kustomize

Returns:

  • (String)


6543
6544
6545
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6543

def kustomize
  @kustomize
end

#skaffoldString

Optional. The Skaffold version to use for Cloud Deploy operations. Corresponds to the JSON property skaffold

Returns:

  • (String)


6548
6549
6550
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6548

def skaffold
  @skaffold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6555
6556
6557
6558
6559
6560
6561
6562
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6555

def update!(**args)
  @docker = args[:docker] if args.key?(:docker)
  @helm = args[:helm] if args.key?(:helm)
  @kpt = args[:kpt] if args.key?(:kpt)
  @kubectl = args[:kubectl] if args.key?(:kubectl)
  @kustomize = args[:kustomize] if args.key?(:kustomize)
  @skaffold = args[:skaffold] if args.key?(:skaffold)
end