Class: Google::Apis::ClouddeployV1::VerifyJobRun

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb

Overview

VerifyJobRun contains information specific to a verify JobRun.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VerifyJobRun

Returns a new instance of VerifyJobRun.



6610
6611
6612
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6610

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_uriString

Output only. URI of a directory containing the verify artifacts. This contains the Skaffold event log. Corresponds to the JSON property artifactUri

Returns:

  • (String)


6586
6587
6588
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6586

def artifact_uri
  @artifact_uri
end

#buildString

Output only. The resource name of the Cloud Build Build object that is used to verify. Format is projects/project/locations/location/builds/build`. Corresponds to the JSON propertybuild`

Returns:

  • (String)


6592
6593
6594
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6592

def build
  @build
end

#event_log_pathString

Output only. File path of the Skaffold event log relative to the artifact URI. Corresponds to the JSON property eventLogPath

Returns:

  • (String)


6597
6598
6599
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6597

def event_log_path
  @event_log_path
end

#failure_causeString

Output only. The reason the verify failed. This will always be unspecified while the verify is in progress or if it succeeded. Corresponds to the JSON property failureCause

Returns:

  • (String)


6603
6604
6605
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6603

def failure_cause
  @failure_cause
end

#failure_messageString

Output only. Additional information about the verify failure, if available. Corresponds to the JSON property failureMessage

Returns:

  • (String)


6608
6609
6610
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6608

def failure_message
  @failure_message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6615
6616
6617
6618
6619
6620
6621
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6615

def update!(**args)
  @artifact_uri = args[:artifact_uri] if args.key?(:artifact_uri)
  @build = args[:build] if args.key?(:build)
  @event_log_path = args[:event_log_path] if args.key?(:event_log_path)
  @failure_cause = args[:failure_cause] if args.key?(:failure_cause)
  @failure_message = args[:failure_message] if args.key?(:failure_message)
end