Class: Google::Apis::ClouddeployV1::VerifyJobRun
- Inherits:
-
Object
- Object
- Google::Apis::ClouddeployV1::VerifyJobRun
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/clouddeploy_v1/classes.rb,
lib/google/apis/clouddeploy_v1/representations.rb,
lib/google/apis/clouddeploy_v1/representations.rb
Overview
VerifyJobRun contains information specific to a verify JobRun.
Instance Attribute Summary collapse
-
#artifact_uri ⇒ String
Output only.
-
#build ⇒ String
Output only.
-
#event_log_path ⇒ String
Output only.
-
#failure_cause ⇒ String
Output only.
-
#failure_message ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VerifyJobRun
constructor
A new instance of VerifyJobRun.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VerifyJobRun
Returns a new instance of VerifyJobRun.
6610 6611 6612 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6610 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_uri ⇒ String
Output only. URI of a directory containing the verify artifacts. This contains
the Skaffold event log.
Corresponds to the JSON property artifactUri
6586 6587 6588 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6586 def artifact_uri @artifact_uri end |
#build ⇒ String
Output only. The resource name of the Cloud Build Build object that is used
to verify. Format is projects/project/locations/location/builds/build`.
Corresponds to the JSON propertybuild`
6592 6593 6594 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6592 def build @build end |
#event_log_path ⇒ String
Output only. File path of the Skaffold event log relative to the artifact URI.
Corresponds to the JSON property eventLogPath
6597 6598 6599 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6597 def event_log_path @event_log_path end |
#failure_cause ⇒ String
Output only. The reason the verify failed. This will always be unspecified
while the verify is in progress or if it succeeded.
Corresponds to the JSON property failureCause
6603 6604 6605 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6603 def failure_cause @failure_cause end |
#failure_message ⇒ String
Output only. Additional information about the verify failure, if available.
Corresponds to the JSON property failureMessage
6608 6609 6610 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6608 def @failure_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6615 6616 6617 6618 6619 6620 6621 |
# File 'lib/google/apis/clouddeploy_v1/classes.rb', line 6615 def update!(**args) @artifact_uri = args[:artifact_uri] if args.key?(:artifact_uri) @build = args[:build] if args.key?(:build) @event_log_path = args[:event_log_path] if args.key?(:event_log_path) @failure_cause = args[:failure_cause] if args.key?(:failure_cause) @failure_message = args[:failure_message] if args.key?(:failure_message) end |